<?php
/**
 * Custom functions for Visual Composer
 *
 * @package    Supro
 * @subpackage Visual Composer
 */

if ( ! function_exists( 'is_plugin_active' ) ) {
	require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
}

/**
 * Class Supro
 *
 * @since 1.0.0
 */
class Supro_VC {

	/**
	 * Temporary cached terms variable
	 *
	 * @var array
	 */
	public $terms = array();

	/**
	 * Construction
	 */
	function __construct() {
		// Stop if VC is not installed
		if ( ! is_plugin_active( 'js_composer/js_composer.php' ) ) {
			return false;
		}

		add_filter( 'vc_autocomplete_supro_portfolios_grid_gap_ids_callback', array( $this, 'portfolioIdsAutocompleteSuggester', ), 10, 1 );
		add_filter( 'vc_autocomplete_supro_portfolios_grid_gap_ids_render', array( $this, 'portfolioIdsAutocompleteRender', ), 10, 1 );

		add_filter( 'vc_autocomplete_supro_portfolios_grid_gap_cats_callback', array( $this, 'portfolioCatsAutocompleteSuggester', ), 10, 1 );
		add_filter( 'vc_autocomplete_supro_portfolios_grid_gap_cats_render', array( $this, 'portfolioCatsAutocompleteRender', ), 10, 1 );

		add_filter( 'vc_iconpicker-type-ionicons', array( $this, 'vc_iconpicker_type_ionicons' ) );
		add_filter( 'vc_iconpicker-type-linearicons', array( $this, 'vc_iconpicker_type_linearicons' ) );

		add_action( 'vc_base_register_front_css', array( $this, 'vc_iconpicker_base_register_css' ) );
		add_action( 'vc_base_register_admin_css', array( $this, 'vc_iconpicker_base_register_css' ) );

		add_action( 'vc_enqueue_font_icon_element', array( $this, 'vc_icon_element_fonts_enqueue' ) );

		vc_add_shortcode_param( 'supro_heading', array( $this, 'supro_custom_heading_field' ) );

		add_action( 'init', array( $this, 'map_shortcodes' ), 20 );
		add_action( 'init', array( $this, 'modify_element' ), 25 );
	}

	function modify_element() {
		// Add new option to Custom Header element
		vc_add_param(
			'vc_custom_heading', array(
				'heading'     => esc_html__( 'Letter Spacing', 'supro' ),
				'description' => esc_html__( 'Enter letter spacing', 'supro' ),
				'type'        => 'textfield',
				'param_name'  => 'letter_spacing',
				'value'       => '',
			)
		);
		vc_add_param(
			'vc_custom_heading', array(
				'heading'     => esc_html__( 'Font Weight', 'supro' ),
				'description' => esc_html__( 'Enter font weight', 'supro' ),
				'type'        => 'textfield',
				'param_name'  => 'font_weight',
				'value'       => '',
				'dependency'  => array(
					'element' => 'use_theme_fonts',
					'value'   => 'yes',
				),
			)
		);

		// Responsive Custom Header element
		vc_add_param(
			'vc_custom_heading', array(
				'type'             => 'supro_heading',
				'param_name'       => 't_supro_heading',
				'value'            => esc_html__( 'Tablet', 'supro' ),
				'edit_field_class' => 'vc_col-xs-6',
				'group'            => esc_html__( 'Responsive', 'supro' ),
			)
		);
		vc_add_param(
			'vc_custom_heading', array(
				'type'             => 'supro_heading',
				'param_name'       => 'm_supro_heading',
				'value'            => esc_html__( 'Mobile', 'supro' ),
				'edit_field_class' => 'vc_col-xs-6',
				'group'            => esc_html__( 'Responsive', 'supro' ),
			)
		);
		vc_add_param(
			'vc_custom_heading', array(
				'heading'          => esc_html__( 'Font Size', 'supro' ),
				'description'      => esc_html__( 'Enter letter font size', 'supro' ),
				'type'             => 'textfield',
				'param_name'       => 't_font_size',
				'value'            => '',
				'edit_field_class' => 'vc_col-xs-6',
				'group'            => esc_html__( 'Responsive', 'supro' ),
			)
		);
		vc_add_param(
			'vc_custom_heading', array(
				'heading'          => esc_html__( 'Font Size', 'supro' ),
				'description'      => esc_html__( 'Enter letter font size', 'supro' ),
				'type'             => 'textfield',
				'param_name'       => 'm_font_size',
				'value'            => '',
				'edit_field_class' => 'vc_col-xs-6',
				'group'            => esc_html__( 'Responsive', 'supro' ),
			)
		);
		vc_add_param(
			'vc_custom_heading', array(
				'heading'          => esc_html__( 'Line Height', 'supro' ),
				'description'      => esc_html__( 'Enter line height', 'supro' ),
				'type'             => 'textfield',
				'param_name'       => 't_line_height',
				'value'            => '',
				'edit_field_class' => 'vc_col-xs-6',
				'group'            => esc_html__( 'Responsive', 'supro' ),
			)
		);
		vc_add_param(
			'vc_custom_heading', array(
				'heading'          => esc_html__( 'Line Height', 'supro' ),
				'description'      => esc_html__( 'Enter line height', 'supro' ),
				'type'             => 'textfield',
				'param_name'       => 'm_line_height',
				'value'            => '',
				'edit_field_class' => 'vc_col-xs-6',
				'group'            => esc_html__( 'Responsive', 'supro' ),
			)
		);
	}

	/**
	 * Add new params or add new shortcode to VC
	 *
	 * @since 1.0
	 *
	 * @return void
	 */
	function map_shortcodes() {

		vc_remove_param( 'vc_row', 'parallax_image' );
		vc_remove_param( 'vc_row', 'parallax' );
		vc_remove_param( 'vc_row', 'parallax_speed_bg' );

		$attributes = array(
			array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Enable Parallax effect', 'supro' ),
				'param_name'  => 'enable_parallax',
				'group'       => esc_html__( 'Design Options', 'supro' ),
				'value'       => array( esc_html__( 'Enable', 'supro' ) => 'yes' ),
				'description' => esc_html__( 'Enable this option if you want to have parallax effect on this row. When you enable this option, please set background repeat option as "Theme defaults" to make it works.', 'supro' ),
			),
			array(
				'type'        => 'colorpicker',
				'heading'     => esc_html__( 'Overlay', 'supro' ),
				'param_name'  => 'overlay',
				'group'       => esc_html__( 'Design Options', 'supro' ),
				'value'       => '',
				'description' => esc_html__( 'Select an overlay color for this row', 'supro' ),
			),
		);

		vc_add_params( 'vc_row', $attributes );

		// Empty Space
		vc_map(
			array(
				'name'     => esc_html__( 'Supro Empty Space', 'supro' ),
				'base'     => 'supro_empty_space',
				'class'    => '',
				'category' => esc_html__( 'Supro', 'supro' ),
				'params'   => array(
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Height(px)', 'supro' ),
						'param_name'  => 'height',
						'admin_label' => true,
						'description' => esc_html__( 'Enter empty space height on Desktop.', 'supro' )
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Height on Tablet(px)', 'supro' ),
						'param_name'  => 'height_tablet',
						'admin_label' => true,
						'description' => esc_html__( 'Enter empty space height on Mobile. Leave empty to use the height of the desktop', 'supro' )
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Height on Mobile(px)', 'supro' ),
						'param_name'  => 'height_mobile',
						'admin_label' => true,
						'description' => esc_html__( 'Enter empty space height on Mobile. Leave empty to use the height of the tablet', 'supro' )
					),
					array(
						'type'       => 'colorpicker',
						'heading'    => esc_html__( 'Background Color', 'supro' ),
						'param_name' => 'bg_color',
						'value'      => '',
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'supro' ),
						'param_name'  => 'el_class',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'supro' ),
					),
				),
			)
		);

		// Button
		vc_map(
			array(
				'name'     => esc_html__( 'Supro Button', 'supro' ),
				'base'     => 'supro_button',
				'class'    => '',
				'category' => esc_html__( 'Supro', 'supro' ),
				'params'   => array(
					array(
						'heading'    => esc_html__( 'URL (Link)', 'supro' ),
						'type'       => 'vc_link',
						'param_name' => 'link',
					),
					array(
						'heading'    => esc_html__( 'Color', 'supro' ),
						'param_name' => 'color',
						'type'       => 'dropdown',
						'value'      => array(
							esc_html__( 'Dark', 'supro' )  => 'dark',
							esc_html__( 'Light', 'supro' ) => 'light',
						),
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Font Size', 'supro' ),
						'param_name'  => 'font_size',
						'value'       => '',
						'description' => esc_html__( 'Enter button font size. Leave empty to use default', 'supro' )
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Line Height', 'supro' ),
						'param_name'  => 'line_height',
						'description' => esc_html__( 'Enter button line height. Leave empty to use default', 'supro' ),
					),
					array(
						'heading'     => esc_html__( 'Alignment', 'supro' ),
						'description' => esc_html__( 'Select button alignment', 'supro' ),
						'param_name'  => 'align',
						'type'        => 'dropdown',
						'value'       => array(
							esc_html__( 'Left', 'supro' )   => 'left',
							esc_html__( 'Center', 'supro' ) => 'center',
							esc_html__( 'Right', 'supro' )  => 'right',
						),
					),
					array(
						'heading'     => esc_html__( 'Style', 'supro' ),
						'description' => esc_html__( 'Select button style', 'supro' ),
						'param_name'  => 'style',
						'type'        => 'dropdown',
						'value'       => array(
							esc_html__( 'Flat', 'supro' )               => 'flat',
							esc_html__( 'Border Bottom Only', 'supro' ) => 'border-bottom',
						),
					),
					vc_map_add_css_animation(),
					array(
						'heading'     => esc_html__( 'Extra class name', 'supro' ),
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'supro' ),
						'param_name'  => 'el_class',
						'type'        => 'textfield',
						'value'       => '',
					),

					// Responsive
					array(
						'type'             => 'supro_heading',
						'param_name'       => 't_supro_heading',
						'value'            => esc_html__( 'Tablet', 'supro' ),
						'edit_field_class' => 'vc_col-xs-6',
						'group'            => esc_html__( 'Responsive', 'supro' ),
					),
					array(
						'type'             => 'supro_heading',
						'param_name'       => 'm_supro_heading',
						'value'            => esc_html__( 'Mobile', 'supro' ),
						'edit_field_class' => 'vc_col-xs-6',
						'group'            => esc_html__( 'Responsive', 'supro' ),
					),
					array(
						'heading'          => esc_html__( 'Font Size', 'supro' ),
						'description'      => esc_html__( 'Enter letter font size', 'supro' ),
						'type'             => 'textfield',
						'param_name'       => 't_font_size',
						'value'            => '',
						'edit_field_class' => 'vc_col-xs-6',
						'group'            => esc_html__( 'Responsive', 'supro' ),
					),
					array(
						'heading'          => esc_html__( 'Font Size', 'supro' ),
						'description'      => esc_html__( 'Enter letter font size', 'supro' ),
						'type'             => 'textfield',
						'param_name'       => 'm_font_size',
						'value'            => '',
						'edit_field_class' => 'vc_col-xs-6',
						'group'            => esc_html__( 'Responsive', 'supro' ),
					),
					array(
						'heading'          => esc_html__( 'Line Height', 'supro' ),
						'description'      => esc_html__( 'Enter line height', 'supro' ),
						'type'             => 'textfield',
						'param_name'       => 't_line_height',
						'value'            => '',
						'edit_field_class' => 'vc_col-xs-6',
						'group'            => esc_html__( 'Responsive', 'supro' ),
					),
					array(
						'heading'          => esc_html__( 'Line Height', 'supro' ),
						'description'      => esc_html__( 'Enter line height', 'supro' ),
						'type'             => 'textfield',
						'param_name'       => 'm_line_height',
						'value'            => '',
						'edit_field_class' => 'vc_col-xs-6',
						'group'            => esc_html__( 'Responsive', 'supro' ),
					),
					array(
						'heading'          => esc_html__( 'Alignment', 'supro' ),
						'description'      => esc_html__( 'Select button alignment', 'supro' ),
						'param_name'       => 't_align',
						'std'              => 'inherit',
						'type'             => 'dropdown',
						'value'            => array(
							esc_html__( 'Inherit', 'supro' ) => 'inherit',
							esc_html__( 'Left', 'supro' )    => 'left',
							esc_html__( 'Center', 'supro' )  => 'center',
							esc_html__( 'Right', 'supro' )   => 'right',
						),
						'edit_field_class' => 'vc_col-xs-6',
						'group'            => esc_html__( 'Responsive', 'supro' ),
					),
					array(
						'heading'          => esc_html__( 'Alignment', 'supro' ),
						'description'      => esc_html__( 'Select button alignment', 'supro' ),
						'param_name'       => 'm_align',
						'std'              => 'inherit',
						'type'             => 'dropdown',
						'value'            => array(
							esc_html__( 'Inherit', 'supro' ) => 'inherit',
							esc_html__( 'Left', 'supro' )    => 'left',
							esc_html__( 'Center', 'supro' )  => 'center',
							esc_html__( 'Right', 'supro' )   => 'right',
						),
						'edit_field_class' => 'vc_col-xs-6',
						'group'            => esc_html__( 'Responsive', 'supro' ),
					),
				),
			)
		);

		// Add custom single image
		vc_map(
			array(
				'name'     => esc_html__( 'Supro Single Image', 'supro' ),
				'base'     => 'supro_single_image',
				'class'    => '',
				'category' => esc_html__( 'Supro', 'supro' ),
				'params'   => array(
					array(
						'type'        => 'attach_image',
						'heading'     => esc_html__( 'Image', 'supro' ),
						'param_name'  => 'image',
						'value'       => '',
						'description' => esc_html__( 'Select an image from media library', 'supro' ),
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Image size', 'supro' ),
						'param_name'  => 'image_size',
						'value'       => '',
						'description' => esc_html__( 'Enter image size (Example: "thumbnail", "medium", "large", "full" or other sizes defined by theme). Alternatively enter size in pixels (Example: 200x100 (Width x Height)).', 'supro' )
					),
					array(
						'heading'     => esc_html__( 'Alignment', 'supro' ),
						'description' => esc_html__( 'Select image alignment', 'supro' ),
						'param_name'  => 'align',
						'type'        => 'dropdown',
						'value'       => array(
							esc_html__( 'Left', 'supro' )   => 'left',
							esc_html__( 'Center', 'supro' ) => 'center',
							esc_html__( 'Right', 'supro' )  => 'right',
						),
					),
					vc_map_add_css_animation(),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'supro' ),
						'param_name'  => 'el_class',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'supro' ),
					),
				),
			)
		);

		vc_map(
			array(
				'name'     => esc_html__( 'Icons Box', 'supro' ),
				'base'     => 'supro_icons_box',
				'class'    => '',
				'category' => esc_html__( 'Supro', 'supro' ),
				'params'   => array(
					array(
						'type'       => 'checkbox',
						'heading'    => esc_html__( 'Box Shadow Effect', 'supro' ),
						'param_name' => 'box_shadow',
						'value'      => array( esc_html__( 'Yes', 'supro' ) => '1' ),
					),
					array(
						'type'        => 'checkbox',
						'heading'     => esc_html__( 'No Space', 'supro' ),
						'description' => esc_html__( 'Remove padding left and right.', 'supro' ),
						'param_name'  => 'space',
						'value'       => array( esc_html__( 'Yes', 'supro' ) => '1' ),
					),
					array(
						'heading'    => esc_html__( 'Icons', 'supro' ),
						'type'       => 'param_group',
						'value'      => '',
						'param_name' => 'icons',
						'params'     => array(
							array(
								'heading'     => esc_html__( 'Icon library', 'supro' ),
								'description' => esc_html__( 'Select icon library.', 'supro' ),
								'param_name'  => 'icon_type',
								'type'        => 'dropdown',
								'value'       => array(
									esc_html__( 'LinearIcons', 'supro' ) => 'linearicons',
									esc_html__( 'IonIcons', 'supro' )    => 'ionicons',
								),
							),
							array(
								'heading'     => esc_html__( 'Icon', 'supro' ),
								'description' => esc_html__( 'Select icon from library.', 'supro' ),
								'type'        => 'iconpicker',
								'param_name'  => 'icon_linearicons',
								'value'       => '',
								'settings'    => array(
									'emptyIcon'    => false,
									'iconsPerPage' => 4000,
									'type'         => 'linearicons',
								),
								'dependency'  => array(
									'element' => 'icon_type',
									'value'   => 'linearicons',
								),
							),
							array(
								'heading'     => esc_html__( 'Icon', 'supro' ),
								'description' => esc_html__( 'Select icon from library.', 'supro' ),
								'type'        => 'iconpicker',
								'param_name'  => 'icon_ionicons',
								'value'       => '',
								'settings'    => array(
									'emptyIcon'    => false,
									'iconsPerPage' => 4000,
									'type'         => 'ionicons',
								),
								'dependency'  => array(
									'element' => 'icon_type',
									'value'   => 'ionicons',
								),
							),
							array(
								'type'        => 'textfield',
								'heading'     => esc_html__( 'Title', 'supro' ),
								'param_name'  => 'title',
								'value'       => '',
								'admin_label' => true,
							),
							array(
								'type'       => 'textarea',
								'heading'    => esc_html__( 'Description', 'supro' ),
								'param_name' => 'desc',
								'value'      => '',
							),
							array(
								'type'       => 'vc_link',
								'value'      => '',
								'heading'    => esc_html__( 'Link', 'supro' ),
								'param_name' => 'link',
							),
						),
					),
					vc_map_add_css_animation(),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'supro' ),
						'param_name'  => 'el_class',
						'value'       => '',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'supro' ),
					),
				),
			)
		);

		// Images Box
		vc_map(
			array(
				'name'     => esc_html__( 'Images Box', 'supro' ),
				'base'     => 'supro_images_box',
				'class'    => '',
				'category' => esc_html__( 'Supro', 'supro' ),
				'params'   => array(
					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Type', 'supro' ),
						'param_name' => 'type',
						'value'      => array(
							esc_html__( 'Carousel', 'supro' ) => 'carousel',
							esc_html__( 'Grid', 'supro' )     => 'grid',
						),
					),
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Min Height (px)', 'supro' ),
						'param_name' => 'height',
						'value'      => '300',
						'dependency' => array(
							'element' => 'type',
							'value'   => 'carousel',
						),
					),
					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Columns', 'supro' ),
						'param_name' => 'columns',
						'value'      => array(
							esc_html__( '2 Columns', 'supro' ) => '2',
							esc_html__( '3 Columns', 'supro' ) => '3',
							esc_html__( '4 Columns', 'supro' ) => '4',
						),
						'std'        => '4',
					),

					array(
						'heading'    => esc_html__( 'Box', 'supro' ),
						'type'       => 'param_group',
						'value'      => '',
						'param_name' => 'box_option',
						'params'     => array(
							array(
								'type'        => 'attach_image',
								'heading'     => esc_html__( 'Image', 'supro' ),
								'param_name'  => 'image',
								'value'       => '',
								'description' => esc_html__( 'Choose images from media library', 'supro' ),
							),
							array(
								'type'        => 'textfield',
								'heading'     => esc_html__( 'Image size', 'supro' ),
								'param_name'  => 'image_size',
								'description' => esc_html__( 'Enter image size', 'supro' ),
							),
							array(
								'type'        => 'textarea',
								'heading'     => esc_html__( 'Title', 'supro' ),
								'param_name'  => 'title',
								'value'       => '',
								'admin_label' => true,
							),
							array(
								'type'       => 'textfield',
								'heading'    => esc_html__( 'Subtitle', 'supro' ),
								'param_name' => 'subtitle',
								'value'      => '',
							),
							array(
								'type'       => 'vc_link',
								'value'      => '',
								'heading'    => esc_html__( 'Link', 'supro' ),
								'param_name' => 'link',
							),
						),
					),
					vc_map_add_css_animation(),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'supro' ),
						'param_name'  => 'el_class',
						'value'       => '',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'supro' ),
					),

					// Box Settings
					array(
						'type'             => 'checkbox',
						'heading'          => esc_html__( 'Show Nav', 'supro' ),
						'param_name'       => 'nav',
						'value'            => array( esc_html__( 'Yes', 'supro' ) => '1' ),
						'edit_field_class' => 'vc_col-xs-4',
						'dependency'       => array(
							'element' => 'type',
							'value'   => 'carousel',
						),
						'group'            => esc_html__( 'Box Setting', 'supro' ),
					),
					array(
						'type'             => 'checkbox',
						'heading'          => esc_html__( 'Show Dots', 'supro' ),
						'param_name'       => 'dots',
						'value'            => array( esc_html__( 'Yes', 'supro' ) => '1' ),
						'edit_field_class' => 'vc_col-xs-4',
						'dependency'       => array(
							'element' => 'type',
							'value'   => 'carousel',
						),
						'group'            => esc_html__( 'Box Setting', 'supro' ),
					),
					array(
						'heading'          => esc_html__( 'Infinite Loop', 'supro' ),
						'param_name'       => 'infinite',
						'type'             => 'checkbox',
						'value'            => array(
							esc_html__( 'Yes', 'supro' ) => '1',
						),
						'edit_field_class' => 'vc_col-xs-4',
						'dependency'       => array(
							'element' => 'type',
							'value'   => 'carousel',
						),
						'group'            => esc_html__( 'Box Setting', 'supro' ),
					),
					array(
						'type'             => 'checkbox',
						'heading'          => esc_html__( 'Autoplay', 'supro' ),
						'param_name'       => 'autoplay',
						'value'            => array( esc_html__( 'Yes', 'supro' ) => '1' ),
						'edit_field_class' => 'vc_col-xs-6',
						'dependency'       => array(
							'element' => 'type',
							'value'   => 'carousel',
						),
						'group'            => esc_html__( 'Box Setting', 'supro' ),
					),
					array(
						'type'             => 'textfield',
						'heading'          => esc_html__( 'Autoplay Speed', 'supro' ),
						'param_name'       => 'speed',
						'value'            => '2000',
						'edit_field_class' => 'vc_col-xs-6',
						'dependency'       => array(
							'element' => 'type',
							'value'   => 'carousel',
						),
						'group'            => esc_html__( 'Box Setting', 'supro' ),
					),
				),
			)
		);

		// Product Grid
		vc_map(
			array(
				'name'     => esc_html__( 'Supro Products', 'supro' ),
				'base'     => 'supro_products',
				'class'    => '',
				'category' => esc_html__( 'Supro', 'supro' ),
				'params'   => array(
					array(
						'heading'     => esc_html__( 'Style', 'supro' ),
						'param_name'  => 'style',
						'type'        => 'dropdown',
						'value'       => array(
							esc_html__( 'Style 1', 'supro' ) => '1',
							esc_html__( 'Style 2', 'supro' ) => '2',
							esc_html__( 'Style 3', 'supro' ) => '3',
							esc_html__( 'Style 4', 'supro' ) => '4',
						),
						'description' => esc_html__( 'Select style for shortcode', 'supro' ),
					),
					array(
						'heading'          => esc_html__( 'Number Of Products', 'supro' ),
						'param_name'       => 'limit',
						'type'             => 'textfield',
						'value'            => 6,
						'description'      => esc_html__( 'Total number of products will be display in single tab', 'supro' ),
						'edit_field_class' => 'vc_col-xs-6',
					),
					array(
						'heading'          => esc_html__( 'Columns', 'supro' ),
						'param_name'       => 'columns',
						'type'             => 'dropdown',
						'value'            => array(
							esc_html__( '3 Columns', 'supro' ) => 3,
							esc_html__( '4 Columns', 'supro' ) => 4,
							esc_html__( '5 Columns', 'supro' ) => 5,
						),
						'description'      => esc_html__( 'Display products in how many columns', 'supro' ),
						'edit_field_class' => 'vc_col-xs-6',
					),
					array(
						'heading'          => esc_html__( 'Order By', 'supro' ),
						'param_name'       => 'orderby',
						'type'             => 'dropdown',
						'value'            => array(
							esc_html__( 'Title', 'supro' )      => 'title',
							esc_html__( 'Date', 'supro' )       => 'date',
							esc_html__( 'ID', 'supro' )         => 'id',
							esc_html__( 'Menu Order', 'supro' ) => 'menu_order',
							esc_html__( 'Random', 'supro' )     => 'rand',
						),
						'description'      => esc_html__( 'Select to order products.', 'supro' ),
						'edit_field_class' => 'vc_col-xs-6',
						'dependency'       => array(
							'element' => 'filter',
							'value'   => 'category',
						),
					),
					array(
						'heading'          => esc_html__( 'Order', 'supro' ),
						'param_name'       => 'order',
						'type'             => 'dropdown',
						'value'            => array(
							esc_html__( 'Ascending', 'supro' )  => 'ASC',
							esc_html__( 'Descending', 'supro' ) => 'DESC',
						),
						'description'      => esc_html__( 'Select to sort products', 'supro' ),
						'edit_field_class' => 'vc_col-xs-6',
						'dependency'       => array(
							'element' => 'filter',
							'value'   => 'category',
						),
					),
					array(
						'heading'     => esc_html__( 'Tabs', 'supro' ),
						'description' => esc_html__( 'Select how to filter products.', 'supro' ),
						'param_name'  => 'filter',
						'type'        => 'dropdown',
						'value'       => array(
							esc_html__( 'Filter by category', 'supro' ) => 'category',
							esc_html__( 'Filter by feature', 'supro' )  => 'group',
						),
					),
					array(
						'heading'          => esc_html__( 'Show "All products" item', 'supro' ),
						'param_name'       => 'show_all_product',
						'type'             => 'checkbox',
						'value'            => array(
							esc_html__( 'Yes', 'supro' ) => '1',
						),
						'std'              => '1',
						'dependency'       => array(
							'element' => 'filter',
							'value'   => 'category',
						),
						'edit_field_class' => 'vc_col-xs-6',
					),
					array(
						'heading'          => esc_html__( '"All products" item text', 'supro' ),
						'param_name'       => 'all_product_text',
						'type'             => 'textfield',
						'value'            => esc_html__( 'All Products', 'supro' ),
						'dependency'       => array(
							'element' => 'filter',
							'value'   => 'category',
						),
						'edit_field_class' => 'vc_col-xs-6',
					),
					array(
						'heading'     => esc_html__( 'Categories', 'supro' ),
						'description' => esc_html__( 'Select what categories you want to use. Leave it empty to use all categories.', 'supro' ),
						'param_name'  => 'category',
						'type'        => 'autocomplete',
						'value'       => '',
						'settings'    => array(
							'multiple' => true,
							'sortable' => true,
							'values'   => $this->get_terms(),
						),
					),
					array(
						'heading'    => esc_html__( 'Tabs Setting', 'supro' ),
						'type'       => 'param_group',
						'value'      => '',
						'param_name' => 'tabs',
						'params'     => array(
							array(
								'type'        => 'textfield',
								'heading'     => esc_html__( 'Title', 'supro' ),
								'param_name'  => 'title',
								'value'       => '',
								'admin_label' => true,
							),
							array(
								'type'       => 'dropdown',
								'heading'    => esc_html__( 'Products', 'supro' ),
								'param_name' => 'products',
								'value'      => array(
									esc_html__( 'New Products', 'supro' )          => 'recent_products',
									esc_html__( 'Featured Products', 'supro' )     => 'featured_products',
									esc_html__( 'Best Selling Products', 'supro' ) => 'best_selling_products',
									esc_html__( 'Sale Products', 'supro' )         => 'sale_products',
									esc_html__( 'Top Rated Products', 'supro' )    => 'top_rated_products',
								),
							),
							array(
								'heading'          => esc_html__( 'Order By', 'supro' ),
								'param_name'       => 'orderby',
								'type'             => 'dropdown',
								'value'            => array(
									esc_html__( 'Date', 'supro' )       => 'date',
									esc_html__( 'Title', 'supro' )      => 'title',
									esc_html__( 'ID', 'supro' )         => 'id',
									esc_html__( 'Menu Order', 'supro' ) => 'menu_order',
									esc_html__( 'Random', 'supro' )     => 'rand',
								),
								'description'      => esc_html__( 'Select to order products.', 'supro' ),
								'edit_field_class' => 'vc_col-xs-6',
							),
							array(
								'heading'          => esc_html__( 'Order', 'supro' ),
								'param_name'       => 'order',
								'type'             => 'dropdown',
								'value'            => array(
									esc_html__( 'Descending', 'supro' ) => 'DESC',
									esc_html__( 'Ascending', 'supro' )  => 'ASC',
								),
								'description'      => esc_html__( 'Select to sort products', 'supro' ),
								'edit_field_class' => 'vc_col-xs-6',
							),
						),
						'dependency' => array(
							'element' => 'filter',
							'value'   => 'group',
						),
					),
					array(
						'type'        => 'vc_link',
						'heading'     => esc_html__( 'Link', 'supro' ),
						'param_name'  => 'link',
						'description' => esc_html__( 'Link to Products Page', 'supro' ),
						'dependency'  => array(
							'element' => 'style',
							'value'   => '3',
						),
					),
					array(
						'heading'     => esc_html__( 'Load More Button', 'supro' ),
						'description' => esc_html__( 'Show load more button with ajax loading', 'supro' ),
						'param_name'  => 'load_more',
						'type'        => 'checkbox',
						'value'       => array(
							esc_html__( 'Yes', 'supro' ) => '1',
						),
						'dependency'  => array(
							'element' => 'style',
							'value'   => array( '1', '2', '4' ),
						),
					),
					vc_map_add_css_animation(),
					array(
						'heading'     => esc_html__( 'Extra class name', 'supro' ),
						'param_name'  => 'el_class',
						'type'        => 'textfield',
						'value'       => '',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'supro' ),
					),

					// Title
					array(
						'type'        => 'textarea',
						'heading'     => esc_html__( 'Title', 'supro' ),
						'param_name'  => 'title',
						'value'       => '',
						'admin_label' => true,
						'group'       => esc_html__( 'Title', 'supro' ),
					),
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Subtitle', 'supro' ),
						'param_name' => 'subtitle',
						'value'      => '',
						'group'      => esc_html__( 'Title', 'supro' ),
					),
				),
			)
		);

		// Product Carousel

		vc_map(
			array(
				'name'     => esc_html__( 'Supro Products Carousel', 'supro' ),
				'base'     => 'supro_products_carousel',
				'class'    => '',
				'category' => esc_html__( 'Supro', 'supro' ),
				'params'   => array(
					array(
						'type'        => 'textarea',
						'heading'     => esc_html__( 'Title', 'supro' ),
						'param_name'  => 'title',
						'value'       => '',
						'admin_label' => true,
					),
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Subtitle', 'supro' ),
						'param_name' => 'subtitle',
						'value'      => '',
					),
					array(
						'heading'     => esc_html__( 'Style', 'supro' ),
						'param_name'  => 'style',
						'type'        => 'dropdown',
						'value'       => array(
							esc_html__( 'Style 1', 'supro' ) => '1',
							esc_html__( 'Style 2', 'supro' ) => '2',
						),
						'description' => esc_html__( 'Select style for shortcode', 'supro' ),
					),
					array(
						'heading'          => esc_html__( 'Number Of Products', 'supro' ),
						'param_name'       => 'limit',
						'type'             => 'textfield',
						'value'            => 6,
						'description'      => esc_html__( 'Total number of products will be display in single tab', 'supro' ),
						'edit_field_class' => 'vc_col-xs-6',
					),
					array(
						'heading'          => esc_html__( 'Columns', 'supro' ),
						'param_name'       => 'columns',
						'type'             => 'dropdown',
						'value'            => array(
							esc_html__( '3 Columns', 'supro' ) => 3,
							esc_html__( '4 Columns', 'supro' ) => 4,
							esc_html__( '5 Columns', 'supro' ) => 5,
						),
						'description'      => esc_html__( 'Display products in how many columns', 'supro' ),
						'edit_field_class' => 'vc_col-xs-6',
					),
					array(
						'heading'          => esc_html__( 'Order By', 'supro' ),
						'param_name'       => 'orderby',
						'type'             => 'dropdown',
						'value'            => array(
							esc_html__( 'Title', 'supro' )      => 'title',
							esc_html__( 'Date', 'supro' )       => 'date',
							esc_html__( 'ID', 'supro' )         => 'id',
							esc_html__( 'Menu Order', 'supro' ) => 'menu_order',
							esc_html__( 'Random', 'supro' )     => 'rand',
						),
						'description'      => esc_html__( 'Select to order products.', 'supro' ),
						'edit_field_class' => 'vc_col-xs-6',
						'dependency'       => array(
							'element' => 'filter',
							'value'   => 'category',
						),
					),
					array(
						'heading'          => esc_html__( 'Order', 'supro' ),
						'param_name'       => 'order',
						'type'             => 'dropdown',
						'value'            => array(
							esc_html__( 'Ascending', 'supro' )  => 'ASC',
							esc_html__( 'Descending', 'supro' ) => 'DESC',
						),
						'description'      => esc_html__( 'Select to sort products', 'supro' ),
						'edit_field_class' => 'vc_col-xs-6',
						'dependency'       => array(
							'element' => 'filter',
							'value'   => 'category',
						),
					),
					array(
						'heading'     => esc_html__( 'Tabs', 'supro' ),
						'description' => esc_html__( 'Select how to filter products.', 'supro' ),
						'param_name'  => 'filter',
						'type'        => 'dropdown',
						'value'       => array(
							esc_html__( 'Filter by category', 'supro' ) => 'category',
							esc_html__( 'Filter by feature', 'supro' )  => 'group',
						),
					),
					array(
						'heading'          => esc_html__( 'Show "All products" item', 'supro' ),
						'param_name'       => 'show_all_product',
						'type'             => 'checkbox',
						'value'            => array(
							esc_html__( 'Yes', 'supro' ) => '1',
						),
						'std'              => '1',
						'dependency'       => array(
							'element' => 'filter',
							'value'   => 'category',
						),
						'edit_field_class' => 'vc_col-xs-6',
					),
					array(
						'heading'          => esc_html__( '"All products" item text', 'supro' ),
						'param_name'       => 'all_product_text',
						'type'             => 'textfield',
						'value'            => esc_html__( 'All Products', 'supro' ),
						'dependency'       => array(
							'element' => 'filter',
							'value'   => 'category',
						),
						'edit_field_class' => 'vc_col-xs-6',
					),
					array(
						'heading'     => esc_html__( 'Categories', 'supro' ),
						'description' => esc_html__( 'Select what categories you want to use. Leave it empty to use all categories.', 'supro' ),
						'param_name'  => 'category',
						'type'        => 'autocomplete',
						'value'       => '',
						'settings'    => array(
							'multiple' => true,
							'sortable' => true,
							'values'   => $this->get_terms(),
						),
					),
					array(
						'heading'    => esc_html__( 'Tabs Setting', 'supro' ),
						'type'       => 'param_group',
						'value'      => '',
						'param_name' => 'tabs',
						'params'     => array(
							array(
								'type'        => 'textfield',
								'heading'     => esc_html__( 'Title', 'supro' ),
								'param_name'  => 'title',
								'value'       => '',
								'admin_label' => true,
							),
							array(
								'type'       => 'dropdown',
								'heading'    => esc_html__( 'Products', 'supro' ),
								'param_name' => 'products',
								'value'      => array(
									esc_html__( 'New Products', 'supro' )          => 'recent_products',
									esc_html__( 'Featured Products', 'supro' )     => 'featured_products',
									esc_html__( 'Best Selling Products', 'supro' ) => 'best_selling_products',
									esc_html__( 'Sale Products', 'supro' )         => 'sale_products',
									esc_html__( 'Top Rated Products', 'supro' )    => 'top_rated_products',
								),
							),
							array(
								'heading'          => esc_html__( 'Order By', 'supro' ),
								'param_name'       => 'orderby',
								'type'             => 'dropdown',
								'value'            => array(
									esc_html__( 'Date', 'supro' )       => 'date',
									esc_html__( 'Title', 'supro' )      => 'title',
									esc_html__( 'ID', 'supro' )         => 'id',
									esc_html__( 'Menu Order', 'supro' ) => 'menu_order',
									esc_html__( 'Random', 'supro' )     => 'rand',
								),
								'description'      => esc_html__( 'Select to order products.', 'supro' ),
								'edit_field_class' => 'vc_col-xs-6',
							),
							array(
								'heading'          => esc_html__( 'Order', 'supro' ),
								'param_name'       => 'order',
								'type'             => 'dropdown',
								'value'            => array(
									esc_html__( 'Descending', 'supro' ) => 'DESC',
									esc_html__( 'Ascending', 'supro' )  => 'ASC',
								),
								'description'      => esc_html__( 'Select to sort products', 'supro' ),
								'edit_field_class' => 'vc_col-xs-6',
							),
						),
						'dependency' => array(
							'element' => 'filter',
							'value'   => 'group',
						),
					),
					vc_map_add_css_animation(),
					array(
						'heading'     => esc_html__( 'Extra class name', 'supro' ),
						'param_name'  => 'el_class',
						'type'        => 'textfield',
						'value'       => '',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'supro' ),
					),

					// Slide Option
					array(
						'type'             => 'checkbox',
						'heading'          => esc_html__( 'Show Nav', 'supro' ),
						'param_name'       => 'nav',
						'value'            => array( esc_html__( 'Yes', 'supro' ) => '1' ),
						'edit_field_class' => 'vc_col-xs-4',
						'group'            => esc_html__( 'Slide Option', 'supro' ),
					),
					array(
						'type'             => 'checkbox',
						'heading'          => esc_html__( 'Show Dots', 'supro' ),
						'param_name'       => 'dots',
						'value'            => array( esc_html__( 'Yes', 'supro' ) => '1' ),
						'edit_field_class' => 'vc_col-xs-4',
						'group'            => esc_html__( 'Slide Option', 'supro' ),
					),
					array(
						'heading'          => esc_html__( 'Infinite Loop', 'supro' ),
						'param_name'       => 'infinite',
						'type'             => 'checkbox',
						'value'            => array(
							esc_html__( 'Yes', 'supro' ) => '1',
						),
						'edit_field_class' => 'vc_col-xs-4',
						'group'            => esc_html__( 'Slide Option', 'supro' ),
					),
					array(
						'type'             => 'checkbox',
						'heading'          => esc_html__( 'Autoplay', 'supro' ),
						'param_name'       => 'autoplay',
						'value'            => array( esc_html__( 'Yes', 'supro' ) => '1' ),
						'edit_field_class' => 'vc_col-xs-4',
						'group'            => esc_html__( 'Slide Option', 'supro' ),
					),
					array(
						'type'             => 'textfield',
						'heading'          => esc_html__( 'Autoplay Speed', 'supro' ),
						'param_name'       => 'autoplay_speed',
						'value'            => 2000,
						'description'      => esc_html__( 'Autoplay Speed in milliseconds', 'supro' ),
						'edit_field_class' => 'vc_col-xs-4',
						'group'            => esc_html__( 'Slide Option', 'supro' ),
					),
					array(
						'type'             => 'textfield',
						'heading'          => esc_html__( 'Speed( ms )', 'supro' ),
						'param_name'       => 'speed',
						'value'            => 1000,
						'description'      => esc_html__( 'Slide / Fade animation speed', 'supro' ),
						'edit_field_class' => 'vc_col-xs-4',
						'group'            => esc_html__( 'Slide Option', 'supro' ),
					),
					array(
						'type'             => 'textfield',
						'heading'          => esc_html__( 'Slide to show', 'supro' ),
						'param_name'       => 'slide_to_show',
						'value'            => 4,
						'description'      => esc_html__( 'Number of slides to show', 'supro' ),
						'edit_field_class' => 'vc_col-xs-6',
						'group'            => esc_html__( 'Slide Option', 'supro' ),
					),
					array(
						'type'             => 'textfield',
						'heading'          => esc_html__( 'Slide to scroll', 'supro' ),
						'param_name'       => 'slide_to_scroll',
						'value'            => 1,
						'description'      => esc_html__( 'Number of slides to scroll', 'supro' ),
						'edit_field_class' => 'vc_col-xs-6',
						'group'            => esc_html__( 'Slide Option', 'supro' ),
					),
				),
			)
		);

		// Supro Banner
		vc_map(
			array(
				'name'     => esc_html__( 'Supro Banner Grid', 'supro' ),
				'base'     => 'supro_banner',
				'class'    => '',
				'category' => esc_html__( 'Supro', 'supro' ),
				'params'   => array(
					// Banner
					array(
						'heading'    => esc_html__( 'Banner Style', 'supro' ),
						'param_name' => 'style',
						'type'       => 'dropdown',
						'std'        => '1',
						'value'      => array(
							esc_html__( 'Style 1', 'supro' ) => '1',
							esc_html__( 'Style 2', 'supro' ) => '2',
							esc_html__( 'Style 3', 'supro' ) => '3',
						),
					),
					array(
						'type'        => 'attach_image',
						'heading'     => esc_html__( 'Image', 'supro' ),
						'param_name'  => 'image',
						'value'       => '',
						'description' => esc_html__( 'Banner Image. Select an image from media library', 'supro' ),
					),
					array(
						'heading'    => esc_html__( 'Text Align', 'supro' ),
						'param_name' => 'text_align',
						'type'       => 'dropdown',
						'value'      => array(
							esc_html__( 'Left', 'supro' )   => 'left',
							esc_html__( 'Center', 'supro' ) => 'center',
							esc_html__( 'Right', 'supro' )  => 'right',
						),
					),
					array(
						'heading'    => esc_html__( 'Link( URL )', 'supro' ),
						'type'       => 'vc_link',
						'param_name' => 'link',
					),
					array(
						'heading'    => esc_html__( 'Button Style', 'supro' ),
						'param_name' => 'btn_style',
						'type'       => 'dropdown',
						'value'      => array(
							esc_html__( 'Border Bottom', 'supro' )  => '1',
							esc_html__( 'Has Background', 'supro' ) => '2',
						),
					),
					array(
						'type'        => 'colorpicker',
						'heading'     => esc_html__( 'Button Color', 'supro' ),
						'param_name'  => 'btn_color',
						'description' => esc_html__( 'Enter button color', 'supro' ),
						'value'       => '',
					),
					array(
						'type'        => 'colorpicker',
						'heading'     => esc_html__( 'Button Background Color', 'supro' ),
						'param_name'  => 'btn_background_color',
						'description' => esc_html__( 'Enter button background color', 'supro' ),
						'value'       => '',
						'dependency'  => array(
							'element' => 'btn_style',
							'value'   => '2',
						),
					),
					array(
						'heading'    => esc_html__( 'Banner Content Position', 'supro' ),
						'param_name' => 'position',
						'type'       => 'dropdown',
						'std'        => 'top-left',
						'value'      => array(
							esc_html__( 'Top Left', 'supro' )      => 'top-left',
							esc_html__( 'Top Center', 'supro' )    => 'top-center',
							esc_html__( 'Top Right', 'supro' )     => 'top-right',
							esc_html__( 'Center Left', 'supro' )   => 'center-left',
							esc_html__( 'Center Center', 'supro' ) => 'center-center',
							esc_html__( 'Center Right', 'supro' )  => 'center-right',
							esc_html__( 'Bottom Left', 'supro' )   => 'bottom-left',
							esc_html__( 'Bottom Center', 'supro' ) => 'bottom-center',
							esc_html__( 'Bottom Right', 'supro' )  => 'bottom-right',
						),
					),
					array(
						'heading'          => esc_html__( 'Top', 'supro' ),
						'description'      => esc_html__( 'Enter content top position . Exp: 50px, 50 %, 50em, etc . ', 'supro' ),
						'param_name'       => 'top',
						'edit_field_class' => 'vc_col-xs-3',
						'type'             => 'textfield',
						'value'            => '',
						'dependency'       => array(
							'element' => 'position',
							'value'   => array( 'top-left', 'top-right', 'top-center' ),
						),
					),
					array(
						'heading'          => esc_html__( 'Right', 'supro' ),
						'description'      => esc_html__( 'Enter right top position . Exp: 50px, 50 %, 50em, etc . ', 'supro' ),
						'param_name'       => 'right',
						'edit_field_class' => 'vc_col-xs-3',
						'type'             => 'textfield',
						'value'            => '',
						'dependency'       => array(
							'element' => 'position',
							'value'   => array( 'top-right', 'center-right', 'bottom-right' ),
						),
					),
					array(
						'heading'          => esc_html__( 'Bottom', 'supro' ),
						'description'      => esc_html__( 'Enter content bottom position . Exp: 50px, 50 %, 50em, etc . ', 'supro' ),
						'param_name'       => 'bottom',
						'edit_field_class' => 'vc_col-xs-3',
						'type'             => 'textfield',
						'value'            => '',
						'dependency'       => array(
							'element' => 'position',
							'value'   => array( 'bottom-left', 'bottom-right', 'bottom-center' ),
						),
					),
					array(
						'heading'          => esc_html__( 'Left', 'supro' ),
						'description'      => esc_html__( 'Enter content left position . Exp: 50px, 50 %, 50em, etc . ', 'supro' ),
						'param_name'       => 'left',
						'edit_field_class' => 'vc_col-xs-3',
						'type'             => 'textfield',
						'value'            => '',
						'dependency'       => array(
							'element' => 'position',
							'value'   => array( 'top-left', 'center-left', 'bottom-left' ),
						),
					),
					array(
						'heading'    => esc_html__( 'Short Description', 'supro' ),
						'type'       => 'textarea_html',
						'param_name' => 'content',
						'dependency' => array(
							'element' => 'style',
							'value'   => '2',
						),
					),
					array(
						'type'       => 'colorpicker',
						'heading'    => esc_html__( 'Content Color', 'supro' ),
						'param_name' => 'content_color',
						'value'      => '',
						'dependency' => array(
							'element' => 'style',
							'value'   => '2',
						),
					),
					vc_map_add_css_animation(),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'supro' ),
						'param_name'  => 'el_class',
						'value'       => '',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file . ', 'supro' ),
					),

					// Banner Title
					array(
						'type'        => 'textarea',
						'heading'     => esc_html__( 'Title', 'supro' ),
						'param_name'  => 'title',
						'value'       => '',
						'admin_label' => true,
						'group'       => esc_html__( 'Banner Title', 'supro' ),
					),
					array(
						'type'        => 'colorpicker',
						'heading'     => esc_html__( 'Color', 'supro' ),
						'param_name'  => 'color',
						'description' => esc_html__( 'Enter color of Title', 'supro' ),
						'value'       => '',
						'group'       => esc_html__( 'Banner Title', 'supro' ),
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Font Weight', 'supro' ),
						'param_name'  => 'font_weight',
						'value'       => '',
						'group'       => esc_html__( 'Banner Title', 'supro' ),
						'description' => esc_html__( 'Enter font weight of Title', 'supro' ),
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Line Height', 'supro' ),
						'param_name'  => 'line_height',
						'value'       => '',
						'group'       => esc_html__( 'Banner Title', 'supro' ),
						'description' => esc_html__( 'Enter line height of Title', 'supro' ),
					),
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Subtitle', 'supro' ),
						'param_name' => 'subtitle',
						'value'      => '',
						'group'      => esc_html__( 'Banner Title', 'supro' ),
					),
					array(
						'type'       => 'colorpicker',
						'heading'    => esc_html__( 'Subtitle Color', 'supro' ),
						'param_name' => 'subtitle_color',
						'value'      => '',
						'group'      => esc_html__( 'Banner Title', 'supro' ),
					),
				),
			)
		);

		// Supro Banner Grid 2
		vc_map(
			array(
				'name'     => esc_html__( 'Supro Banner Grid 2', 'supro' ),
				'base'     => 'supro_banner2',
				'class'    => '',
				'category' => esc_html__( 'Supro', 'supro' ),
				'params'   => array(
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Height', 'supro' ),
						'description' => esc_html__( 'Enter height of the grid', 'supro' ),
						'param_name'  => 'height',
						'value'       => 820,
						'group'       => esc_html__( 'General', 'supro' ),
					),
					array(
						'heading'     => esc_html__( 'Banner gap', 'supro' ),
						'description' => esc_html__( 'Select gap between banners in grid . ', 'supro' ),
						'param_name'  => 'gap',
						'type'        => 'dropdown',
						'value'       => array(
							esc_html__( '0px', 'supro' )  => '0',
							esc_html__( '1px', 'supro' )  => '1',
							esc_html__( '2px', 'supro' )  => '2',
							esc_html__( '3px', 'supro' )  => '3',
							esc_html__( '4px', 'supro' )  => '4',
							esc_html__( '5px', 'supro' )  => '5',
							esc_html__( '10px', 'supro' ) => '10',
							esc_html__( '15px', 'supro' ) => '15',
							esc_html__( '20px', 'supro' ) => '20',
							esc_html__( '25px', 'supro' ) => '25',
							esc_html__( '30px', 'supro' ) => '30',
						),
						'std'         => '10',
						'group'       => esc_html__( 'General', 'supro' ),
					),

					// Banner 1
					array(
						'type'        => 'attach_image',
						'heading'     => esc_html__( 'Image', 'supro' ),
						'param_name'  => 'image1',
						'value'       => '',
						'description' => esc_html__( 'Banner Image . Select an image from media library', 'supro' ),
						'group'       => esc_html__( 'Banner 1', 'supro' ),
					),
					array(
						'type'        => 'textarea',
						'heading'     => esc_html__( 'Title', 'supro' ),
						'param_name'  => 'title1',
						'value'       => '',
						'admin_label' => true,
						'group'       => esc_html__( 'Banner 1', 'supro' ),
					),
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Subtitle', 'supro' ),
						'param_name' => 'subtitle1',
						'value'      => '',
						'group'      => esc_html__( 'Banner 1', 'supro' ),
					),
					array(
						'type'       => 'colorpicker',
						'heading'    => esc_html__( 'Subtitle Color', 'supro' ),
						'param_name' => 'subtitle_color1',
						'value'      => '',
						'group'      => esc_html__( 'Banner 1', 'supro' ),
					),
					array(
						'heading'    => esc_html__( 'Link( URL )', 'supro' ),
						'type'       => 'vc_link',
						'param_name' => 'link1',
						'group'      => esc_html__( 'Banner 1', 'supro' ),
					),
					array(
						'heading'    => esc_html__( 'Banner Content Position', 'supro' ),
						'param_name' => 'position1',
						'type'       => 'dropdown',
						'value'      => array(
							esc_html__( 'Left', 'supro' )   => 'left',
							esc_html__( 'Center', 'supro' ) => 'center',
							esc_html__( 'Right', 'supro' )  => 'right',
						),
						'std'        => 'center',
						'group'      => esc_html__( 'Banner 1', 'supro' ),
					),
					array(
						'heading'     => esc_html__( 'Banner Color Scheme', 'supro' ),
						'param_name'  => 'color_scheme1',
						'type'        => 'dropdown',
						'value'       => array(
							esc_html__( 'Dark', 'supro' )  => 'dark',
							esc_html__( 'Light', 'supro' ) => 'light',
						),
						'description' => esc_html__( 'Select color scheme for Banner', 'supro' ),
						'group'       => esc_html__( 'Banner 1', 'supro' ),
					),

					// Banner 2
					array(
						'type'        => 'attach_image',
						'heading'     => esc_html__( 'Image', 'supro' ),
						'param_name'  => 'image2',
						'value'       => '',
						'description' => esc_html__( 'Banner Image . Select an image from media library', 'supro' ),
						'group'       => esc_html__( 'Banner 2', 'supro' ),
					),
					array(
						'type'        => 'textarea',
						'heading'     => esc_html__( 'Title', 'supro' ),
						'param_name'  => 'title2',
						'value'       => '',
						'admin_label' => true,
						'group'       => esc_html__( 'Banner 2', 'supro' ),
					),
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Subtitle', 'supro' ),
						'param_name' => 'subtitle2',
						'value'      => '',
						'group'      => esc_html__( 'Banner 2', 'supro' ),
					),
					array(
						'type'       => 'colorpicker',
						'heading'    => esc_html__( 'Subtitle Color', 'supro' ),
						'param_name' => 'subtitle_color2',
						'value'      => '',
						'group'      => esc_html__( 'Banner 2', 'supro' ),
					),
					array(
						'heading'    => esc_html__( 'Link( URL )', 'supro' ),
						'type'       => 'vc_link',
						'param_name' => 'link2',
						'group'      => esc_html__( 'Banner 2', 'supro' ),
					),
					array(
						'heading'    => esc_html__( 'Banner Content Position', 'supro' ),
						'param_name' => 'position2',
						'type'       => 'dropdown',
						'value'      => array(
							esc_html__( 'Left', 'supro' )   => 'left',
							esc_html__( 'Center', 'supro' ) => 'center',
							esc_html__( 'Right', 'supro' )  => 'right',
						),
						'std'        => 'center',
						'group'      => esc_html__( 'Banner 2', 'supro' ),
					),
					array(
						'heading'     => esc_html__( 'Banner Color Scheme', 'supro' ),
						'param_name'  => 'color_scheme2',
						'type'        => 'dropdown',
						'value'       => array(
							esc_html__( 'Dark', 'supro' )  => 'dark',
							esc_html__( 'Light', 'supro' ) => 'light',
						),
						'description' => esc_html__( 'Select color scheme for Banner', 'supro' ),
						'group'       => esc_html__( 'Banner 2', 'supro' ),
					),

					// Banner 3
					array(
						'type'        => 'attach_image',
						'heading'     => esc_html__( 'Image', 'supro' ),
						'param_name'  => 'image3',
						'value'       => '',
						'description' => esc_html__( 'Banner Image . Select an image from media library', 'supro' ),
						'group'       => esc_html__( 'Banner 3', 'supro' ),
					),
					array(
						'type'        => 'textarea',
						'heading'     => esc_html__( 'Title', 'supro' ),
						'param_name'  => 'title3',
						'value'       => '',
						'admin_label' => true,
						'group'       => esc_html__( 'Banner 3', 'supro' ),
					),
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Subtitle', 'supro' ),
						'param_name' => 'subtitle3',
						'value'      => '',
						'group'      => esc_html__( 'Banner 3', 'supro' ),
					),
					array(
						'type'       => 'colorpicker',
						'heading'    => esc_html__( 'Subtitle Color', 'supro' ),
						'param_name' => 'subtitle_color3',
						'value'      => '',
						'group'      => esc_html__( 'Banner 3', 'supro' ),
					),
					array(
						'heading'    => esc_html__( 'Link( URL )', 'supro' ),
						'type'       => 'vc_link',
						'param_name' => 'link3',
						'group'      => esc_html__( 'Banner 3', 'supro' ),
					),
					array(
						'heading'    => esc_html__( 'Banner Content Position', 'supro' ),
						'param_name' => 'position3',
						'type'       => 'dropdown',
						'value'      => array(
							esc_html__( 'Left', 'supro' )   => 'left',
							esc_html__( 'Center', 'supro' ) => 'center',
							esc_html__( 'Right', 'supro' )  => 'right',
						),
						'std'        => 'center',
						'group'      => esc_html__( 'Banner 3', 'supro' ),
					),
					array(
						'heading'     => esc_html__( 'Banner Color Scheme', 'supro' ),
						'param_name'  => 'color_scheme3',
						'type'        => 'dropdown',
						'value'       => array(
							esc_html__( 'Dark', 'supro' )  => 'dark',
							esc_html__( 'Light', 'supro' ) => 'light',
						),
						'description' => esc_html__( 'Select color scheme for Banner', 'supro' ),
						'group'       => esc_html__( 'Banner 3', 'supro' ),
					),

					// Banner 4
					array(
						'type'        => 'attach_image',
						'heading'     => esc_html__( 'Image', 'supro' ),
						'param_name'  => 'image4',
						'value'       => '',
						'description' => esc_html__( 'Banner Image . Select an image from media library', 'supro' ),
						'group'       => esc_html__( 'Banner 4', 'supro' ),
					),
					array(
						'type'        => 'textarea',
						'heading'     => esc_html__( 'Title', 'supro' ),
						'param_name'  => 'title4',
						'value'       => '',
						'admin_label' => true,
						'group'       => esc_html__( 'Banner 4', 'supro' ),
					),
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Subtitle', 'supro' ),
						'param_name' => 'subtitle4',
						'value'      => '',
						'group'      => esc_html__( 'Banner 4', 'supro' ),
					),
					array(
						'type'       => 'colorpicker',
						'heading'    => esc_html__( 'Subtitle Color', 'supro' ),
						'param_name' => 'subtitle_color4',
						'value'      => '',
						'group'      => esc_html__( 'Banner 4', 'supro' ),
					),
					array(
						'heading'    => esc_html__( 'Link( URL )', 'supro' ),
						'type'       => 'vc_link',
						'param_name' => 'link4',
						'group'      => esc_html__( 'Banner 4', 'supro' ),
					),
					array(
						'heading'    => esc_html__( 'Banner Content Position', 'supro' ),
						'param_name' => 'position4',
						'type'       => 'dropdown',
						'value'      => array(
							esc_html__( 'Left', 'supro' )   => 'left',
							esc_html__( 'Center', 'supro' ) => 'center',
							esc_html__( 'Right', 'supro' )  => 'right',
						),
						'std'        => 'center',
						'group'      => esc_html__( 'Banner 4', 'supro' ),
					),
					array(
						'heading'     => esc_html__( 'Banner Color Scheme', 'supro' ),
						'param_name'  => 'color_scheme4',
						'type'        => 'dropdown',
						'value'       => array(
							esc_html__( 'Dark', 'supro' )  => 'dark',
							esc_html__( 'Light', 'supro' ) => 'light',
						),
						'description' => esc_html__( 'Select color scheme for Banner', 'supro' ),
						'group'       => esc_html__( 'Banner 4', 'supro' ),
					),
					vc_map_add_css_animation(),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'supro' ),
						'param_name'  => 'el_class',
						'value'       => '',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file . ', 'supro' ),
						'group'       => esc_html__( 'General', 'supro' ),
					),
				),
			)
		);

		// Supro Banner Grid 3
		vc_map(
			array(
				'name'     => esc_html__( 'Supro Banner Grid 3', 'supro' ),
				'base'     => 'supro_banner3',
				'class'    => '',
				'category' => esc_html__( 'Supro', 'supro' ),
				'params'   => array(
					array(
						'type'       => 'param_group',
						'heading'    => esc_html__( 'Banners', 'supro' ),
						'value'      => '',
						'param_name' => 'banners',
						'params'     => array(
							array(
								'heading'    => esc_html__( 'Banner Content Position', 'supro' ),
								'param_name' => 'position',
								'type'       => 'dropdown',
								'std'        => 'top-left',
								'value'      => array(
									esc_html__( 'Top Left', 'supro' )      => 'top-left',
									esc_html__( 'Top Center', 'supro' )    => 'top-center',
									esc_html__( 'Top Right', 'supro' )     => 'top-right',
									esc_html__( 'Center Left', 'supro' )   => 'center-left',
									esc_html__( 'Center Center', 'supro' ) => 'center-center',
									esc_html__( 'Center Right', 'supro' )  => 'center-right',
									esc_html__( 'Bottom Left', 'supro' )   => 'bottom-left',
									esc_html__( 'Bottom Center', 'supro' ) => 'bottom-center',
									esc_html__( 'Bottom Right', 'supro' )  => 'bottom-right',
								),
							),
							array(
								'type'        => 'attach_image',
								'heading'     => esc_html__( 'Image', 'supro' ),
								'param_name'  => 'image',
								'value'       => '',
								'description' => esc_html__( 'Choose images from media library', 'supro' ),
							),
							array(
								'type'        => 'textarea',
								'heading'     => esc_html__( 'Title', 'supro' ),
								'param_name'  => 'title',
								'value'       => '',
								'description' => esc_html__( 'Enter the title', 'supro' ),
								'admin_label' => true,
							),
							array(
								'type'        => 'textfield',
								'heading'     => esc_html__( 'Subtitle', 'supro' ),
								'param_name'  => 'subtitle',
								'value'       => '',
								'description' => esc_html__( 'Enter the subtitle', 'supro' ),
							),
							array(
								'type'       => 'vc_link',
								'value'      => '',
								'heading'    => esc_html__( 'Link', 'supro' ),
								'param_name' => 'link',
							),
						),
					),
					vc_map_add_css_animation(),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'supro' ),
						'param_name'  => 'el_class',
						'value'       => '',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file . ', 'supro' ),
					),
				),
			)
		);

		// Supro Banner Grid 4
		vc_map(
			array(
				'name'     => esc_html__( 'Supro Banner Grid 4', 'supro' ),
				'base'     => 'supro_banner4',
				'class'    => '',
				'category' => esc_html__( 'Supro', 'supro' ),
				'params'   => array(
					array(
						'type'       => 'param_group',
						'heading'    => esc_html__( 'Banners', 'supro' ),
						'value'      => '',
						'param_name' => 'banners',
						'params'     => array(
							array(
								'type'        => 'attach_image',
								'heading'     => esc_html__( 'Image', 'supro' ),
								'param_name'  => 'image',
								'value'       => '',
								'description' => esc_html__( 'Choose images from media library', 'supro' ),
							),
							array(
								'type'        => 'textarea',
								'heading'     => esc_html__( 'Title', 'supro' ),
								'param_name'  => 'title',
								'value'       => '',
								'description' => esc_html__( 'Enter the title', 'supro' ),
								'admin_label' => true,
							),
							array(
								'type'        => 'textfield',
								'heading'     => esc_html__( 'Subtitle', 'supro' ),
								'param_name'  => 'subtitle',
								'value'       => '',
								'description' => esc_html__( 'Enter the subtitle', 'supro' ),
							),
							array(
								'type'       => 'vc_link',
								'value'      => '',
								'heading'    => esc_html__( 'Link', 'supro' ),
								'param_name' => 'link',
							),
						),
					),
					vc_map_add_css_animation(),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'supro' ),
						'param_name'  => 'el_class',
						'value'       => '',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file . ', 'supro' ),
					),
				),
			)
		);

		// Supro Product Banner
		vc_map(
			array(
				'name'     => esc_html__( 'Supro Product Banner', 'supro' ),
				'base'     => 'supro_product_banner',
				'class'    => '',
				'category' => esc_html__( 'Supro', 'supro' ),
				'params'   => array(
					array(
						'type'        => 'param_group',
						'heading'     => esc_html__( 'Banner Option', 'supro' ),
						'value'       => '',
						'param_name'  => 'option',
						'description' => esc_html__( 'The size of banner that named with odd number are smaller than ones named with even number', 'supro' ),
						'params'      => array(
							array(
								'type'        => 'attach_image',
								'heading'     => esc_html__( 'Image', 'supro' ),
								'param_name'  => 'image',
								'value'       => '',
								'description' => esc_html__( 'Choose images from media library', 'supro' ),
							),
							array(
								'type'        => 'textfield',
								'heading'     => esc_html__( 'Image size', 'supro' ),
								'param_name'  => 'image_size',
								'description' => esc_html__( 'Enter image size', 'supro' ),
							),
							array(
								'type'        => 'textarea',
								'heading'     => esc_html__( 'Title', 'supro' ),
								'param_name'  => 'title',
								'value'       => '',
								'description' => esc_html__( 'Enter the title', 'supro' ),
								'admin_label' => true,
							),
							array(
								'type'       => 'textfield',
								'heading'    => esc_html__( 'Price', 'supro' ),
								'param_name' => 'price',
								'value'      => '',
							),
							array(
								'heading'    => esc_html__( 'Link( URL )', 'supro' ),
								'type'       => 'vc_link',
								'param_name' => 'link',
							),
						),
					),
					vc_map_add_css_animation(),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'supro' ),
						'param_name'  => 'el_class',
						'value'       => '',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file . ', 'supro' ),
					),
				),
			)
		);

		vc_map(
			array(
				'name'     => esc_html__( 'Supro Product Banner 2', 'supro' ),
				'base'     => 'supro_product_banner2',
				'class'    => '',
				'category' => esc_html__( 'Supro', 'supro' ),
				'params'   => array(
					array(
						'heading'    => esc_html__( 'Style', 'supro' ),
						'param_name' => 'style',
						'type'       => 'dropdown',
						'value'      => array(
							esc_html__( 'Default', 'supro' ) => '1',
							esc_html__( 'Center', 'supro' )  => '2',
						),
					),
					array(
						'type'        => 'attach_image',
						'heading'     => esc_html__( 'Image', 'supro' ),
						'param_name'  => 'image',
						'value'       => '',
						'description' => esc_html__( 'Banner Image . Select an image from media library', 'supro' ),
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Image size', 'supro' ),
						'param_name'  => 'image_size',
						'value'       => '',
						'description' => esc_html__( 'Enter image size( Example: "thumbnail", "medium", "large", "full" or other sizes defined by theme). Alternatively enter size in pixels( Example: 200x100( Width x Height)).', 'supro' )
					),
					array(
						'type'        => 'textarea',
						'heading'     => esc_html__( 'Title', 'supro' ),
						'param_name'  => 'title',
						'value'       => '',
						'admin_label' => true,
					),
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Price', 'supro' ),
						'param_name' => 'price',
						'value'      => '',
					),
					array(
						'heading'    => esc_html__( 'Link( URL )', 'supro' ),
						'type'       => 'vc_link',
						'param_name' => 'link',
					),
					array(
						'heading'    => esc_html__( 'Alignment', 'supro' ),
						'param_name' => 'alignment',
						'type'       => 'dropdown',
						'value'      => array(
							esc_html__( 'Left', 'supro' )   => 'left',
							esc_html__( 'Center', 'supro' ) => 'center',
							esc_html__( 'Right', 'supro' )  => 'right',
						),
						'dependency' => array(
							'element' => 'style',
							'value'   => '1',
						),
					),
					vc_map_add_css_animation(),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'supro' ),
						'param_name'  => 'el_class',
						'value'       => '',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file . ', 'supro' ),
					),
				),
			)
		);

		vc_map(
			array(
				'name'     => esc_html__( 'Supro Product Banner 3', 'supro' ),
				'base'     => 'supro_product_banner3',
				'class'    => '',
				'category' => esc_html__( 'Supro', 'supro' ),
				'params'   => array(
					array(
						'type'        => 'attach_image',
						'heading'     => esc_html__( 'Image', 'supro' ),
						'param_name'  => 'image',
						'value'       => '',
						'description' => esc_html__( 'Choose images from media library', 'supro' ),
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Image size', 'supro' ),
						'param_name'  => 'image_size',
						'description' => esc_html__( 'Enter image size( Example: "thumbnail", "medium", "large", "full" or other sizes defined by theme). Alternatively enter size in pixels( Example: 200x100( Width x Height)).', 'supro' ),
					),
					array(
						'type'        => 'textarea',
						'heading'     => esc_html__( 'Title', 'supro' ),
						'param_name'  => 'title',
						'value'       => '',
						'description' => esc_html__( 'Enter the title', 'supro' ),
						'admin_label' => true,
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Subtitle', 'supro' ),
						'param_name'  => 'subtitle',
						'value'       => '',
						'description' => esc_html__( 'Enter the subtitle', 'supro' ),
					),
					array(
						'type'       => 'vc_link',
						'value'      => '',
						'heading'    => esc_html__( 'Link', 'supro' ),
						'param_name' => 'link',
					),
					vc_map_add_css_animation(),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'supro' ),
						'param_name'  => 'el_class',
						'value'       => '',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file . ', 'supro' ),
					),
				),
			)
		);

		// Images
		vc_map(
			array(
				'name'     => __( 'Images', 'supro' ),
				'base'     => 'supro_images',
				'class'    => '',
				'category' => __( 'Supro', 'supro' ),
				'params'   => array(
					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Type', 'supro' ),
						'param_name' => 'type',
						'value'      => array(
							esc_html__( 'Grid', 'supro' )   => 'grid',
							esc_html__( 'Slides', 'supro' ) => 'slides',
						),
					),
					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Columns', 'supro' ),
						'param_name' => 'columns',
						'value'      => array(
							esc_html__( '1 Columns', 'supro' ) => '1',
							esc_html__( '2 Columns', 'supro' ) => '2',
							esc_html__( '3 Columns', 'supro' ) => '3',
						),
						'std'        => '2',
					),
					array(
						'type'        => 'attach_images',
						'heading'     => esc_html__( 'Images', 'supro' ),
						'param_name'  => 'images',
						'value'       => '',
						'description' => esc_html__( 'Choose images from media library', 'supro' ),
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Image size', 'supro' ),
						'param_name'  => 'image_size',
						'description' => esc_html__( 'Enter image size (Example: "thumbnail", "medium", "large", "full" or other sizes defined by theme). Alternatively enter size in pixels (Example: 200x100 (Width x Height)).', 'supro' ),
					),
					// Slide Option
					array(
						'type'             => 'checkbox',
						'heading'          => esc_html__( 'Show Nav', 'supro' ),
						'param_name'       => 'nav',
						'value'            => array( esc_html__( 'Yes', 'supro' ) => '1' ),
						'edit_field_class' => 'vc_col-xs-4',
						'dependency'       => array(
							'element' => 'type',
							'value'   => 'slides',
						),
					),
					array(
						'type'             => 'checkbox',
						'heading'          => esc_html__( 'Show Dots', 'supro' ),
						'param_name'       => 'dots',
						'value'            => array( esc_html__( 'Yes', 'supro' ) => '1' ),
						'edit_field_class' => 'vc_col-xs-4',
						'dependency'       => array(
							'element' => 'type',
							'value'   => 'slides',
						),
					),
					array(
						'heading'          => esc_html__( 'Infinite Loop', 'supro' ),
						'param_name'       => 'infinite',
						'type'             => 'checkbox',
						'value'            => array(
							esc_html__( 'Yes', 'supro' ) => '1',
						),
						'edit_field_class' => 'vc_col-xs-4',
						'dependency'       => array(
							'element' => 'type',
							'value'   => 'slides',
						),
					),
					array(
						'type'             => 'checkbox',
						'heading'          => esc_html__( 'Autoplay', 'supro' ),
						'param_name'       => 'autoplay',
						'value'            => array( esc_html__( 'Yes', 'supro' ) => '1' ),
						'edit_field_class' => 'vc_col-xs-4',
						'dependency'       => array(
							'element' => 'type',
							'value'   => 'slides',
						),
					),
					array(
						'type'             => 'textfield',
						'heading'          => esc_html__( 'Autoplay Speed', 'supro' ),
						'param_name'       => 'autoplay_speed',
						'value'            => 1600,
						'description'      => esc_html__( 'Autoplay Speed in milliseconds', 'supro' ),
						'edit_field_class' => 'vc_col-xs-4',
						'dependency'       => array(
							'element' => 'type',
							'value'   => 'slides',
						),
					),
					array(
						'type'             => 'textfield',
						'heading'          => esc_html__( 'Speed( ms )', 'supro' ),
						'param_name'       => 'speed',
						'value'            => 800,
						'description'      => esc_html__( 'Slide / Fade animation speed', 'supro' ),
						'edit_field_class' => 'vc_col-xs-4',
						'dependency'       => array(
							'element' => 'type',
							'value'   => 'slides',
						),
					),
					vc_map_add_css_animation(),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'supro' ),
						'param_name'  => 'el_class',
						'value'       => '',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file . ', 'supro' ),
					),
				),
			)
		);

		// Sale product
		vc_map(
			array(
				'name'     => esc_html__( 'Supro Sale Product', 'supro' ),
				'base'     => 'supro_sale_product',
				'class'    => '',
				'category' => esc_html__( 'Supro', 'supro' ),
				'params'   => array(
					array(
						'heading'    => esc_html__( 'Style', 'supro' ),
						'param_name' => 'style',
						'type'       => 'dropdown',
						'value'      => array(
							esc_html__( 'Has Background', 'supro' ) => '1',
							esc_html__( 'No Background', 'supro' )  => '2',
						),
					),
					array(
						'type'        => 'attach_image',
						'heading'     => esc_html__( 'Background Image', 'supro' ),
						'param_name'  => 'image',
						'value'       => '',
						'description' => esc_html__( 'Select an image from media library', 'supro' ),
						'dependency'  => array(
							'element' => 'style',
							'value'   => '1',
						),
					),
					array(
						'type'       => 'checkbox',
						'heading'    => esc_html__( 'Parallax', 'supro' ),
						'param_name' => 'parallax',
						'value'      => array( esc_html__( 'Yes', 'supro' ) => '1' ),
					),
					array(
						'type'        => 'textarea',
						'heading'     => esc_html__( 'Product Name', 'supro' ),
						'param_name'  => 'name',
						'value'       => '',
						'admin_label' => true,
					),
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Title', 'supro' ),
						'param_name' => 'title',
						'value'      => esc_html__( 'Deal of the day', 'supro' ),
					),
					array(
						'type'             => 'textfield',
						'heading'          => esc_html__( 'Regular price', 'supro' ),
						'param_name'       => 'regular_price',
						'edit_field_class' => 'vc_col-xs-4',
						'value'            => '',
					),
					array(
						'type'             => 'textfield',
						'heading'          => esc_html__( 'Sale price', 'supro' ),
						'param_name'       => 'sale_price',
						'edit_field_class' => 'vc_col-xs-4',
						'value'            => '',
						'description'      => esc_html__( 'Please enter in a value less than Regular price', 'supro' ),
					),
					array(
						'type'             => 'textfield',
						'heading'          => esc_html__( 'Currency', 'supro' ),
						'param_name'       => 'currency',
						'edit_field_class' => 'vc_col-xs-4',
						'value'            => '$',
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Expiration Date', 'supro' ),
						'param_name'  => 'date',
						'value'       => '',
						'description' => esc_html__( 'Enter the date in format: YYYY / MM / DD', 'supro' ),
					),
					array(
						'heading'    => esc_html__( 'Link( URL )', 'supro' ),
						'type'       => 'vc_link',
						'param_name' => 'link',
					),
					array(
						'heading'    => esc_html__( 'Short Description', 'supro' ),
						'type'       => 'textarea_html',
						'param_name' => 'content',
					),
					vc_map_add_css_animation(),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'supro' ),
						'param_name'  => 'el_class',
						'value'       => '',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file . ', 'supro' ),
					),
				),
			)
		);

		// Latest Post
		vc_map(
			array(
				'name'     => esc_html__( 'Latest Post', 'supro' ),
				'base'     => 'supro_latest_post',
				'class'    => '',
				'category' => esc_html__( 'Supro', 'supro' ),
				'params'   => array(
					array(
						'heading'    => esc_html__( 'Blog Style', 'supro' ),
						'param_name' => 'style',
						'type'       => 'dropdown',
						'value'      => array(
							esc_html__( 'Style 1', 'supro' ) => '1',
							esc_html__( 'Style 2', 'supro' ) => '2',
						),
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Number of Posts', 'supro' ),
						'param_name'  => 'number',
						'value'       => '3',
						'description' => esc_html__( 'Set numbers of Posts you want to display . Set -1 to display all posts', 'supro' ),
					),
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Button Text', 'supro' ),
						'param_name' => 'btn_text',
						'value'      => esc_html__( 'READ MORE', 'supro' ),
						'dependency' => array(
							'element' => 'style',
							'value'   => '1',
						),
					),

					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Excerpt Length', 'supro' ),
						'param_name' => 'excerpt_length',
						'value'      => '10',
						'dependency' => array(
							'element' => 'style',
							'value'   => '2',
						),
					),
					vc_map_add_css_animation(),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'supro' ),
						'param_name'  => 'el_class',
						'value'       => '',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file . ', 'supro' ),
					),
				),
			)
		);

		// Slider
		vc_map(
			array(
				'name'     => esc_html__( 'Sliders', 'supro' ),
				'base'     => 'supro_sliders',
				'class'    => '',
				'category' => esc_html__( 'Supro', 'supro' ),
				'params'   => array(
					array(
						'type'             => 'checkbox',
						'heading'          => esc_html__( 'Show Nav', 'supro' ),
						'param_name'       => 'nav',
						'value'            => array( esc_html__( 'Yes', 'supro' ) => '1' ),
						'edit_field_class' => 'vc_col-xs-4',
					),
					array(
						'type'             => 'checkbox',
						'heading'          => esc_html__( 'Show Dots', 'supro' ),
						'param_name'       => 'dots',
						'value'            => array( esc_html__( 'Yes', 'supro' ) => '1' ),
						'edit_field_class' => 'vc_col-xs-4',
					),
					array(
						'heading'          => esc_html__( 'Infinite Loop', 'supro' ),
						'param_name'       => 'infinite',
						'type'             => 'checkbox',
						'value'            => array(
							esc_html__( 'Yes', 'supro' ) => '1',
						),
						'edit_field_class' => 'vc_col-xs-4',
					),
					array(
						'type'             => 'checkbox',
						'heading'          => esc_html__( 'Autoplay', 'supro' ),
						'param_name'       => 'autoplay',
						'value'            => array( esc_html__( 'Yes', 'supro' ) => '1' ),
						'edit_field_class' => 'vc_col-xs-6',
					),
					array(
						'type'             => 'textfield',
						'heading'          => esc_html__( 'Autoplay Speed', 'supro' ),
						'param_name'       => 'autoplay_speed',
						'value'            => 2000,
						'edit_field_class' => 'vc_col-xs-6',
					),
					array(
						'type'             => 'textfield',
						'heading'          => esc_html__( 'Initial Slide', 'supro' ),
						'param_name'       => 'initial_slide',
						'value'            => 1,
						'description'      => esc_html__( 'Slide to start on', 'supro' ),
						'edit_field_class' => 'vc_col-xs-6',
					),
					array(
						'type'             => 'textfield',
						'heading'          => esc_html__( 'Speed( ms )', 'supro' ),
						'param_name'       => 'speed',
						'value'            => 1000,
						'description'      => esc_html__( 'Slide / Fade animation speed', 'supro' ),
						'edit_field_class' => 'vc_col-xs-6',
					),
					array(
						'type'       => 'param_group',
						'heading'    => esc_html__( 'Slider Option', 'supro' ),
						'value'      => '',
						'param_name' => 'slider_option',
						'params'     => array(
							array(
								'type'        => 'attach_image',
								'heading'     => esc_html__( 'Image', 'supro' ),
								'param_name'  => 'image',
								'value'       => '',
								'description' => esc_html__( 'Choose images from media library', 'supro' ),
							),
							array(
								'type'        => 'textfield',
								'heading'     => esc_html__( 'Image size', 'supro' ),
								'param_name'  => 'image_size',
								'description' => esc_html__( 'Enter image size', 'supro' ),
							),
							array(
								'type'        => 'textarea',
								'heading'     => esc_html__( 'Title', 'supro' ),
								'param_name'  => 'title',
								'value'       => '',
								'description' => esc_html__( 'Enter the title', 'supro' ),
								'admin_label' => true,
							),
							array(
								'type'        => 'textfield',
								'heading'     => esc_html__( 'Subtitle', 'supro' ),
								'param_name'  => 'subtitle',
								'value'       => '',
								'description' => esc_html__( 'Enter the subtitle', 'supro' ),
							),
							array(
								'type'        => 'colorpicker',
								'heading'     => esc_html__( 'Subtitle Color', 'supro' ),
								'param_name'  => 'color',
								'value'       => '',
								'description' => esc_html__( 'Select background color for form . Leave empty to use default', 'supro' ),
							),
							array(
								'type'        => 'textarea',
								'heading'     => esc_html__( 'Description', 'supro' ),
								'param_name'  => 'description',
								'value'       => '',
								'description' => esc_html__( 'Enter the subtitle', 'supro' ),
							),
							array(
								'type'       => 'vc_link',
								'value'      => '',
								'heading'    => esc_html__( 'Link', 'supro' ),
								'param_name' => 'link',
							),
						),
					),
					vc_map_add_css_animation(),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'supro' ),
						'param_name'  => 'el_class',
						'value'       => '',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file . ', 'supro' ),
					),
				),
			)
		);

		// Supro Testimonial
		vc_map(
			array(
				'name'     => esc_html__( 'Testimonial', 'supro' ),
				'base'     => 'supro_testimonial',
				'class'    => '',
				'category' => esc_html__( 'Supro', 'supro' ),
				'params'   => array(
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Title', 'supro' ),
						'param_name' => 'title',
						'value'      => '',
					),
					array(
						'type'        => 'textarea',
						'heading'     => esc_html__( 'Name', 'supro' ),
						'param_name'  => 'name',
						'value'       => '',
						'admin_label' => true,
					),
					array(
						'heading'    => esc_html__( 'Content', 'supro' ),
						'type'       => 'textarea_html',
						'param_name' => 'content',
					),
					vc_map_add_css_animation(),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'supro' ),
						'param_name'  => 'el_class',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file . ', 'supro' ),
					),
				),
			)
		);

		// Counter
		vc_map(
			array(
				'name'     => esc_html__( 'Counter', 'supro' ),
				'base'     => 'supro_counter',
				'class'    => '',
				'category' => esc_html__( 'Supro', 'supro' ),
				'params'   => array(
					array(
						'heading'    => esc_html__( 'Color Scheme', 'supro' ),
						'param_name' => 'color_scheme',
						'type'       => 'dropdown',
						'value'      => array(
							esc_html__( 'Dark', 'supro' )  => 'dark',
							esc_html__( 'Light', 'supro' ) => 'light',
						),
					),
					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Columns', 'supro' ),
						'param_name' => 'columns',
						'value'      => array(
							esc_html__( '1 Columns', 'supro' ) => '1',
							esc_html__( '2 Columns', 'supro' ) => '2',
							esc_html__( '3 Columns', 'supro' ) => '3',
							esc_html__( '4 Columns', 'supro' ) => '4',
						),
					),
					array(
						'type'       => 'param_group',
						'heading'    => esc_html__( 'Counter Option', 'supro' ),
						'value'      => '',
						'param_name' => 'counter_option',
						'params'     => array(
							array(
								'type'        => 'textfield',
								'heading'     => esc_html__( 'Counter Value', 'supro' ),
								'param_name'  => 'value',
								'value'       => '',
								'description' => esc_html__( 'Input integer value for counting', 'supro' ),
							),
							array(
								'type'        => 'textfield',
								'heading'     => esc_html__( 'Title', 'supro' ),
								'param_name'  => 'title',
								'value'       => '',
								'description' => esc_html__( 'Enter the title of this box', 'supro' ),
								'admin_label' => true,
							),
						),
					),
					vc_map_add_css_animation(),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'supro' ),
						'param_name'  => 'el_class',
						'value'       => '',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file . ', 'supro' ),
					),
				),
			)
		);

		// FAQs
		vc_map(
			array(
				'name'     => esc_html__( 'FAQs', 'supro' ),
				'base'     => 'supro_faqs',
				'category' => esc_html__( 'Supro', 'supro' ),
				'class'    => '',
				'params'   => array(
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Title', 'supro' ),
						'param_name' => 'title',
						'value'      => '',
					),
					array(
						'heading'    => esc_html__( 'FAQs', 'supro' ),
						'type'       => 'param_group',
						'value'      => '',
						'param_name' => 'faqs',
						'params'     => array(
							array(
								'type'       => 'textfield',
								'heading'    => esc_html__( 'Title', 'supro' ),
								'param_name' => 'title',
								'value'      => '',
							),
							array(
								'type'       => 'textarea',
								'value'      => '',
								'heading'    => esc_html__( 'Content', 'supro' ),
								'param_name' => 'desc',
							),
						),
					),
					vc_map_add_css_animation(),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'supro' ),
						'param_name'  => 'el_class',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file . ', 'supro' ),
					),
				),
			)
		);

		// Partner
		vc_map(
			array(
				'name'     => esc_html__( 'Partners', 'supro' ),
				'base'     => 'supro_partner',
				'class'    => '',
				'category' => esc_html__( 'Supro', 'supro' ),
				'params'   => array(
					array(
						'type'        => 'attach_images',
						'heading'     => esc_html__( 'Images', 'supro' ),
						'param_name'  => 'images',
						'value'       => '',
						'description' => esc_html__( 'Choose images from media library', 'supro' ),
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Image size', 'supro' ),
						'param_name'  => 'image_size',
						'description' => esc_html__( 'Enter image size( Example: "thumbnail", "medium", "large", "full" or other sizes defined by theme). Alternatively enter size in pixels( Example: 200x100( Width x Height)).', 'supro' ),
					),
					array(
						'type'        => 'exploded_textarea_safe',
						'heading'     => esc_html__( 'Custom links', 'supro' ),
						'param_name'  => 'custom_links',
						'description' => esc_html__( 'Enter links for each slide here . Divide links with linebreaks( Enter ) . ', 'supro' ),
					),
					array(
						'type'        => 'dropdown',
						'heading'     => esc_html__( 'Custom link target', 'supro' ),
						'param_name'  => 'custom_links_target',
						'value'       => array(
							esc_html__( 'Same window', 'supro' ) => '_self',
							esc_html__( 'New window', 'supro' )  => '_blank',
						),
						'description' => esc_html__( 'Select where to open custom links . ', 'supro' ),
					),
					vc_map_add_css_animation(),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'supro' ),
						'param_name'  => 'el_class',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file . ', 'supro' ),
					),
				),
			)
		);

		// Member
		vc_map(
			array(
				'name'     => esc_html__( 'Members', 'supro' ),
				'base'     => 'supro_members',
				'class'    => '',
				'category' => esc_html__( 'Supro', 'supro' ),
				'params'   => array(
					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Columns', 'supro' ),
						'param_name' => 'columns',
						'value'      => array(
							esc_html__( '2 Columns', 'supro' ) => '2',
							esc_html__( '3 Columns', 'supro' ) => '3',
							esc_html__( '4 Columns', 'supro' ) => '4',
						),
						'std'        => '3',
					),
					array(
						'type'       => 'param_group',
						'heading'    => esc_html__( 'Member Option', 'supro' ),
						'value'      => '',
						'param_name' => 'member_option',
						'params'     => array(
							array(
								'type'        => 'attach_image',
								'heading'     => esc_html__( 'Image', 'supro' ),
								'param_name'  => 'image',
								'value'       => '',
								'description' => esc_html__( 'Member Image . Select an image from media library', 'supro' ),
							),
							array(
								'type'        => 'textfield',
								'heading'     => esc_html__( 'Image size', 'supro' ),
								'param_name'  => 'image_size',
								'value'       => '',
								'description' => esc_html__( 'Alternatively enter size in pixels( Ex: 200x100( W x H)).', 'supro' )
							),
							array(
								'type'        => 'textfield',
								'heading'     => esc_html__( 'Name', 'supro' ),
								'param_name'  => 'name',
								'value'       => '',
								'description' => esc_html__( 'Enter member\'s name', 'supro' ),
								'admin_label' => true,
							),
							array(
								'type'        => 'textfield',
								'heading'     => esc_html__( 'Job', 'supro' ),
								'param_name'  => 'job',
								'value'       => '',
								'description' => esc_html__( 'Enter member\'s job', 'supro' ),
							),
						),
					),
					vc_map_add_css_animation(),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'supro' ),
						'param_name'  => 'el_class',
						'value'       => '',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'supro' ),
					),
				),
			)
		);

		// Contact Box
		vc_map(
			array(
				'name'     => esc_html__( 'Contact Box', 'supro' ),
				'base'     => 'supro_contact_box',
				'class'    => '',
				'category' => esc_html__( 'Supro', 'supro' ),
				'params'   => array(
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Box Title', 'supro' ),
						'param_name'  => 'title',
						'value'       => '',
						'admin_label' => true,
					),
					array(
						'type'       => 'checkbox',
						'heading'    => esc_html__( 'Hide Label', 'supro' ),
						'param_name' => 'hide_label',
						'value'      => array( esc_html__( 'Yes', 'supro' ) => '1' ),
					),
					array(
						'heading'    => esc_html__( 'Display', 'supro' ),
						'param_name' => 'display',
						'type'       => 'dropdown',
						'value'      => array(
							esc_html__( 'Horizontal', 'supro' ) => 'horizontal',
							esc_html__( 'Vertical', 'supro' )   => 'vertical',
						),
					),
					array(
						'type'       => 'textarea',
						'heading'    => esc_html__( 'Location', 'supro' ),
						'param_name' => 'location',
						'value'      => '',
					),
					array(
						'type'       => 'textarea',
						'heading'    => esc_html__( 'Phone Number', 'supro' ),
						'param_name' => 'phone',
						'value'      => '',
					),
					array(
						'type'       => 'textarea',
						'heading'    => esc_html__( 'Email', 'supro' ),
						'param_name' => 'email',
						'value'      => '',
					),
					vc_map_add_css_animation(),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'supro' ),
						'param_name'  => 'el_class',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'supro' ),
					),
				),
			)
		);

		// Video Banner
		vc_map(
			array(
				'name'     => esc_html__( 'Video Banner', 'supro' ),
				'base'     => 'supro_video',
				'category' => esc_html__( 'Supro', 'supro' ),
				'params'   => array(
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Video file URL', 'supro' ),
						'description' => esc_html__( 'Only support YouTube and Vimeo', 'supro' ),
						'param_name'  => 'video',
						'value'       => '',
					),
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Min Height(px)', 'supro' ),
						'param_name' => 'min_height',
						'value'      => '500',
					),
					array(
						'type'       => 'attach_image',
						'heading'    => esc_html__( 'Video Background Image', 'supro' ),
						'param_name' => 'image',
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Image size', 'supro' ),
						'param_name'  => 'image_size',
						'description' => esc_html__( 'Enter image size (Example: "thumbnail", "medium", "large", "full" or other sizes defined by theme). Alternatively enter size in pixels (Example: 200x100 (Width x Height)).', 'supro' ),
					),
					array(
						'heading'    => esc_html__( 'Content', 'supro' ),
						'type'       => 'textarea_html',
						'param_name' => 'content',
					),
					vc_map_add_css_animation(),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'supro' ),
						'param_name'  => 'el_class',
						'value'       => '',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file . ', 'supro' ),
					),
				),
			)
		);

		// Socials
		vc_map(
			array(
				'name'     => esc_html__( 'Socials', 'supro' ),
				'base'     => 'supro_socials',
				'class'    => '',
				'category' => esc_html__( 'Supro', 'supro' ),
				'params'   => array(
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Title', 'supro' ),
						'param_name' => 'title',
						'value'      => '',
					),
					array(
						'heading'    => esc_html__( 'Style', 'supro' ),
						'param_name' => 'style',
						'type'       => 'dropdown',
						'value'      => array(
							esc_html__( 'Border', 'supro' )  => 'border',
							esc_html__( 'Outline', 'supro' ) => 'outline',
						),
					),
					array(
						'heading'    => esc_html__( 'Color', 'supro' ),
						'param_name' => 'color',
						'type'       => 'dropdown',
						'value'      => array(
							esc_html__( 'Dark', 'supro' )  => 'dark',
							esc_html__( 'Light', 'supro' ) => 'light',
						),
					),
					array(
						'heading'    => esc_html__( 'Socials', 'supro' ),
						'type'       => 'param_group',
						'value'      => '',
						'param_name' => 'socials',
						'params'     => array(
							array(
								'heading'     => esc_html__( 'Icon library', 'supro' ),
								'description' => esc_html__( 'Select icon library.', 'supro' ),
								'param_name'  => 'icon_type',
								'type'        => 'dropdown',
								'value'       => array(
									esc_html__( 'Font Awesome', 'supro' ) => 'fontawesome',
									esc_html__( 'IonIcons', 'supro' )     => 'ionicons',
								),
							),
							array(
								'heading'     => esc_html__( 'Icon', 'supro' ),
								'description' => esc_html__( 'Pick an icon from library.', 'supro' ),
								'type'        => 'iconpicker',
								'param_name'  => 'icon_fontawesome',
								'value'       => 'fa fa-adjust',
								'settings'    => array(
									'emptyIcon'    => false,
									'iconsPerPage' => 4000,
								),
								'dependency'  => array(
									'element' => 'icon_type',
									'value'   => 'fontawesome',
								),
							),
							array(
								'heading'     => esc_html__( 'Icon', 'supro' ),
								'description' => esc_html__( 'Select icon from library.', 'supro' ),
								'type'        => 'iconpicker',
								'param_name'  => 'icon_ionicons',
								'value'       => 'ion-alert',
								'settings'    => array(
									'emptyIcon'    => false,
									'iconsPerPage' => 4000,
									'type'         => 'ionicons',
								),
								'dependency'  => array(
									'element' => 'icon_type',
									'value'   => 'ionicons',
								),
							),
							array(
								'type'       => 'vc_link',
								'value'      => '',
								'heading'    => esc_html__( 'Link', 'supro' ),
								'param_name' => 'link',
							),
						)
					),
					vc_map_add_css_animation(),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'supro' ),
						'param_name'  => 'el_class',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'supro' ),
					),
				),
			)
		);

		// Add newsletter shortcode - get form id of mailchimp
		$mail_forms    = get_posts( 'post_type=mc4wp-form&posts_per_page=-1' );
		$mail_form_ids = array(
			esc_html__( 'Select Form', 'supro' ) => '',
		);
		foreach ( $mail_forms as $form ) {
			$mail_form_ids[$form->post_title] = $form->ID;
		}
		vc_map(
			array(
				'name'     => esc_html__( 'Newsletter', 'supro' ),
				'base'     => 'supro_newsletter',
				'class'    => '',
				'category' => esc_html__( 'Supro', 'supro' ),
				'params'   => array(
					array(
						'heading'    => esc_html__( 'Style', 'supro' ),
						'param_name' => 'style',
						'type'       => 'dropdown',
						'value'      => array(
							esc_html__( 'Space Between', 'supro' ) => 'space-between',
							esc_html__( 'Center', 'supro' )        => 'center',
						),
					),
					array(
						'type'       => 'dropdown',
						'heading'    => esc_html__( 'Mailchimp Form', 'supro' ),
						'param_name' => 'form',
						'value'      => $mail_form_ids,
					),
					array(
						'type'        => 'textarea',
						'heading'     => esc_html__( 'Title', 'supro' ),
						'param_name'  => 'title',
						'value'       => '',
						'admin_label' => true,
					),
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Subtitle', 'supro' ),
						'param_name' => 'subtitle',
						'value'      => '',
					),
					array(
						'type'        => 'colorpicker',
						'heading'     => esc_html__( 'Form Background Color', 'supro' ),
						'param_name'  => 'bg_color',
						'value'       => '',
						'description' => esc_html__( 'Select background color for form. Leave empty to use default', 'supro' ),
					),
					array(
						'type'        => 'colorpicker',
						'heading'     => esc_html__( 'Form Text Color', 'supro' ),
						'param_name'  => 'text_color',
						'value'       => '',
						'description' => esc_html__( 'Select text color for form. Leave empty to use default', 'supro' ),
					),
					array(
						'heading'    => esc_html__( 'Shape', 'supro' ),
						'param_name' => 'shape',
						'type'       => 'dropdown',
						'value'      => array(
							esc_html__( 'Square', 'supro' ) => 'square',
							esc_html__( 'Round', 'supro' )  => 'round',
						),
					),
					vc_map_add_css_animation(),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'supro' ),
						'param_name'  => 'el_class',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'supro' ),
					),
				),
			)
		);

		// Instagram
		vc_map(
			array(
				'name'     => esc_html__( 'Instagram', 'supro' ),
				'base'     => 'supro_instagram',
				'class'    => '',
				'category' => esc_html__( 'Supro', 'supro' ),
				'params'   => array(
					array(
						'heading'    => esc_html__( 'Access Methods', 'supro' ),
						'param_name' => 'methods',
						'type'       => 'dropdown',
						'value'      => array(
							esc_html__( 'User', 'supro' )  => 'user',
							esc_html__( 'Token', 'supro' ) => 'token',
						),
					),
					array(
						'heading'    => esc_html__( 'Username', 'supro' ),
						'param_name' => 'user',
						'type'       => 'textfield',
						'value'      => '',
						'dependency' => array(
							'element' => 'methods',
							'value'   => 'user',
						),
					),
					array(
						'heading'     => esc_html__( 'Token', 'supro' ),
						'param_name'  => 'token',
						'type'        => 'textfield',
						'value'       => '',
						'description' => sprintf( __( 'Please go to <a href="%s">here</a> to get a access token', 'supro' ), esc_url( 'http://instagramwordpress.rafsegat.com/docs/get-access-token/' ) ),
						'dependency'  => array(
							'element' => 'methods',
							'value'   => 'token',
						),
					),
					array(
						'heading'    => esc_html__( 'Number of photos', 'supro' ),
						'param_name' => 'number',
						'type'       => 'textfield',
						'value'      => 8,
					),
					array(
						'type'       => 'checkbox',
						'heading'    => esc_html__( 'Include Video', 'supro' ),
						'param_name' => 'video',
						'value'      => array( esc_html__( 'Yes', 'supro' ) => 'yes' ),
					),
					array(
						'heading'    => esc_html__( 'Columns', 'supro' ),
						'param_name' => 'columns',
						'type'       => 'dropdown',
						'value'      => array(
							esc_html__( '8 Columns', 'supro' ) => '8',
							esc_html__( '6 Columns', 'supro' ) => '6',
							esc_html__( '5 Columns', 'supro' ) => '5',
							esc_html__( '4 Columns', 'supro' ) => '4',
						),
					),
					array(
						'heading'    => esc_html__( 'Photo size', 'supro' ),
						'param_name' => 'size',
						'type'       => 'dropdown',
						'value'      => array(
							esc_html__( 'Small', 'supro' )     => 'small',
							esc_html__( 'Large', 'supro' )     => 'large',
							esc_html__( 'Thumbnail', 'supro' ) => 'thumbnail',
						),
					),
					array(
						'heading'    => esc_html__( 'Open link in', 'supro' ),
						'param_name' => 'target',
						'type'       => 'dropdown',
						'value'      => array(
							esc_html__( 'New window', 'supro' )     => '_blank',
							esc_html__( 'Current window', 'supro' ) => '_self',
						),
					),
					vc_map_add_css_animation(),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'supro' ),
						'param_name'  => 'el_class',
						'value'       => '',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'supro' ),
					),
				),
			)
		);

		// Coming soon shortcode
		vc_map(
			array(
				'name'     => esc_html__( 'Coming Soon', 'supro' ),
				'base'     => 'supro_coming_soon',
				'class'    => '',
				'category' => esc_html__( 'Supro', 'supro' ),
				'params'   => array(
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Date', 'supro' ),
						'param_name'  => 'date',
						'value'       => '',
						'description' => esc_html__( 'Enter the date by format: YYYY-MM-DD', 'supro' ),
					),
					array(
						'heading'    => esc_html__( 'Color', 'supro' ),
						'param_name' => 'color',
						'type'       => 'dropdown',
						'value'      => array(
							esc_html__( 'Dark', 'supro' )  => 'dark',
							esc_html__( 'Light', 'supro' ) => 'light',
						),
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'supro' ),
						'param_name'  => 'el_class',
						'value'       => '',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file . ', 'supro' ),
					),
				),
			)
		);

		// GG maps

		vc_map(
			array(
				'name'     => esc_html__( 'Google Maps', 'supro' ),
				'base'     => 'supro_gmap',
				'category' => esc_html__( 'Supro', 'supro' ),
				'params'   => array(
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Api Key', 'supro' ),
						'param_name'  => 'api_key',
						'value'       => '',
						'description' => sprintf( __( 'Please go to <a href="%s">Google Maps APIs</a> to get a key', 'supro' ), esc_url( 'https://developers.google.com/maps/documentation/javascript/get-api-key#get-an-api-key' ) ),
					),
					array(
						'type'        => 'attach_image',
						'heading'     => esc_html__( 'Marker', 'supro' ),
						'param_name'  => 'marker',
						'value'       => '',
						'description' => esc_html__( 'Choose an image from media library', 'supro' ),
					),
					array(
						'type'       => 'param_group',
						'heading'    => esc_html__( 'Address Infomation', 'supro' ),
						'value'      => '',
						'param_name' => 'info',
						'params'     => array(
							array(
								'type'       => 'textfield',
								'heading'    => esc_html__( 'Lat', 'supro' ),
								'param_name' => 'lat',
								'value'      => '',
							),
							array(
								'type'       => 'textfield',
								'heading'    => esc_html__( 'Lng', 'supro' ),
								'param_name' => 'lng',
								'value'      => '',
							),
							array(
								'type'        => 'textarea',
								'heading'     => esc_html__( 'Address Details', 'supro' ),
								'param_name'  => 'details',
								'admin_label' => true,
							),
						),
					),
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Width(px)', 'supro' ),
						'param_name' => 'width',
						'value'      => '',
					),
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Height(px)', 'supro' ),
						'param_name' => 'height',
						'value'      => '400',
					),
					array(
						'type'       => 'textfield',
						'heading'    => esc_html__( 'Zoom', 'supro' ),
						'param_name' => 'zoom',
						'value'      => '16',
					),
					vc_map_add_css_animation(),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'supro' ),
						'param_name'  => 'el_class',
						'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file . ', 'supro' ),
					),
				),
			)
		);
	}

	/**
	 * Suggester for autocomplete by slug
	 *
	 *
	 * @return array - id's from portfolio with title/slug.
	 */
	public function portfolioIdsAutocompleteSuggester( $query ) {
		$args = array(
			'post_type'              => 'portfolio',
			'no_found_rows'          => true,
			'update_post_term_cache' => false,
			'update_post_meta_cache' => false,
			'ignore_sticky_posts'    => true,
			's'                      => $query
		);

		$query   = new WP_Query( $args );
		$results = array();
		while ( $query->have_posts() ) : $query->the_post();
			$data          = array();
			$data['value'] = get_the_ID();
			$data['label'] = esc_html__( 'Id', 'supro' ) . ': ' . get_the_ID() . ' - ' . esc_html__( 'Title', 'supro' ) . ': ' . get_the_title();
			$results[]     = $data;

		endwhile;
		wp_reset_postdata();

		return $results;
	}

	/**
	 * Suggester for autocomplete by slug
	 *
	 *
	 * @return array - id's from portfolio cat with title/slug.
	 */
	public function portfolioCatsAutocompleteSuggester( $query ) {
		global $wpdb;
		$cat_id          = (int) $query;
		$query           = trim( $query );
		$post_meta_infos = $wpdb->get_results(
			$wpdb->prepare(
				"SELECT a.term_id AS id, b.name as name, b.slug AS slug
						FROM {$wpdb->term_taxonomy} AS a
						INNER JOIN {$wpdb->terms} AS b ON b.term_id = a.term_id
						WHERE a.taxonomy = 'portfolio_category' AND (a.term_id = '%d' OR b.slug LIKE '%%%s%%' OR b.name LIKE '%%%s%%' )", $cat_id > 0 ? $cat_id : - 1, stripslashes( $query ), stripslashes( $query )
			), ARRAY_A
		);

		$result = array();
		if ( is_array( $post_meta_infos ) && ! empty( $post_meta_infos ) ) {
			foreach ( $post_meta_infos as $value ) {
				$data          = array();
				$data['value'] = $value['slug'];
				$data['label'] = esc_html__( 'Id', 'supro' ) . ': ' . $value['id'] . ' - ' . esc_html__( 'Name', 'supro' ) . ': ' . $value['name'];
				$result[]      = $data;
			}
		}

		return $result;
	}

	/**
	 * Find portfolio cat by slug
	 * @since 4.4
	 *
	 * @param $query
	 *
	 * @return bool|array
	 */
	public function portfolioCatsAutocompleteRender( $query ) {
		$query = $query['value'];
		$query = trim( $query );
		$term  = get_term_by( 'slug', $query, 'portfolio_category' );

		if ( is_wp_error( $term ) || ! $term ) {
			return false;
		}

		$data          = array();
		$data['value'] = $term->slug;
		$data['label'] = esc_html__( 'Id', 'supro' ) . ': ' . $term->term_id . ' - ' . esc_html__( 'Name', 'supro' ) . ': ' . $term->name;


		return $data;
	}


	/**
	 * Find portfolio by id
	 * @since 4.4
	 *
	 * @param $query
	 *
	 * @return bool|array
	 */
	public function portfolioIdsAutocompleteRender( $query ) {
		$query = trim( $query['value'] ); // get value from requested

		if ( empty( $query ) ) {
			return false;
		}

		$args = array(
			'post_type'              => 'portfolio',
			'no_found_rows'          => true,
			'update_post_term_cache' => false,
			'update_post_meta_cache' => false,
			'ignore_sticky_posts'    => true,
			'p'                      => intval( $query )
		);

		$query = new WP_Query( $args );
		$data  = array();
		while ( $query->have_posts() ) : $query->the_post();
			$data['value'] = get_the_ID();
			$data['label'] = esc_html__( 'Id', 'supro' ) . ': ' . get_the_ID() . ' - ' . esc_html__( 'Title', 'supro' ) . ': ' . get_the_title();
		endwhile;
		wp_reset_postdata();

		return $data;

	}

	/**
	 * Get category for auto complete field
	 *
	 * @param string $taxonomy Taxnomy to get terms
	 *
	 * @return array
	 */
	protected function get_terms( $taxonomy = 'product_cat' ) {
		// We don't want to query all terms again
		if ( isset( $this->terms[$taxonomy] ) ) {
			return $this->terms[$taxonomy];
		}

		$cats = get_terms( $taxonomy );
		if ( ! $cats || is_wp_error( $cats ) ) {
			return array();
		}

		$categories = array();
		foreach ( $cats as $cat ) {
			$categories[] = array(
				'label' => $cat->name,
				'value' => $cat->slug,
				'group' => 'category',
			);
		}

		// Store this in order to avoid double query this
		$this->terms[$taxonomy] = $categories;

		return $categories;
	}

	/**
	 *
	 */
	function supro_custom_heading_field( $settings, $value ) {
		$class = array(
			$settings['param_name'],
			$settings['type']
		);

		return '<div class="supro_custom_heading"><h2 class="' . esc_attr( implode( ' ', $class ) ) . '" style="margin: 0;">' . $value . '</h2></div>';
	}

	/**
	 * Get icons
	 *
	 * @return array|string
	 */
	function vc_iconpicker_type_ionicons( $icons ) {
		$ionicons = array(
			array( 'ion-alert' => 'alert' ),
			array( 'ion-alert-circled' => 'alert circled' ),
			array( 'ion-android-add' => 'android add' ),
			array( 'ion-android-add-circle' => 'android add circle' ),
			array( 'ion-android-alarm-clock' => 'android alarm clock' ),
			array( 'ion-android-alert' => 'android alert' ),
			array( 'ion-android-apps' => 'android apps' ),
			array( 'ion-android-archive' => 'android archive' ),
			array( 'ion-android-arrow-back' => 'android arrow back' ),
			array( 'ion-android-arrow-down' => 'android arrow down' ),
			array( 'ion-android-arrow-dropdown' => 'android arrow dropdown' ),
			array( 'ion-android-arrow-dropdown-circle' => 'android arrow dropdown circle' ),
			array( 'ion-android-arrow-dropleft' => 'android arrow dropleft' ),
			array( 'ion-android-arrow-dropleft-circle' => 'android arrow dropleft circle' ),
			array( 'ion-android-arrow-dropright' => 'android arrow dropright' ),
			array( 'ion-android-arrow-dropright-circle' => 'android arrow dropright circle' ),
			array( 'ion-android-arrow-dropup' => 'android arrow dropup' ),
			array( 'ion-android-arrow-dropup-circle' => 'android arrow dropup circle' ),
			array( 'ion-android-arrow-forward' => 'android arrow forward' ),
			array( 'ion-android-arrow-up' => 'android arrow up' ),
			array( 'ion-android-attach' => 'android attach' ),
			array( 'ion-android-bar' => 'android bar' ),
			array( 'ion-android-bicycle' => 'android bicycle' ),
			array( 'ion-android-boat' => 'android boat' ),
			array( 'ion-android-bookmark' => 'android bookmark' ),
			array( 'ion-android-bulb' => 'android bulb' ),
			array( 'ion-android-bus' => 'android bus' ),
			array( 'ion-android-calendar' => 'android calendar' ),
			array( 'ion-android-call' => 'android call' ),
			array( 'ion-android-camera' => 'android camera' ),
			array( 'ion-android-cancel' => 'android cancel' ),
			array( 'ion-android-car' => 'android car' ),
			array( 'ion-android-cart' => 'android cart' ),
			array( 'ion-android-chat' => 'android chat' ),
			array( 'ion-android-checkbox' => 'android checkbox' ),
			array( 'ion-android-checkbox-blank' => 'android checkbox blank' ),
			array( 'ion-android-checkbox-outline' => 'android checkbox outline' ),
			array( 'ion-android-checkbox-outline-blank' => 'android checkbox outline blank' ),
			array( 'ion-android-checkmark-circle' => 'android checkmark circle' ),
			array( 'ion-android-clipboard' => 'android clipboard' ),
			array( 'ion-android-close' => 'android close' ),
			array( 'ion-android-cloud' => 'android cloud' ),
			array( 'ion-android-cloud-circle' => 'android cloud circle' ),
			array( 'ion-android-cloud-done' => 'android cloud done' ),
			array( 'ion-android-cloud-outline' => 'android cloud outline' ),
			array( 'ion-android-color-palette' => 'android color palette' ),
			array( 'ion-android-compass' => 'android compass' ),
			array( 'ion-android-contact' => 'android contact' ),
			array( 'ion-android-contacts' => 'android contacts' ),
			array( 'ion-android-contract' => 'android contract' ),
			array( 'ion-android-create' => 'android create' ),
			array( 'ion-android-delete' => 'android delete' ),
			array( 'ion-android-desktop' => 'android desktop' ),
			array( 'ion-android-document' => 'android document' ),
			array( 'ion-android-done' => 'android done' ),
			array( 'ion-android-done-all' => 'android done all' ),
			array( 'ion-android-download' => 'android download' ),
			array( 'ion-android-drafts' => 'android drafts' ),
			array( 'ion-android-exit' => 'android exit' ),
			array( 'ion-android-expand' => 'android expand' ),
			array( 'ion-android-favorite' => 'android favorite' ),
			array( 'ion-android-favorite-outline' => 'android favorite outline' ),
			array( 'ion-android-film' => 'android film' ),
			array( 'ion-android-folder' => 'android folder' ),
			array( 'ion-android-folder-open' => 'android folder open' ),
			array( 'ion-android-funnel' => 'android funnel' ),
			array( 'ion-android-globe' => 'android globe' ),
			array( 'ion-android-hand' => 'android hand' ),
			array( 'ion-android-hangout' => 'android hangout' ),
			array( 'ion-android-happy' => 'android happy' ),
			array( 'ion-android-home' => 'android home' ),
			array( 'ion-android-image' => 'android image' ),
			array( 'ion-android-laptop' => 'android laptop' ),
			array( 'ion-android-list' => 'android list' ),
			array( 'ion-android-locate' => 'android locate' ),
			array( 'ion-android-lock' => 'android lock' ),
			array( 'ion-android-mail' => 'android mail' ),
			array( 'ion-android-map' => 'android map' ),
			array( 'ion-android-menu' => 'android menu' ),
			array( 'ion-android-microphone' => 'android microphone' ),
			array( 'ion-android-microphone-off' => 'android microphone off' ),
			array( 'ion-android-more-horizontal' => 'android more horizontal' ),
			array( 'ion-android-more-vertical' => 'android more vertical' ),
			array( 'ion-android-navigate' => 'android navigate' ),
			array( 'ion-android-notifications' => 'android notifications' ),
			array( 'ion-android-notifications-none' => 'android notifications none' ),
			array( 'ion-android-notifications-off' => 'android notifications off' ),
			array( 'ion-android-open' => 'android open' ),
			array( 'ion-android-options' => 'android options' ),
			array( 'ion-android-people' => 'android people' ),
			array( 'ion-android-person' => 'android person' ),
			array( 'ion-android-person-add' => 'android person add' ),
			array( 'ion-android-phone-landscape' => 'android phone landscape' ),
			array( 'ion-android-phone-portrait' => 'android phone portrait' ),
			array( 'ion-android-pin' => 'android pin' ),
			array( 'ion-android-plane' => 'android plane' ),
			array( 'ion-android-playstore' => 'android playstore' ),
			array( 'ion-android-print' => 'android print' ),
			array( 'ion-android-radio-button-off' => 'android radio button off' ),
			array( 'ion-android-radio-button-on' => 'android radio button on' ),
			array( 'ion-android-refresh' => 'android refresh' ),
			array( 'ion-android-remove' => 'android remove' ),
			array( 'ion-android-remove-circle' => 'android remove circle' ),
			array( 'ion-android-restaurant' => 'android restaurant' ),
			array( 'ion-android-sad' => 'android sad' ),
			array( 'ion-android-search' => 'android search' ),
			array( 'ion-android-send' => 'android send' ),
			array( 'ion-android-settings' => 'android settings' ),
			array( 'ion-android-share' => 'android share' ),
			array( 'ion-android-share-alt' => 'android share alt' ),
			array( 'ion-android-star' => 'android star' ),
			array( 'ion-android-star-half' => 'android star half' ),
			array( 'ion-android-star-outline' => 'android star outline' ),
			array( 'ion-android-stopwatch' => 'android stopwatch' ),
			array( 'ion-android-subway' => 'android subway' ),
			array( 'ion-android-sunny' => 'android sunny' ),
			array( 'ion-android-sync' => 'android sync' ),
			array( 'ion-android-textsms' => 'android textsms' ),
			array( 'ion-android-time' => 'android time' ),
			array( 'ion-android-train' => 'android train' ),
			array( 'ion-android-unlock' => 'android unlock' ),
			array( 'ion-android-upload' => 'android upload' ),
			array( 'ion-android-volume-down' => 'android volume down' ),
			array( 'ion-android-volume-mute' => 'android volume mute' ),
			array( 'ion-android-volume-off' => 'android volume off' ),
			array( 'ion-android-volume-up' => 'android volume up' ),
			array( 'ion-android-walk' => 'android walk' ),
			array( 'ion-android-warning' => 'android warning' ),
			array( 'ion-android-watch' => 'android watch' ),
			array( 'ion-android-wifi' => 'android wifi' ),
			array( 'ion-aperture' => 'aperture' ),
			array( 'ion-archive' => 'archive' ),
			array( 'ion-arrow-down-a' => 'arrow down a' ),
			array( 'ion-arrow-down-b' => 'arrow down b' ),
			array( 'ion-arrow-down-c' => 'arrow down c' ),
			array( 'ion-arrow-expand' => 'arrow expand' ),
			array( 'ion-arrow-graph-down-left' => 'arrow graph down left' ),
			array( 'ion-arrow-graph-down-right' => 'arrow graph down right' ),
			array( 'ion-arrow-graph-up-left' => 'arrow graph up left' ),
			array( 'ion-arrow-graph-up-right' => 'arrow graph up right' ),
			array( 'ion-arrow-left-a' => 'arrow left a' ),
			array( 'ion-arrow-left-b' => 'arrow left b' ),
			array( 'ion-arrow-left-c' => 'arrow left c' ),
			array( 'ion-arrow-move' => 'arrow move' ),
			array( 'ion-arrow-resize' => 'arrow resize' ),
			array( 'ion-arrow-return-left' => 'arrow return left' ),
			array( 'ion-arrow-return-right' => 'arrow return right' ),
			array( 'ion-arrow-right-a' => 'arrow right a' ),
			array( 'ion-arrow-right-b' => 'arrow right b' ),
			array( 'ion-arrow-right-c' => 'arrow right c' ),
			array( 'ion-arrow-shrink' => 'arrow shrink' ),
			array( 'ion-arrow-swap' => 'arrow swap' ),
			array( 'ion-arrow-up-a' => 'arrow up a' ),
			array( 'ion-arrow-up-b' => 'arrow up b' ),
			array( 'ion-arrow-up-c' => 'arrow up c' ),
			array( 'ion-asterisk' => 'asterisk' ),
			array( 'ion-at' => 'at' ),
			array( 'ion-backspace' => 'backspace' ),
			array( 'ion-backspace-outline' => 'backspace outline' ),
			array( 'ion-bag' => 'bag' ),
			array( 'ion-battery-charging' => 'battery charging' ),
			array( 'ion-battery-empty' => 'battery empty' ),
			array( 'ion-battery-full' => 'battery full' ),
			array( 'ion-battery-half' => 'battery half' ),
			array( 'ion-battery-low' => 'battery low' ),
			array( 'ion-beaker' => 'beaker' ),
			array( 'ion-beer' => 'beer' ),
			array( 'ion-bluetooth' => 'bluetooth' ),
			array( 'ion-bonfire' => 'bonfire' ),
			array( 'ion-bookmark' => 'bookmark' ),
			array( 'ion-bowtie' => 'bowtie' ),
			array( 'ion-briefcase' => 'briefcase' ),
			array( 'ion-bug' => 'bug' ),
			array( 'ion-calculator' => 'calculator' ),
			array( 'ion-calendar' => 'calendar' ),
			array( 'ion-camera' => 'camera' ),
			array( 'ion-card' => 'card' ),
			array( 'ion-cash' => 'cash' ),
			array( 'ion-chatbox' => 'chatbox' ),
			array( 'ion-chatbox-working' => 'chatbox working' ),
			array( 'ion-chatboxes' => 'chatboxes' ),
			array( 'ion-chatbubble' => 'chatbubble' ),
			array( 'ion-chatbubble-working' => 'chatbubble working' ),
			array( 'ion-chatbubbles' => 'chatbubbles' ),
			array( 'ion-checkmark' => 'checkmark' ),
			array( 'ion-checkmark-circled' => 'checkmark circled' ),
			array( 'ion-checkmark-round' => 'checkmark round' ),
			array( 'ion-chevron-down' => 'chevron down' ),
			array( 'ion-chevron-left' => 'chevron left' ),
			array( 'ion-chevron-right' => 'chevron right' ),
			array( 'ion-chevron-up' => 'chevron up' ),
			array( 'ion-clipboard' => 'clipboard' ),
			array( 'ion-clock' => 'clock' ),
			array( 'ion-close' => 'close' ),
			array( 'ion-close-circled' => 'close circled' ),
			array( 'ion-close-round' => 'close round' ),
			array( 'ion-closed-captioning' => 'closed captioning' ),
			array( 'ion-cloud' => 'cloud' ),
			array( 'ion-code' => 'code' ),
			array( 'ion-code-download' => 'code download' ),
			array( 'ion-code-working' => 'code working' ),
			array( 'ion-coffee' => 'coffee' ),
			array( 'ion-compass' => 'compass' ),
			array( 'ion-compose' => 'compose' ),
			array( 'ion-connection-bars' => 'connectbars' ),
			array( 'ion-contrast' => 'contrast' ),
			array( 'ion-crop' => 'crop' ),
			array( 'ion-cube' => 'cube' ),
			array( 'ion-disc' => 'disc' ),
			array( 'ion-document' => 'document' ),
			array( 'ion-document-text' => 'document text' ),
			array( 'ion-drag' => 'drag' ),
			array( 'ion-earth' => 'earth' ),
			array( 'ion-easel' => 'easel' ),
			array( 'ion-edit' => 'edit' ),
			array( 'ion-egg' => 'egg' ),
			array( 'ion-eject' => 'eject' ),
			array( 'ion-email' => 'email' ),
			array( 'ion-email-unread' => 'email unread' ),
			array( 'ion-erlenmeyer-flask' => 'erlenmeyer flask' ),
			array( 'ion-erlenmeyer-flask-bubbles' => 'erlenmeyer flask bubbles' ),
			array( 'ion-eye' => 'eye' ),
			array( 'ion-eye-disabled' => 'eye disabled' ),
			array( 'ion-female' => 'female' ),
			array( 'ion-filing' => 'filing' ),
			array( 'ion-film-marker' => 'film marker' ),
			array( 'ion-fireball' => 'fireball' ),
			array( 'ion-flag' => 'flag' ),
			array( 'ion-flame' => 'flame' ),
			array( 'ion-flash' => 'flash' ),
			array( 'ion-flash-off' => 'flash off' ),
			array( 'ion-folder' => 'folder' ),
			array( 'ion-fork' => 'fork' ),
			array( 'ion-fork-repo' => 'fork repo' ),
			array( 'ion-forward' => 'forward' ),
			array( 'ion-funnel' => 'funnel' ),
			array( 'ion-gear-a' => 'gear a' ),
			array( 'ion-gear-b' => 'gear b' ),
			array( 'ion-grid' => 'grid' ),
			array( 'ion-hammer' => 'hammer' ),
			array( 'ion-happy' => 'happy' ),
			array( 'ion-happy-outline' => 'happy outline' ),
			array( 'ion-headphone' => 'headphone' ),
			array( 'ion-heart' => 'heart' ),
			array( 'ion-heart-broken' => 'heart broken' ),
			array( 'ion-help' => 'help' ),
			array( 'ion-help-buoy' => 'help buoy' ),
			array( 'ion-help-circled' => 'help circled' ),
			array( 'ion-home' => 'home' ),
			array( 'ion-icecream' => 'icecream' ),
			array( 'ion-image' => 'image' ),
			array( 'ion-images' => 'images' ),
			array( 'ion-information' => 'information' ),
			array( 'ion-information-circled' => 'informatcircled' ),
			array( 'ion-ionic' => 'ionic' ),
			array( 'ion-ios-alarm' => 'ios alarm' ),
			array( 'ion-ios-alarm-outline' => 'ios alarm outline' ),
			array( 'ion-ios-albums' => 'ios albums' ),
			array( 'ion-ios-albums-outline' => 'ios albums outline' ),
			array( 'ion-ios-americanfootball' => 'ios americanfootball' ),
			array( 'ion-ios-americanfootball-outline' => 'ios americanfootball outline' ),
			array( 'ion-ios-analytics' => 'ios analytics' ),
			array( 'ion-ios-analytics-outline' => 'ios analytics outline' ),
			array( 'ion-ios-arrow-back' => 'ios arrow back' ),
			array( 'ion-ios-arrow-down' => 'ios arrow down' ),
			array( 'ion-ios-arrow-forward' => 'ios arrow forward' ),
			array( 'ion-ios-arrow-left' => 'ios arrow left' ),
			array( 'ion-ios-arrow-right' => 'ios arrow right' ),
			array( 'ion-ios-arrow-thin-down' => 'ios arrow thin down' ),
			array( 'ion-ios-arrow-thin-left' => 'ios arrow thin left' ),
			array( 'ion-ios-arrow-thin-right' => 'ios arrow thin right' ),
			array( 'ion-ios-arrow-thin-up' => 'ios arrow thin up' ),
			array( 'ion-ios-arrow-up' => 'ios arrow up' ),
			array( 'ion-ios-at' => 'ios at' ),
			array( 'ion-ios-at-outline' => 'ios at outline' ),
			array( 'ion-ios-barcode' => 'ios barcode' ),
			array( 'ion-ios-barcode-outline' => 'ios barcode outline' ),
			array( 'ion-ios-baseball' => 'ios baseball' ),
			array( 'ion-ios-baseball-outline' => 'ios baseball outline' ),
			array( 'ion-ios-basketball' => 'ios basketball' ),
			array( 'ion-ios-basketball-outline' => 'ios basketball outline' ),
			array( 'ion-ios-bell' => 'ios bell' ),
			array( 'ion-ios-bell-outline' => 'ios bell outline' ),
			array( 'ion-ios-body' => 'ios body' ),
			array( 'ion-ios-body-outline' => 'ios body outline' ),
			array( 'ion-ios-bolt' => 'ios bolt' ),
			array( 'ion-ios-bolt-outline' => 'ios bolt outline' ),
			array( 'ion-ios-book' => 'ios book' ),
			array( 'ion-ios-book-outline' => 'ios book outline' ),
			array( 'ion-ios-bookmarks' => 'ios bookmarks' ),
			array( 'ion-ios-bookmarks-outline' => 'ios bookmarks outline' ),
			array( 'ion-ios-box' => 'ios box' ),
			array( 'ion-ios-box-outline' => 'ios box outline' ),
			array( 'ion-ios-briefcase' => 'ios briefcase' ),
			array( 'ion-ios-briefcase-outline' => 'ios briefcase outline' ),
			array( 'ion-ios-browsers' => 'ios browsers' ),
			array( 'ion-ios-browsers-outline' => 'ios browsers outline' ),
			array( 'ion-ios-calculator' => 'ios calculator' ),
			array( 'ion-ios-calculator-outline' => 'ios calculator outline' ),
			array( 'ion-ios-calendar' => 'ios calendar' ),
			array( 'ion-ios-calendar-outline' => 'ios calendar outline' ),
			array( 'ion-ios-camera' => 'ios camera' ),
			array( 'ion-ios-camera-outline' => 'ios camera outline' ),
			array( 'ion-ios-cart' => 'ios cart' ),
			array( 'ion-ios-cart-outline' => 'ios cart outline' ),
			array( 'ion-ios-chatboxes' => 'ios chatboxes' ),
			array( 'ion-ios-chatboxes-outline' => 'ios chatboxes outline' ),
			array( 'ion-ios-chatbubble' => 'ios chatbubble' ),
			array( 'ion-ios-chatbubble-outline' => 'ios chatbubble outline' ),
			array( 'ion-ios-checkmark' => 'ios checkmark' ),
			array( 'ion-ios-checkmark-empty' => 'ios checkmark empty' ),
			array( 'ion-ios-checkmark-outline' => 'ios checkmark outline' ),
			array( 'ion-ios-circle-filled' => 'ios circle filled' ),
			array( 'ion-ios-circle-outline' => 'ios circle outline' ),
			array( 'ion-ios-clock' => 'ios clock' ),
			array( 'ion-ios-clock-outline' => 'ios clock outline' ),
			array( 'ion-ios-close' => 'ios close' ),
			array( 'ion-ios-close-empty' => 'ios close empty' ),
			array( 'ion-ios-close-outline' => 'ios close outline' ),
			array( 'ion-ios-cloud' => 'ios cloud' ),
			array( 'ion-ios-cloud-download' => 'ios cloud download' ),
			array( 'ion-ios-cloud-download-outline' => 'ios cloud download outline' ),
			array( 'ion-ios-cloud-outline' => 'ios cloud outline' ),
			array( 'ion-ios-cloud-upload' => 'ios cloud upload' ),
			array( 'ion-ios-cloud-upload-outline' => 'ios cloud upload outline' ),
			array( 'ion-ios-cloudy' => 'ios cloudy' ),
			array( 'ion-ios-cloudy-night' => 'ios cloudy night' ),
			array( 'ion-ios-cloudy-night-outline' => 'ios cloudy night outline' ),
			array( 'ion-ios-cloudy-outline' => 'ios cloudy outline' ),
			array( 'ion-ios-cog' => 'ios cog' ),
			array( 'ion-ios-cog-outline' => 'ios cog outline' ),
			array( 'ion-ios-color-filter' => 'ios color filter' ),
			array( 'ion-ios-color-filter-outline' => 'ios color filter outline' ),
			array( 'ion-ios-color-wand' => 'ios color wand' ),
			array( 'ion-ios-color-wand-outline' => 'ios color wand outline' ),
			array( 'ion-ios-compose' => 'ios compose' ),
			array( 'ion-ios-compose-outline' => 'ios compose outline' ),
			array( 'ion-ios-contact' => 'ios contact' ),
			array( 'ion-ios-contact-outline' => 'ios contact outline' ),
			array( 'ion-ios-copy' => 'ios copy' ),
			array( 'ion-ios-copy-outline' => 'ios copy outline' ),
			array( 'ion-ios-crop' => 'ios crop' ),
			array( 'ion-ios-crop-strong' => 'ios crop strong' ),
			array( 'ion-ios-download' => 'ios download' ),
			array( 'ion-ios-download-outline' => 'ios download outline' ),
			array( 'ion-ios-drag' => 'ios drag' ),
			array( 'ion-ios-email' => 'ios email' ),
			array( 'ion-ios-email-outline' => 'ios email outline' ),
			array( 'ion-ios-eye' => 'ios eye' ),
			array( 'ion-ios-eye-outline' => 'ios eye outline' ),
			array( 'ion-ios-fastforward' => 'ios fastforward' ),
			array( 'ion-ios-fastforward-outline' => 'ios fastforward outline' ),
			array( 'ion-ios-filing' => 'ios filing' ),
			array( 'ion-ios-filing-outline' => 'ios filing outline' ),
			array( 'ion-ios-film' => 'ios film' ),
			array( 'ion-ios-film-outline' => 'ios film outline' ),
			array( 'ion-ios-flag' => 'ios flag' ),
			array( 'ion-ios-flag-outline' => 'ios flag outline' ),
			array( 'ion-ios-flame' => 'ios flame' ),
			array( 'ion-ios-flame-outline' => 'ios flame outline' ),
			array( 'ion-ios-flask' => 'ios flask' ),
			array( 'ion-ios-flask-outline' => 'ios flask outline' ),
			array( 'ion-ios-flower' => 'ios flower' ),
			array( 'ion-ios-flower-outline' => 'ios flower outline' ),
			array( 'ion-ios-folder' => 'ios folder' ),
			array( 'ion-ios-folder-outline' => 'ios folder outline' ),
			array( 'ion-ios-football' => 'ios football' ),
			array( 'ion-ios-football-outline' => 'ios football outline' ),
			array( 'ion-ios-game-controller-a' => 'ios game controller a' ),
			array( 'ion-ios-game-controller-a-outline' => 'ios game controller a outline' ),
			array( 'ion-ios-game-controller-b' => 'ios game controller b' ),
			array( 'ion-ios-game-controller-b-outline' => 'ios game controller b outline' ),
			array( 'ion-ios-gear' => 'ios gear' ),
			array( 'ion-ios-gear-outline' => 'ios gear outline' ),
			array( 'ion-ios-glasses' => 'ios glasses' ),
			array( 'ion-ios-glasses-outline' => 'ios glasses outline' ),
			array( 'ion-ios-grid-view' => 'ios grid view' ),
			array( 'ion-ios-grid-view-outline' => 'ios grid view outline' ),
			array( 'ion-ios-heart' => 'ios heart' ),
			array( 'ion-ios-heart-outline' => 'ios heart outline' ),
			array( 'ion-ios-help' => 'ios help' ),
			array( 'ion-ios-help-empty' => 'ios help empty' ),
			array( 'ion-ios-help-outline' => 'ios help outline' ),
			array( 'ion-ios-home' => 'ios home' ),
			array( 'ion-ios-home-outline' => 'ios home outline' ),
			array( 'ion-ios-infinite' => 'ios infinite' ),
			array( 'ion-ios-infinite-outline' => 'ios infinite outline' ),
			array( 'ion-ios-information' => 'ios information' ),
			array( 'ion-ios-information-empty' => 'ios informatempty' ),
			array( 'ion-ios-information-outline' => 'ios informatoutline' ),
			array( 'ion-ios-ionic-outline' => 'ios ionic outline' ),
			array( 'ion-ios-keypad' => 'ios keypad' ),
			array( 'ion-ios-keypad-outline' => 'ios keypad outline' ),
			array( 'ion-ios-lightbulb' => 'ios lightbulb' ),
			array( 'ion-ios-lightbulb-outline' => 'ios lightbulb outline' ),
			array( 'ion-ios-list' => 'ios list' ),
			array( 'ion-ios-list-outline' => 'ios list outline' ),
			array( 'ion-ios-location' => 'ios location' ),
			array( 'ion-ios-location-outline' => 'ios locatoutline' ),
			array( 'ion-ios-locked' => 'ios locked' ),
			array( 'ion-ios-locked-outline' => 'ios locked outline' ),
			array( 'ion-ios-loop' => 'ios loop' ),
			array( 'ion-ios-loop-strong' => 'ios loop strong' ),
			array( 'ion-ios-medical' => 'ios medical' ),
			array( 'ion-ios-medical-outline' => 'ios medical outline' ),
			array( 'ion-ios-medkit' => 'ios medkit' ),
			array( 'ion-ios-medkit-outline' => 'ios medkit outline' ),
			array( 'ion-ios-mic' => 'ios mic' ),
			array( 'ion-ios-mic-off' => 'ios mic off' ),
			array( 'ion-ios-mic-outline' => 'ios mic outline' ),
			array( 'ion-ios-minus' => 'ios minus' ),
			array( 'ion-ios-minus-empty' => 'ios minus empty' ),
			array( 'ion-ios-minus-outline' => 'ios minus outline' ),
			array( 'ion-ios-monitor' => 'ios monitor' ),
			array( 'ion-ios-monitor-outline' => 'ios monitor outline' ),
			array( 'ion-ios-moon' => 'ios moon' ),
			array( 'ion-ios-moon-outline' => 'ios moon outline' ),
			array( 'ion-ios-more' => 'ios more' ),
			array( 'ion-ios-more-outline' => 'ios more outline' ),
			array( 'ion-ios-musical-note' => 'ios musical note' ),
			array( 'ion-ios-musical-notes' => 'ios musical notes' ),
			array( 'ion-ios-navigate' => 'ios navigate' ),
			array( 'ion-ios-navigate-outline' => 'ios navigate outline' ),
			array( 'ion-ios-nutrition' => 'ios nutrition' ),
			array( 'ion-ios-nutrition-outline' => 'ios nutritoutline' ),
			array( 'ion-ios-paper' => 'ios paper' ),
			array( 'ion-ios-paper-outline' => 'ios paper outline' ),
			array( 'ion-ios-paperplane' => 'ios paperplane' ),
			array( 'ion-ios-paperplane-outline' => 'ios paperplane outline' ),
			array( 'ion-ios-partlysunny' => 'ios partlysunny' ),
			array( 'ion-ios-partlysunny-outline' => 'ios partlysunny outline' ),
			array( 'ion-ios-pause' => 'ios pause' ),
			array( 'ion-ios-pause-outline' => 'ios pause outline' ),
			array( 'ion-ios-paw' => 'ios paw' ),
			array( 'ion-ios-paw-outline' => 'ios paw outline' ),
			array( 'ion-ios-people' => 'ios people' ),
			array( 'ion-ios-people-outline' => 'ios people outline' ),
			array( 'ion-ios-person' => 'ios person' ),
			array( 'ion-ios-person-outline' => 'ios person outline' ),
			array( 'ion-ios-personadd' => 'ios personadd' ),
			array( 'ion-ios-personadd-outline' => 'ios personadd outline' ),
			array( 'ion-ios-photos' => 'ios photos' ),
			array( 'ion-ios-photos-outline' => 'ios photos outline' ),
			array( 'ion-ios-pie' => 'ios pie' ),
			array( 'ion-ios-pie-outline' => 'ios pie outline' ),
			array( 'ion-ios-pint' => 'ios pint' ),
			array( 'ion-ios-pint-outline' => 'ios pint outline' ),
			array( 'ion-ios-play' => 'ios play' ),
			array( 'ion-ios-play-outline' => 'ios play outline' ),
			array( 'ion-ios-plus' => 'ios plus' ),
			array( 'ion-ios-plus-empty' => 'ios plus empty' ),
			array( 'ion-ios-plus-outline' => 'ios plus outline' ),
			array( 'ion-ios-pricetag' => 'ios pricetag' ),
			array( 'ion-ios-pricetag-outline' => 'ios pricetag outline' ),
			array( 'ion-ios-pricetags' => 'ios pricetags' ),
			array( 'ion-ios-pricetags-outline' => 'ios pricetags outline' ),
			array( 'ion-ios-printer' => 'ios printer' ),
			array( 'ion-ios-printer-outline' => 'ios printer outline' ),
			array( 'ion-ios-pulse' => 'ios pulse' ),
			array( 'ion-ios-pulse-strong' => 'ios pulse strong' ),
			array( 'ion-ios-rainy' => 'ios rainy' ),
			array( 'ion-ios-rainy-outline' => 'ios rainy outline' ),
			array( 'ion-ios-recording' => 'ios recording' ),
			array( 'ion-ios-recording-outline' => 'ios recording outline' ),
			array( 'ion-ios-redo' => 'ios redo' ),
			array( 'ion-ios-redo-outline' => 'ios redo outline' ),
			array( 'ion-ios-refresh' => 'ios refresh' ),
			array( 'ion-ios-refresh-empty' => 'ios refresh empty' ),
			array( 'ion-ios-refresh-outline' => 'ios refresh outline' ),
			array( 'ion-ios-reload' => 'ios reload' ),
			array( 'ion-ios-reverse-camera' => 'ios reverse camera' ),
			array( 'ion-ios-reverse-camera-outline' => 'ios reverse camera outline' ),
			array( 'ion-ios-rewind' => 'ios rewind' ),
			array( 'ion-ios-rewind-outline' => 'ios rewind outline' ),
			array( 'ion-ios-rose' => 'ios rose' ),
			array( 'ion-ios-rose-outline' => 'ios rose outline' ),
			array( 'ion-ios-search' => 'ios search' ),
			array( 'ion-ios-search-strong' => 'ios search strong' ),
			array( 'ion-ios-settings' => 'ios settings' ),
			array( 'ion-ios-settings-strong' => 'ios settings strong' ),
			array( 'ion-ios-shuffle' => 'ios shuffle' ),
			array( 'ion-ios-shuffle-strong' => 'ios shuffle strong' ),
			array( 'ion-ios-skipbackward' => 'ios skipbackward' ),
			array( 'ion-ios-skipbackward-outline' => 'ios skipbackward outline' ),
			array( 'ion-ios-skipforward' => 'ios skipforward' ),
			array( 'ion-ios-skipforward-outline' => 'ios skipforward outline' ),
			array( 'ion-ios-snowy' => 'ios snowy' ),
			array( 'ion-ios-speedometer' => 'ios speedometer' ),
			array( 'ion-ios-speedometer-outline' => 'ios speedometer outline' ),
			array( 'ion-ios-star' => 'ios star' ),
			array( 'ion-ios-star-half' => 'ios star half' ),
			array( 'ion-ios-star-outline' => 'ios star outline' ),
			array( 'ion-ios-stopwatch' => 'ios stopwatch' ),
			array( 'ion-ios-stopwatch-outline' => 'ios stopwatch outline' ),
			array( 'ion-ios-sunny' => 'ios sunny' ),
			array( 'ion-ios-sunny-outline' => 'ios sunny outline' ),
			array( 'ion-ios-telephone' => 'ios telephone' ),
			array( 'ion-ios-telephone-outline' => 'ios telephone outline' ),
			array( 'ion-ios-tennisball' => 'ios tennisball' ),
			array( 'ion-ios-tennisball-outline' => 'ios tennisball outline' ),
			array( 'ion-ios-thunderstorm' => 'ios thunderstorm' ),
			array( 'ion-ios-thunderstorm-outline' => 'ios thunderstorm outline' ),
			array( 'ion-ios-time' => 'ios time' ),
			array( 'ion-ios-time-outline' => 'ios time outline' ),
			array( 'ion-ios-timer' => 'ios timer' ),
			array( 'ion-ios-timer-outline' => 'ios timer outline' ),
			array( 'ion-ios-toggle' => 'ios toggle' ),
			array( 'ion-ios-toggle-outline' => 'ios toggle outline' ),
			array( 'ion-ios-trash' => 'ios trash' ),
			array( 'ion-ios-trash-outline' => 'ios trash outline' ),
			array( 'ion-ios-undo' => 'ios undo' ),
			array( 'ion-ios-undo-outline' => 'ios undo outline' ),
			array( 'ion-ios-unlocked' => 'ios unlocked' ),
			array( 'ion-ios-unlocked-outline' => 'ios unlocked outline' ),
			array( 'ion-ios-upload' => 'ios upload' ),
			array( 'ion-ios-upload-outline' => 'ios upload outline' ),
			array( 'ion-ios-videocam' => 'ios videocam' ),
			array( 'ion-ios-videocam-outline' => 'ios videocam outline' ),
			array( 'ion-ios-volume-high' => 'ios volume high' ),
			array( 'ion-ios-volume-low' => 'ios volume low' ),
			array( 'ion-ios-wineglass' => 'ios wineglass' ),
			array( 'ion-ios-wineglass-outline' => 'ios wineglass outline' ),
			array( 'ion-ios-world' => 'ios world' ),
			array( 'ion-ios-world-outline' => 'ios world outline' ),
			array( 'ion-ipad' => 'ipad' ),
			array( 'ion-iphone' => 'iphone' ),
			array( 'ion-ipod' => 'ipod' ),
			array( 'ion-jet' => 'jet' ),
			array( 'ion-key' => 'key' ),
			array( 'ion-knife' => 'knife' ),
			array( 'ion-laptop' => 'laptop' ),
			array( 'ion-leaf' => 'leaf' ),
			array( 'ion-levels' => 'levels' ),
			array( 'ion-lightbulb' => 'lightbulb' ),
			array( 'ion-link' => 'link' ),
			array( 'ion-load-a' => 'load a' ),
			array( 'ion-load-b' => 'load b' ),
			array( 'ion-load-c' => 'load c' ),
			array( 'ion-load-d' => 'load d' ),
			array( 'ion-location' => 'location' ),
			array( 'ion-lock-combination' => 'lock combination' ),
			array( 'ion-locked' => 'locked' ),
			array( 'ion-log-in' => 'log in' ),
			array( 'ion-log-out' => 'log out' ),
			array( 'ion-loop' => 'loop' ),
			array( 'ion-magnet' => 'magnet' ),
			array( 'ion-male' => 'male' ),
			array( 'ion-man' => 'man' ),
			array( 'ion-map' => 'map' ),
			array( 'ion-medkit' => 'medkit' ),
			array( 'ion-merge' => 'merge' ),
			array( 'ion-mic-a' => 'mic a' ),
			array( 'ion-mic-b' => 'mic b' ),
			array( 'ion-mic-c' => 'mic c' ),
			array( 'ion-minus' => 'minus' ),
			array( 'ion-minus-circled' => 'minus circled' ),
			array( 'ion-minus-round' => 'minus round' ),
			array( 'ion-model-s' => 'model s' ),
			array( 'ion-monitor' => 'monitor' ),
			array( 'ion-more' => 'more' ),
			array( 'ion-mouse' => 'mouse' ),
			array( 'ion-music-note' => 'music note' ),
			array( 'ion-navicon' => 'navicon' ),
			array( 'ion-navicon-round' => 'navicon round' ),
			array( 'ion-navigate' => 'navigate' ),
			array( 'ion-network' => 'network' ),
			array( 'ion-no-smoking' => 'no smoking' ),
			array( 'ion-nuclear' => 'nuclear' ),
			array( 'ion-outlet' => 'outlet' ),
			array( 'ion-paintbrush' => 'paintbrush' ),
			array( 'ion-paintbucket' => 'paintbucket' ),
			array( 'ion-paper-airplane' => 'paper airplane' ),
			array( 'ion-paperclip' => 'paperclip' ),
			array( 'ion-pause' => 'pause' ),
			array( 'ion-person' => 'person' ),
			array( 'ion-person-add' => 'person add' ),
			array( 'ion-person-stalker' => 'person stalker' ),
			array( 'ion-pie-graph' => 'pie graph' ),
			array( 'ion-pin' => 'pin' ),
			array( 'ion-pinpoint' => 'pinpoint' ),
			array( 'ion-pizza' => 'pizza' ),
			array( 'ion-plane' => 'plane' ),
			array( 'ion-planet' => 'planet' ),
			array( 'ion-play' => 'play' ),
			array( 'ion-playstation' => 'playstation' ),
			array( 'ion-plus' => 'plus' ),
			array( 'ion-plus-circled' => 'plus circled' ),
			array( 'ion-plus-round' => 'plus round' ),
			array( 'ion-podium' => 'podium' ),
			array( 'ion-pound' => 'pound' ),
			array( 'ion-power' => 'power' ),
			array( 'ion-pricetag' => 'pricetag' ),
			array( 'ion-pricetags' => 'pricetags' ),
			array( 'ion-printer' => 'printer' ),
			array( 'ion-pull-request' => 'pull request' ),
			array( 'ion-qr-scanner' => 'qr scanner' ),
			array( 'ion-quote' => 'quote' ),
			array( 'ion-radio-waves' => 'radio waves' ),
			array( 'ion-record' => 'record' ),
			array( 'ion-refresh' => 'refresh' ),
			array( 'ion-reply' => 'reply' ),
			array( 'ion-reply-all' => 'reply all' ),
			array( 'ion-ribbon-a' => 'ribbon a' ),
			array( 'ion-ribbon-b' => 'ribbon b' ),
			array( 'ion-sad' => 'sad' ),
			array( 'ion-sad-outline' => 'sad outline' ),
			array( 'ion-scissors' => 'scissors' ),
			array( 'ion-search' => 'search' ),
			array( 'ion-settings' => 'settings' ),
			array( 'ion-share' => 'share' ),
			array( 'ion-shuffle' => 'shuffle' ),
			array( 'ion-skip-backward' => 'skip backward' ),
			array( 'ion-skip-forward' => 'skip forward' ),
			array( 'ion-social-android' => 'social android' ),
			array( 'ion-social-android-outline' => 'social android outline' ),
			array( 'ion-social-angular' => 'social angular' ),
			array( 'ion-social-angular-outline' => 'social angular outline' ),
			array( 'ion-social-apple' => 'social apple' ),
			array( 'ion-social-apple-outline' => 'social apple outline' ),
			array( 'ion-social-bitcoin' => 'social bitcoin' ),
			array( 'ion-social-bitcoin-outline' => 'social bitcoin outline' ),
			array( 'ion-social-buffer' => 'social buffer' ),
			array( 'ion-social-buffer-outline' => 'social buffer outline' ),
			array( 'ion-social-chrome' => 'social chrome' ),
			array( 'ion-social-chrome-outline' => 'social chrome outline' ),
			array( 'ion-social-codepen' => 'social codepen' ),
			array( 'ion-social-codepen-outline' => 'social codepen outline' ),
			array( 'ion-social-css3' => 'social css3' ),
			array( 'ion-social-css3-outline' => 'social css3 outline' ),
			array( 'ion-social-designernews' => 'social designernews' ),
			array( 'ion-social-designernews-outline' => 'social designernews outline' ),
			array( 'ion-social-dribbble' => 'social dribbble' ),
			array( 'ion-social-dribbble-outline' => 'social dribbble outline' ),
			array( 'ion-social-dropbox' => 'social dropbox' ),
			array( 'ion-social-dropbox-outline' => 'social dropbox outline' ),
			array( 'ion-social-euro' => 'social euro' ),
			array( 'ion-social-euro-outline' => 'social euro outline' ),
			array( 'ion-social-facebook' => 'social facebook' ),
			array( 'ion-social-facebook-outline' => 'social facebook outline' ),
			array( 'ion-social-foursquare' => 'social foursquare' ),
			array( 'ion-social-foursquare-outline' => 'social foursquare outline' ),
			array( 'ion-social-freebsd-devil' => 'social freebsd devil' ),
			array( 'ion-social-github' => 'social github' ),
			array( 'ion-social-github-outline' => 'social github outline' ),
			array( 'ion-social-google' => 'social google' ),
			array( 'ion-social-google-outline' => 'social google outline' ),
			array( 'ion-social-googleplus' => 'social googleplus' ),
			array( 'ion-social-googleplus-outline' => 'social googleplus outline' ),
			array( 'ion-social-hackernews' => 'social hackernews' ),
			array( 'ion-social-hackernews-outline' => 'social hackernews outline' ),
			array( 'ion-social-html5' => 'social html5' ),
			array( 'ion-social-html5-outline' => 'social html5 outline' ),
			array( 'ion-social-instagram' => 'social instagram' ),
			array( 'ion-social-instagram-outline' => 'social instagram outline' ),
			array( 'ion-social-javascript' => 'social javascript' ),
			array( 'ion-social-javascript-outline' => 'social javascript outline' ),
			array( 'ion-social-linkedin' => 'social linkedin' ),
			array( 'ion-social-linkedin-outline' => 'social linkedin outline' ),
			array( 'ion-social-markdown' => 'social markdown' ),
			array( 'ion-social-nodejs' => 'social nodejs' ),
			array( 'ion-social-octocat' => 'social octocat' ),
			array( 'ion-social-pinterest' => 'social pinterest' ),
			array( 'ion-social-pinterest-outline' => 'social pinterest outline' ),
			array( 'ion-social-python' => 'social python' ),
			array( 'ion-social-reddit' => 'social reddit' ),
			array( 'ion-social-reddit-outline' => 'social reddit outline' ),
			array( 'ion-social-rss' => 'social rss' ),
			array( 'ion-social-rss-outline' => 'social rss outline' ),
			array( 'ion-social-sass' => 'social sass' ),
			array( 'ion-social-skype' => 'social skype' ),
			array( 'ion-social-skype-outline' => 'social skype outline' ),
			array( 'ion-social-snapchat' => 'social snapchat' ),
			array( 'ion-social-snapchat-outline' => 'social snapchat outline' ),
			array( 'ion-social-tumblr' => 'social tumblr' ),
			array( 'ion-social-tumblr-outline' => 'social tumblr outline' ),
			array( 'ion-social-tux' => 'social tux' ),
			array( 'ion-social-twitch' => 'social twitch' ),
			array( 'ion-social-twitch-outline' => 'social twitch outline' ),
			array( 'ion-social-twitter' => 'social twitter' ),
			array( 'ion-social-twitter-outline' => 'social twitter outline' ),
			array( 'ion-social-usd' => 'social usd' ),
			array( 'ion-social-usd-outline' => 'social usd outline' ),
			array( 'ion-social-vimeo' => 'social vimeo' ),
			array( 'ion-social-vimeo-outline' => 'social vimeo outline' ),
			array( 'ion-social-whatsapp' => 'social whatsapp' ),
			array( 'ion-social-whatsapp-outline' => 'social whatsapp outline' ),
			array( 'ion-social-windows' => 'social windows' ),
			array( 'ion-social-windows-outline' => 'social windows outline' ),
			array( 'ion-social-wordpress' => 'social wordpress' ),
			array( 'ion-social-wordpress-outline' => 'social wordpress outline' ),
			array( 'ion-social-yahoo' => 'social yahoo' ),
			array( 'ion-social-yahoo-outline' => 'social yahoo outline' ),
			array( 'ion-social-yen' => 'social yen' ),
			array( 'ion-social-yen-outline' => 'social yen outline' ),
			array( 'ion-social-youtube' => 'social youtube' ),
			array( 'ion-social-youtube-outline' => 'social youtube outline' ),
			array( 'ion-soup-can' => 'soup can' ),
			array( 'ion-soup-can-outline' => 'soup can outline' ),
			array( 'ion-speakerphone' => 'speakerphone' ),
			array( 'ion-speedometer' => 'speedometer' ),
			array( 'ion-spoon' => 'spoon' ),
			array( 'ion-star' => 'star' ),
			array( 'ion-stats-bars' => 'stats bars' ),
			array( 'ion-steam' => 'steam' ),
			array( 'ion-stop' => 'stop' ),
			array( 'ion-thermometer' => 'thermometer' ),
			array( 'ion-thumbsdown' => 'thumbsdown' ),
			array( 'ion-thumbsup' => 'thumbsup' ),
			array( 'ion-toggle' => 'toggle' ),
			array( 'ion-toggle-filled' => 'toggle filled' ),
			array( 'ion-transgender' => 'transgender' ),
			array( 'ion-trash-a' => 'trash a' ),
			array( 'ion-trash-b' => 'trash b' ),
			array( 'ion-trophy' => 'trophy' ),
			array( 'ion-tshirt' => 'tshirt' ),
			array( 'ion-tshirt-outline' => 'tshirt outline' ),
			array( 'ion-umbrella' => 'umbrella' ),
			array( 'ion-university' => 'university' ),
			array( 'ion-unlocked' => 'unlocked' ),
			array( 'ion-upload' => 'upload' ),
			array( 'ion-usb' => 'usb' ),
			array( 'ion-videocamera' => 'videocamera' ),
			array( 'ion-volume-high' => 'volume high' ),
			array( 'ion-volume-low' => 'volume low' ),
			array( 'ion-volume-medium' => 'volume medium' ),
			array( 'ion-volume-mute' => 'volume mute' ),
			array( 'ion-wand' => 'wand' ),
			array( 'ion-waterdrop' => 'waterdrop' ),
			array( 'ion-wifi' => 'wifi' ),
			array( 'ion-wineglass' => 'wineglass' ),
			array( 'ion-woman' => 'woman' ),
			array( 'ion-wrench' => 'wrench' ),
			array( 'ion-xbox' => 'xbox' ),
		);

		return array_merge( $icons, array( $ionicons ) );
	}

	function vc_iconpicker_type_linearicons( $icons ) {
		$linearicons = array(
			array( 'icon-home' => 'home' ),
			array( 'icon-home2' => 'home2' ),
			array( 'icon-home3' => 'home3' ),
			array( 'icon-home4' => 'home4' ),
			array( 'icon-home5' => 'home5' ),
			array( 'icon-home6' => 'home6' ),
			array( 'icon-bathtub' => 'bathtub' ),
			array( 'icon-toothbrush' => 'toothbrush' ),
			array( 'icon-bed' => 'bed' ),
			array( 'icon-couch' => 'couch' ),
			array( 'icon-chair' => 'chair' ),
			array( 'icon-city' => 'city' ),
			array( 'icon-apartment' => 'apartment' ),
			array( 'icon-pencil' => 'pencil' ),
			array( 'icon-pencil2' => 'pencil2' ),
			array( 'icon-pen' => 'pen' ),
			array( 'icon-pencil3' => 'pencil3' ),
			array( 'icon-eraser' => 'eraser' ),
			array( 'icon-pencil4' => 'pencil4' ),
			array( 'icon-pencil5' => 'pencil5' ),
			array( 'icon-feather' => 'feather' ),
			array( 'icon-feather2' => 'feather2' ),
			array( 'icon-feather3' => 'feather3' ),
			array( 'icon-pen2' => 'pen2' ),
			array( 'icon-pen-add' => 'pen-add' ),
			array( 'icon-pen-remove' => 'pen-remove' ),
			array( 'icon-vector' => 'vector' ),
			array( 'icon-pen3' => 'pen3' ),
			array( 'icon-blog' => 'blog' ),
			array( 'icon-brush' => 'brush' ),
			array( 'icon-brush2' => 'brush2' ),
			array( 'icon-spray' => 'spray' ),
			array( 'icon-paint-roller' => 'paint-roller' ),
			array( 'icon-stamp' => 'stamp' ),
			array( 'icon-tape' => 'tape' ),
			array( 'icon-desk-tape' => 'desk-tape' ),
			array( 'icon-texture' => 'texture' ),
			array( 'icon-eye-dropper' => 'eye-dropper' ),
			array( 'icon-palette' => 'palette' ),
			array( 'icon-color-sampler' => 'color-sampler' ),
			array( 'icon-bucket' => 'bucket' ),
			array( 'icon-gradient' => 'gradient' ),
			array( 'icon-gradient2' => 'gradient2' ),
			array( 'icon-magic-wand' => 'magic-wand' ),
			array( 'icon-magnet' => 'magnet' ),
			array( 'icon-pencil-ruler' => 'pencil-ruler' ),
			array( 'icon-pencil-ruler2' => 'pencil-ruler2' ),
			array( 'icon-compass' => 'compass' ),
			array( 'icon-aim' => 'aim' ),
			array( 'icon-gun' => 'gun' ),
			array( 'icon-bottle' => 'bottle' ),
			array( 'icon-drop' => 'drop' ),
			array( 'icon-drop-crossed' => 'drop-crossed' ),
			array( 'icon-drop2' => 'drop2' ),
			array( 'icon-snow' => 'snow' ),
			array( 'icon-snow2' => 'snow2' ),
			array( 'icon-fire' => 'fire' ),
			array( 'icon-lighter' => 'lighter' ),
			array( 'icon-knife' => 'knife' ),
			array( 'icon-dagger' => 'dagger' ),
			array( 'icon-tissue' => 'tissue' ),
			array( 'icon-toilet-paper' => 'toilet-paper' ),
			array( 'icon-poop' => 'poop' ),
			array( 'icon-umbrella' => 'umbrella' ),
			array( 'icon-umbrella2' => 'umbrella2' ),
			array( 'icon-rain' => 'rain' ),
			array( 'icon-tornado' => 'tornado' ),
			array( 'icon-wind' => 'wind' ),
			array( 'icon-fan' => 'fan' ),
			array( 'icon-contrast' => 'contrast' ),
			array( 'icon-sun-small' => 'sun-small' ),
			array( 'icon-sun' => 'sun' ),
			array( 'icon-sun2' => 'sun2' ),
			array( 'icon-moon' => 'moon' ),
			array( 'icon-cloud' => 'cloud' ),
			array( 'icon-cloud-upload' => 'cloud-upload' ),
			array( 'icon-cloud-download' => 'cloud-download' ),
			array( 'icon-cloud-rain' => 'cloud-rain' ),
			array( 'icon-cloud-hailstones' => 'cloud-hailstones' ),
			array( 'icon-cloud-snow' => 'cloud-snow' ),
			array( 'icon-cloud-windy' => 'cloud-windy' ),
			array( 'icon-sun-wind' => 'sun-wind' ),
			array( 'icon-cloud-fog' => 'cloud-fog' ),
			array( 'icon-cloud-sun' => 'cloud-sun' ),
			array( 'icon-cloud-lightning' => 'cloud-lightning' ),
			array( 'icon-cloud-sync' => 'cloud-sync' ),
			array( 'icon-cloud-lock' => 'cloud-lock' ),
			array( 'icon-cloud-gear' => 'cloud-gear' ),
			array( 'icon-cloud-alert' => 'cloud-alert' ),
			array( 'icon-cloud-check' => 'cloud-check' ),
			array( 'icon-cloud-cross' => 'cloud-cross' ),
			array( 'icon-cloud-crossed' => 'cloud-crossed' ),
			array( 'icon-cloud-database' => 'cloud-database' ),
			array( 'icon-database' => 'database' ),
			array( 'icon-database-add' => 'database-add' ),
			array( 'icon-database-remove' => 'database-remove' ),
			array( 'icon-database-lock' => 'database-lock' ),
			array( 'icon-database-refresh' => 'database-refresh' ),
			array( 'icon-database-check' => 'database-check' ),
			array( 'icon-database-history' => 'database-history' ),
			array( 'icon-database-upload' => 'database-upload' ),
			array( 'icon-database-download' => 'database-download' ),
			array( 'icon-server' => 'server' ),
			array( 'icon-shield' => 'shield' ),
			array( 'icon-shield-check' => 'shield-check' ),
			array( 'icon-shield-alert' => 'shield-alert' ),
			array( 'icon-shield-cross' => 'shield-cross' ),
			array( 'icon-lock' => 'lock' ),
			array( 'icon-rotation-lock' => 'rotation-lock' ),
			array( 'icon-unlock' => 'unlock' ),
			array( 'icon-key' => 'key' ),
			array( 'icon-key-hole' => 'key-hole' ),
			array( 'icon-toggle-off' => 'toggle-off' ),
			array( 'icon-toggle-on' => 'toggle-on' ),
			array( 'icon-cog' => 'cog' ),
			array( 'icon-cog2' => 'cog2' ),
			array( 'icon-wrench' => 'wrench' ),
			array( 'icon-screwdriver' => 'screwdriver' ),
			array( 'icon-hammer-wrench' => 'hammer-wrench' ),
			array( 'icon-hammer' => 'hammer' ),
			array( 'icon-saw' => 'saw' ),
			array( 'icon-axe' => 'axe' ),
			array( 'icon-axe2' => 'axe2' ),
			array( 'icon-shovel' => 'shovel' ),
			array( 'icon-pickaxe' => 'pickaxe' ),
			array( 'icon-factory' => 'factory' ),
			array( 'icon-factory2' => 'factory2' ),
			array( 'icon-recycle' => 'recycle' ),
			array( 'icon-trash' => 'trash' ),
			array( 'icon-trash2' => 'trash2' ),
			array( 'icon-trash3' => 'trash3' ),
			array( 'icon-broom' => 'broom' ),
			array( 'icon-game' => 'game' ),
			array( 'icon-gamepad' => 'gamepad' ),
			array( 'icon-joystick' => 'joystick' ),
			array( 'icon-dice' => 'dice' ),
			array( 'icon-spades' => 'spades' ),
			array( 'icon-diamonds' => 'diamonds' ),
			array( 'icon-clubs' => 'clubs' ),
			array( 'icon-hearts' => 'hearts' ),
			array( 'icon-heart' => 'heart' ),
			array( 'icon-star' => 'star' ),
			array( 'icon-star-half' => 'star-half' ),
			array( 'icon-star-empty' => 'star-empty' ),
			array( 'icon-flag' => 'flag' ),
			array( 'icon-flag2' => 'flag2' ),
			array( 'icon-flag3' => 'flag3' ),
			array( 'icon-mailbox-full' => 'mailbox-full' ),
			array( 'icon-mailbox-empty' => 'mailbox-empty' ),
			array( 'icon-at-sign' => 'at-sign' ),
			array( 'icon-envelope' => 'envelope' ),
			array( 'icon-envelope-open' => 'envelope-open' ),
			array( 'icon-paperclip' => 'paperclip' ),
			array( 'icon-paper-plane' => 'paper-plane' ),
			array( 'icon-reply' => 'reply' ),
			array( 'icon-reply-all' => 'reply-all' ),
			array( 'icon-inbox' => 'inbox' ),
			array( 'icon-inbox2' => 'inbox2' ),
			array( 'icon-outbox' => 'outbox' ),
			array( 'icon-box' => 'box' ),
			array( 'icon-archive' => 'archive' ),
			array( 'icon-archive2' => 'archive2' ),
			array( 'icon-drawers' => 'drawers' ),
			array( 'icon-drawers2' => 'drawers2' ),
			array( 'icon-drawers3' => 'drawers3' ),
			array( 'icon-eye' => 'eye' ),
			array( 'icon-eye-crossed' => 'eye-crossed' ),
			array( 'icon-eye-plus' => 'eye-plus' ),
			array( 'icon-eye-minus' => 'eye-minus' ),
			array( 'icon-binoculars' => 'binoculars' ),
			array( 'icon-binoculars2' => 'binoculars2' ),
			array( 'icon-hdd' => 'hdd' ),
			array( 'icon-hdd-down' => 'hdd-down' ),
			array( 'icon-hdd-up' => 'hdd-up' ),
			array( 'icon-floppy-disk' => 'floppy-disk' ),
			array( 'icon-disc' => 'disc' ),
			array( 'icon-tape2' => 'tape2' ),
			array( 'icon-printer' => 'printer' ),
			array( 'icon-shredder' => 'shredder' ),
			array( 'icon-file-empty' => 'file-empty' ),
			array( 'icon-file-add' => 'file-add' ),
			array( 'icon-file-check' => 'file-check' ),
			array( 'icon-file-lock' => 'file-lock' ),
			array( 'icon-files' => 'files' ),
			array( 'icon-copy' => 'copy' ),
			array( 'icon-compare' => 'compare' ),
			array( 'icon-folder' => 'folder' ),
			array( 'icon-folder-search' => 'folder-search' ),
			array( 'icon-folder-plus' => 'folder-plus' ),
			array( 'icon-folder-minus' => 'folder-minus' ),
			array( 'icon-folder-download' => 'folder-download' ),
			array( 'icon-folder-upload' => 'folder-upload' ),
			array( 'icon-folder-star' => 'folder-star' ),
			array( 'icon-folder-heart' => 'folder-heart' ),
			array( 'icon-folder-user' => 'folder-user' ),
			array( 'icon-folder-shared' => 'folder-shared' ),
			array( 'icon-folder-music' => 'folder-music' ),
			array( 'icon-folder-picture' => 'folder-picture' ),
			array( 'icon-folder-film' => 'folder-film' ),
			array( 'icon-scissors' => 'scissors' ),
			array( 'icon-paste' => 'paste' ),
			array( 'icon-clipboard-empty' => 'clipboard-empty' ),
			array( 'icon-clipboard-pencil' => 'clipboard-pencil' ),
			array( 'icon-clipboard-text' => 'clipboard-text' ),
			array( 'icon-clipboard-check' => 'clipboard-check' ),
			array( 'icon-clipboard-down' => 'clipboard-down' ),
			array( 'icon-clipboard-left' => 'clipboard-left' ),
			array( 'icon-clipboard-alert' => 'clipboard-alert' ),
			array( 'icon-clipboard-user' => 'clipboard-user' ),
			array( 'icon-register' => 'register' ),
			array( 'icon-enter' => 'enter' ),
			array( 'icon-exit' => 'exit' ),
			array( 'icon-papers' => 'papers' ),
			array( 'icon-news' => 'news' ),
			array( 'icon-reading' => 'reading' ),
			array( 'icon-typewriter' => 'typewriter' ),
			array( 'icon-document' => 'document' ),
			array( 'icon-document2' => 'document2' ),
			array( 'icon-graduation-hat' => 'graduation-hat' ),
			array( 'icon-license' => 'license' ),
			array( 'icon-license2' => 'license2' ),
			array( 'icon-medal-empty' => 'medal-empty' ),
			array( 'icon-medal-first' => 'medal-first' ),
			array( 'icon-medal-second' => 'medal-second' ),
			array( 'icon-medal-third' => 'medal-third' ),
			array( 'icon-podium' => 'podium' ),
			array( 'icon-trophy' => 'trophy' ),
			array( 'icon-trophy2' => 'trophy2' ),
			array( 'icon-music-note' => 'music-note' ),
			array( 'icon-music-note2' => 'music-note2' ),
			array( 'icon-music-note3' => 'music-note3' ),
			array( 'icon-playlist' => 'playlist' ),
			array( 'icon-playlist-add' => 'playlist-add' ),
			array( 'icon-guitar' => 'guitar' ),
			array( 'icon-trumpet' => 'trumpet' ),
			array( 'icon-album' => 'album' ),
			array( 'icon-shuffle' => 'shuffle' ),
			array( 'icon-repeat-one' => 'repeat-one' ),
			array( 'icon-repeat' => 'repeat' ),
			array( 'icon-headphones' => 'headphones' ),
			array( 'icon-headset' => 'headset' ),
			array( 'icon-loudspeaker' => 'loudspeaker' ),
			array( 'icon-equalizer' => 'equalizer' ),
			array( 'icon-theater' => 'theater' ),
			array( 'icon-3d-glasses' => '3d-glasses' ),
			array( 'icon-ticket' => 'ticket' ),
			array( 'icon-presentation' => 'presentation' ),
			array( 'icon-play' => 'play' ),
			array( 'icon-film-play' => 'film-play' ),
			array( 'icon-clapboard-play' => 'clapboard-play' ),
			array( 'icon-media' => 'media' ),
			array( 'icon-film' => 'film' ),
			array( 'icon-film2' => 'film2' ),
			array( 'icon-surveillance' => 'surveillance' ),
			array( 'icon-surveillance2' => 'surveillance2' ),
			array( 'icon-camera' => 'camera' ),
			array( 'icon-camera-crossed' => 'camera-crossed' ),
			array( 'icon-camera-play' => 'camera-play' ),
			array( 'icon-time-lapse' => 'time-lapse' ),
			array( 'icon-record' => 'record' ),
			array( 'icon-camera2' => 'camera2' ),
			array( 'icon-camera-flip' => 'camera-flip' ),
			array( 'icon-panorama' => 'panorama' ),
			array( 'icon-time-lapse2' => 'time-lapse2' ),
			array( 'icon-shutter' => 'shutter' ),
			array( 'icon-shutter2' => 'shutter2' ),
			array( 'icon-face-detection' => 'face-detection' ),
			array( 'icon-flare' => 'flare' ),
			array( 'icon-convex' => 'convex' ),
			array( 'icon-concave' => 'concave' ),
			array( 'icon-picture' => 'picture' ),
			array( 'icon-picture2' => 'picture2' ),
			array( 'icon-picture3' => 'picture3' ),
			array( 'icon-pictures' => 'pictures' ),
			array( 'icon-book' => 'book' ),
			array( 'icon-audio-book' => 'audio-book' ),
			array( 'icon-book2' => 'book2' ),
			array( 'icon-bookmark' => 'bookmark' ),
			array( 'icon-bookmark2' => 'bookmark2' ),
			array( 'icon-label' => 'label' ),
			array( 'icon-library' => 'library' ),
			array( 'icon-library2' => 'library2' ),
			array( 'icon-contacts' => 'contacts' ),
			array( 'icon-profile' => 'profile' ),
			array( 'icon-portrait' => 'portrait' ),
			array( 'icon-portrait2' => 'portrait2' ),
			array( 'icon-user' => 'user' ),
			array( 'icon-user-plus' => 'user-plus' ),
			array( 'icon-user-minus' => 'user-minus' ),
			array( 'icon-user-lock' => 'user-lock' ),
			array( 'icon-users' => 'users' ),
			array( 'icon-users2' => 'users2' ),
			array( 'icon-users-plus' => 'users-plus' ),
			array( 'icon-users-minus' => 'users-minus' ),
			array( 'icon-group-work' => 'group-work' ),
			array( 'icon-woman' => 'woman' ),
			array( 'icon-man' => 'man' ),
			array( 'icon-baby' => 'baby' ),
			array( 'icon-baby2' => 'baby2' ),
			array( 'icon-baby3' => 'baby3' ),
			array( 'icon-baby-bottle' => 'baby-bottle' ),
			array( 'icon-walk' => 'walk' ),
			array( 'icon-hand-waving' => 'hand-waving' ),
			array( 'icon-jump' => 'jump' ),
			array( 'icon-run' => 'run' ),
			array( 'icon-woman2' => 'woman2' ),
			array( 'icon-man2' => 'man2' ),
			array( 'icon-man-woman' => 'man-woman' ),
			array( 'icon-height' => 'height' ),
			array( 'icon-weight' => 'weight' ),
			array( 'icon-scale' => 'scale' ),
			array( 'icon-button' => 'button' ),
			array( 'icon-bow-tie' => 'bow-tie' ),
			array( 'icon-tie' => 'tie' ),
			array( 'icon-socks' => 'socks' ),
			array( 'icon-shoe' => 'shoe' ),
			array( 'icon-shoes' => 'shoes' ),
			array( 'icon-hat' => 'hat' ),
			array( 'icon-pants' => 'pants' ),
			array( 'icon-shorts' => 'shorts' ),
			array( 'icon-flip-flops' => 'flip-flops' ),
			array( 'icon-shirt' => 'shirt' ),
			array( 'icon-hanger' => 'hanger' ),
			array( 'icon-laundry' => 'laundry' ),
			array( 'icon-store' => 'store' ),
			array( 'icon-haircut' => 'haircut' ),
			array( 'icon-store-24' => 'store-24' ),
			array( 'icon-barcode' => 'barcode' ),
			array( 'icon-barcode2' => 'barcode2' ),
			array( 'icon-barcode3' => 'barcode3' ),
			array( 'icon-cashier' => 'cashier' ),
			array( 'icon-bag' => 'bag' ),
			array( 'icon-bag2' => 'bag2' ),
			array( 'icon-cart' => 'cart' ),
			array( 'icon-cart-empty' => 'cart-empty' ),
			array( 'icon-cart-full' => 'cart-full' ),
			array( 'icon-cart-plus' => 'cart-plus' ),
			array( 'icon-cart-plus2' => 'cart-plus2' ),
			array( 'icon-cart-add' => 'cart-add' ),
			array( 'icon-cart-remove' => 'cart-remove' ),
			array( 'icon-cart-exchange' => 'cart-exchange' ),
			array( 'icon-tag' => 'tag' ),
			array( 'icon-tags' => 'tags' ),
			array( 'icon-receipt' => 'receipt' ),
			array( 'icon-wallet' => 'wallet' ),
			array( 'icon-credit-card' => 'credit-card' ),
			array( 'icon-cash-dollar' => 'cash-dollar' ),
			array( 'icon-cash-euro' => 'cash-euro' ),
			array( 'icon-cash-pound' => 'cash-pound' ),
			array( 'icon-cash-yen' => 'cash-yen' ),
			array( 'icon-bag-dollar' => 'bag-dollar' ),
			array( 'icon-bag-euro' => 'bag-euro' ),
			array( 'icon-bag-pound' => 'bag-pound' ),
			array( 'icon-bag-yen' => 'bag-yen' ),
			array( 'icon-coin-dollar' => 'coin-dollar' ),
			array( 'icon-coin-euro' => 'coin-euro' ),
			array( 'icon-coin-pound' => 'coin-pound' ),
			array( 'icon-coin-yen' => 'coin-yen' ),
			array( 'icon-calculator' => 'calculator' ),
			array( 'icon-calculator2' => 'calculator2' ),
			array( 'icon-abacus' => 'abacus' ),
			array( 'icon-vault' => 'vault' ),
			array( 'icon-telephone' => 'telephone' ),
			array( 'icon-phone-lock' => 'phone-lock' ),
			array( 'icon-phone-wave' => 'phone-wave' ),
			array( 'icon-phone-pause' => 'phone-pause' ),
			array( 'icon-phone-outgoing' => 'phone-outgoing' ),
			array( 'icon-phone-incoming' => 'phone-incoming' ),
			array( 'icon-phone-in-out' => 'phone-in-out' ),
			array( 'icon-phone-error' => 'phone-error' ),
			array( 'icon-phone-sip' => 'phone-sip' ),
			array( 'icon-phone-plus' => 'phone-plus' ),
			array( 'icon-phone-minus' => 'phone-minus' ),
			array( 'icon-voicemail' => 'voicemail' ),
			array( 'icon-dial' => 'dial' ),
			array( 'icon-telephone2' => 'telephone2' ),
			array( 'icon-pushpin' => 'pushpin' ),
			array( 'icon-pushpin2' => 'pushpin2' ),
			array( 'icon-map-marker' => 'map-marker' ),
			array( 'icon-map-marker-user' => 'map-marker-user' ),
			array( 'icon-map-marker-down' => 'map-marker-down' ),
			array( 'icon-map-marker-check' => 'map-marker-check' ),
			array( 'icon-map-marker-crossed' => 'map-marker-crossed' ),
			array( 'icon-radar' => 'radar' ),
			array( 'icon-compass2' => 'compass2' ),
			array( 'icon-map' => 'map' ),
			array( 'icon-map2' => 'map2' ),
			array( 'icon-location' => 'location' ),
			array( 'icon-road-sign' => 'road-sign' ),
			array( 'icon-calendar-empty' => 'calendar-empty' ),
			array( 'icon-calendar-check' => 'calendar-check' ),
			array( 'icon-calendar-cross' => 'calendar-cross' ),
			array( 'icon-calendar-31' => 'calendar-31' ),
			array( 'icon-calendar-full' => 'calendar-full' ),
			array( 'icon-calendar-insert' => 'calendar-insert' ),
			array( 'icon-calendar-text' => 'calendar-text' ),
			array( 'icon-calendar-user' => 'calendar-user' ),
			array( 'icon-mouse' => 'mouse' ),
			array( 'icon-mouse-left' => 'mouse-left' ),
			array( 'icon-mouse-right' => 'mouse-right' ),
			array( 'icon-mouse-both' => 'mouse-both' ),
			array( 'icon-keyboard' => 'keyboard' ),
			array( 'icon-keyboard-up' => 'keyboard-up' ),
			array( 'icon-keyboard-down' => 'keyboard-down' ),
			array( 'icon-delete' => 'delete' ),
			array( 'icon-spell-check' => 'spell-check' ),
			array( 'icon-escape' => 'escape' ),
			array( 'icon-enter2' => 'enter2' ),
			array( 'icon-screen' => 'screen' ),
			array( 'icon-aspect-ratio' => 'aspect-ratio' ),
			array( 'icon-signal' => 'signal' ),
			array( 'icon-signal-lock' => 'signal-lock' ),
			array( 'icon-signal-80' => 'signal-80' ),
			array( 'icon-signal-60' => 'signal-60' ),
			array( 'icon-signal-40' => 'signal-40' ),
			array( 'icon-signal-20' => 'signal-20' ),
			array( 'icon-signal-0' => 'signal-0' ),
			array( 'icon-signal-blocked' => 'signal-blocked' ),
			array( 'icon-sim' => 'sim' ),
			array( 'icon-flash-memory' => 'flash-memory' ),
			array( 'icon-usb-drive' => 'usb-drive' ),
			array( 'icon-phone' => 'phone' ),
			array( 'icon-smartphone' => 'smartphone' ),
			array( 'icon-smartphone-notification' => 'smartphone-notification' ),
			array( 'icon-smartphone-vibration' => 'smartphone-vibration' ),
			array( 'icon-smartphone-embed' => 'smartphone-embed' ),
			array( 'icon-smartphone-waves' => 'smartphone-waves' ),
			array( 'icon-tablet' => 'tablet' ),
			array( 'icon-tablet2' => 'tablet2' ),
			array( 'icon-laptop' => 'laptop' ),
			array( 'icon-laptop-phone' => 'laptop-phone' ),
			array( 'icon-desktop' => 'desktop' ),
			array( 'icon-launch' => 'launch' ),
			array( 'icon-new-tab' => 'new-tab' ),
			array( 'icon-window' => 'window' ),
			array( 'icon-cable' => 'cable' ),
			array( 'icon-cable2' => 'cable2' ),
			array( 'icon-tv' => 'tv' ),
			array( 'icon-radio' => 'radio' ),
			array( 'icon-remote-control' => 'remote-control' ),
			array( 'icon-power-switch' => 'power-switch' ),
			array( 'icon-power' => 'power' ),
			array( 'icon-power-crossed' => 'power-crossed' ),
			array( 'icon-flash-auto' => 'flash-auto' ),
			array( 'icon-lamp' => 'lamp' ),
			array( 'icon-flashlight' => 'flashlight' ),
			array( 'icon-lampshade' => 'lampshade' ),
			array( 'icon-cord' => 'cord' ),
			array( 'icon-outlet' => 'outlet' ),
			array( 'icon-battery-power' => 'battery-power' ),
			array( 'icon-battery-empty' => 'battery-empty' ),
			array( 'icon-battery-alert' => 'battery-alert' ),
			array( 'icon-battery-error' => 'battery-error' ),
			array( 'icon-battery-low1' => 'battery-low1' ),
			array( 'icon-battery-low2' => 'battery-low2' ),
			array( 'icon-battery-low3' => 'battery-low3' ),
			array( 'icon-battery-mid1' => 'battery-mid1' ),
			array( 'icon-battery-mid2' => 'battery-mid2' ),
			array( 'icon-battery-mid3' => 'battery-mid3' ),
			array( 'icon-battery-full' => 'battery-full' ),
			array( 'icon-battery-charging' => 'battery-charging' ),
			array( 'icon-battery-charging2' => 'battery-charging2' ),
			array( 'icon-battery-charging3' => 'battery-charging3' ),
			array( 'icon-battery-charging4' => 'battery-charging4' ),
			array( 'icon-battery-charging5' => 'battery-charging5' ),
			array( 'icon-battery-charging6' => 'battery-charging6' ),
			array( 'icon-battery-charging7' => 'battery-charging7' ),
			array( 'icon-chip' => 'chip' ),
			array( 'icon-chip-x64' => 'chip-x64' ),
			array( 'icon-chip-x86' => 'chip-x86' ),
			array( 'icon-bubble' => 'bubble' ),
			array( 'icon-bubbles' => 'bubbles' ),
			array( 'icon-bubble-dots' => 'bubble-dots' ),
			array( 'icon-bubble-alert' => 'bubble-alert' ),
			array( 'icon-bubble-question' => 'bubble-question' ),
			array( 'icon-bubble-text' => 'bubble-text' ),
			array( 'icon-bubble-pencil' => 'bubble-pencil' ),
			array( 'icon-bubble-picture' => 'bubble-picture' ),
			array( 'icon-bubble-video' => 'bubble-video' ),
			array( 'icon-bubble-user' => 'bubble-user' ),
			array( 'icon-bubble-quote' => 'bubble-quote' ),
			array( 'icon-bubble-heart' => 'bubble-heart' ),
			array( 'icon-bubble-emoticon' => 'bubble-emoticon' ),
			array( 'icon-bubble-attachment' => 'bubble-attachment' ),
			array( 'icon-phone-bubble' => 'phone-bubble' ),
			array( 'icon-quote-open' => 'quote-open' ),
			array( 'icon-quote-close' => 'quote-close' ),
			array( 'icon-dna' => 'dna' ),
			array( 'icon-heart-pulse' => 'heart-pulse' ),
			array( 'icon-pulse' => 'pulse' ),
			array( 'icon-syringe' => 'syringe' ),
			array( 'icon-pills' => 'pills' ),
			array( 'icon-first-aid' => 'first-aid' ),
			array( 'icon-lifebuoy' => 'lifebuoy' ),
			array( 'icon-bandage' => 'bandage' ),
			array( 'icon-bandages' => 'bandages' ),
			array( 'icon-thermometer' => 'thermometer' ),
			array( 'icon-microscope' => 'microscope' ),
			array( 'icon-brain' => 'brain' ),
			array( 'icon-beaker' => 'beaker' ),
			array( 'icon-skull' => 'skull' ),
			array( 'icon-bone' => 'bone' ),
			array( 'icon-construction' => 'construction' ),
			array( 'icon-construction-cone' => 'construction-cone' ),
			array( 'icon-pie-chart' => 'pie-chart' ),
			array( 'icon-pie-chart2' => 'pie-chart2' ),
			array( 'icon-graph' => 'graph' ),
			array( 'icon-chart-growth' => 'chart-growth' ),
			array( 'icon-chart-bars' => 'chart-bars' ),
			array( 'icon-chart-settings' => 'chart-settings' ),
			array( 'icon-cake' => 'cake' ),
			array( 'icon-gift' => 'gift' ),
			array( 'icon-balloon' => 'balloon' ),
			array( 'icon-rank' => 'rank' ),
			array( 'icon-rank2' => 'rank2' ),
			array( 'icon-rank3' => 'rank3' ),
			array( 'icon-crown' => 'crown' ),
			array( 'icon-lotus' => 'lotus' ),
			array( 'icon-diamond' => 'diamond' ),
			array( 'icon-diamond2' => 'diamond2' ),
			array( 'icon-diamond3' => 'diamond3' ),
			array( 'icon-diamond4' => 'diamond4' ),
			array( 'icon-linearicons' => 'linearicons' ),
			array( 'icon-teacup' => 'teacup' ),
			array( 'icon-teapot' => 'teapot' ),
			array( 'icon-glass' => 'glass' ),
			array( 'icon-bottle2' => 'bottle2' ),
			array( 'icon-glass-cocktail' => 'glass-cocktail' ),
			array( 'icon-glass2' => 'glass2' ),
			array( 'icon-dinner' => 'dinner' ),
			array( 'icon-dinner2' => 'dinner2' ),
			array( 'icon-chef' => 'chef' ),
			array( 'icon-scale2' => 'scale2' ),
			array( 'icon-egg' => 'egg' ),
			array( 'icon-egg2' => 'egg2' ),
			array( 'icon-eggs' => 'eggs' ),
			array( 'icon-platter' => 'platter' ),
			array( 'icon-steak' => 'steak' ),
			array( 'icon-hamburger' => 'hamburger' ),
			array( 'icon-hotdog' => 'hotdog' ),
			array( 'icon-pizza' => 'pizza' ),
			array( 'icon-sausage' => 'sausage' ),
			array( 'icon-chicken' => 'chicken' ),
			array( 'icon-fish' => 'fish' ),
			array( 'icon-carrot' => 'carrot' ),
			array( 'icon-cheese' => 'cheese' ),
			array( 'icon-bread' => 'bread' ),
			array( 'icon-ice-cream' => 'ice-cream' ),
			array( 'icon-ice-cream2' => 'ice-cream2' ),
			array( 'icon-candy' => 'candy' ),
			array( 'icon-lollipop' => 'lollipop' ),
			array( 'icon-coffee-bean' => 'coffee-bean' ),
			array( 'icon-coffee-cup' => 'coffee-cup' ),
			array( 'icon-cherry' => 'cherry' ),
			array( 'icon-grapes' => 'grapes' ),
			array( 'icon-citrus' => 'citrus' ),
			array( 'icon-apple' => 'apple' ),
			array( 'icon-leaf' => 'leaf' ),
			array( 'icon-landscape' => 'landscape' ),
			array( 'icon-pine-tree' => 'pine-tree' ),
			array( 'icon-tree' => 'tree' ),
			array( 'icon-cactus' => 'cactus' ),
			array( 'icon-paw' => 'paw' ),
			array( 'icon-footprint' => 'footprint' ),
			array( 'icon-speed-slow' => 'speed-slow' ),
			array( 'icon-speed-medium' => 'speed-medium' ),
			array( 'icon-speed-fast' => 'speed-fast' ),
			array( 'icon-rocket' => 'rocket' ),
			array( 'icon-hammer2' => 'hammer2' ),
			array( 'icon-balance' => 'balance' ),
			array( 'icon-briefcase' => 'briefcase' ),
			array( 'icon-luggage-weight' => 'luggage-weight' ),
			array( 'icon-dolly' => 'dolly' ),
			array( 'icon-plane' => 'plane' ),
			array( 'icon-plane-crossed' => 'plane-crossed' ),
			array( 'icon-helicopter' => 'helicopter' ),
			array( 'icon-traffic-lights' => 'traffic-lights' ),
			array( 'icon-siren' => 'siren' ),
			array( 'icon-road' => 'road' ),
			array( 'icon-engine' => 'engine' ),
			array( 'icon-oil-pressure' => 'oil-pressure' ),
			array( 'icon-coolant-temperature' => 'coolant-temperature' ),
			array( 'icon-car-battery' => 'car-battery' ),
			array( 'icon-gas' => 'gas' ),
			array( 'icon-gallon' => 'gallon' ),
			array( 'icon-transmission' => 'transmission' ),
			array( 'icon-car' => 'car' ),
			array( 'icon-car-wash' => 'car-wash' ),
			array( 'icon-car-wash2' => 'car-wash2' ),
			array( 'icon-bus' => 'bus' ),
			array( 'icon-bus2' => 'bus2' ),
			array( 'icon-car2' => 'car2' ),
			array( 'icon-parking' => 'parking' ),
			array( 'icon-car-lock' => 'car-lock' ),
			array( 'icon-taxi' => 'taxi' ),
			array( 'icon-car-siren' => 'car-siren' ),
			array( 'icon-car-wash3' => 'car-wash3' ),
			array( 'icon-car-wash4' => 'car-wash4' ),
			array( 'icon-ambulance' => 'ambulance' ),
			array( 'icon-truck' => 'truck' ),
			array( 'icon-trailer' => 'trailer' ),
			array( 'icon-scale-truck' => 'scale-truck' ),
			array( 'icon-train' => 'train' ),
			array( 'icon-ship' => 'ship' ),
			array( 'icon-ship2' => 'ship2' ),
			array( 'icon-anchor' => 'anchor' ),
			array( 'icon-boat' => 'boat' ),
			array( 'icon-bicycle' => 'bicycle' ),
			array( 'icon-bicycle2' => 'bicycle2' ),
			array( 'icon-dumbbell' => 'dumbbell' ),
			array( 'icon-bench-press' => 'bench-press' ),
			array( 'icon-swim' => 'swim' ),
			array( 'icon-football' => 'football' ),
			array( 'icon-baseball-bat' => 'baseball-bat' ),
			array( 'icon-baseball' => 'baseball' ),
			array( 'icon-tennis' => 'tennis' ),
			array( 'icon-tennis2' => 'tennis2' ),
			array( 'icon-ping-pong' => 'ping-pong' ),
			array( 'icon-hockey' => 'hockey' ),
			array( 'icon-8ball' => '8ball' ),
			array( 'icon-bowling' => 'bowling' ),
			array( 'icon-bowling-pins' => 'bowling-pins' ),
			array( 'icon-golf' => 'golf' ),
			array( 'icon-golf2' => 'golf2' ),
			array( 'icon-archery' => 'archery' ),
			array( 'icon-slingshot' => 'slingshot' ),
			array( 'icon-soccer' => 'soccer' ),
			array( 'icon-basketball' => 'basketball' ),
			array( 'icon-cube' => 'cube' ),
			array( 'icon-3d-rotate' => '3d-rotate' ),
			array( 'icon-puzzle' => 'puzzle' ),
			array( 'icon-glasses' => 'glasses' ),
			array( 'icon-glasses2' => 'glasses2' ),
			array( 'icon-accessibility' => 'accessibility' ),
			array( 'icon-wheelchair' => 'wheelchair' ),
			array( 'icon-wall' => 'wall' ),
			array( 'icon-fence' => 'fence' ),
			array( 'icon-wall2' => 'wall2' ),
			array( 'icon-icons' => 'icons' ),
			array( 'icon-resize-handle' => 'resize-handle' ),
			array( 'icon-icons2' => 'icons2' ),
			array( 'icon-select' => 'select' ),
			array( 'icon-select2' => 'select2' ),
			array( 'icon-site-map' => 'site-map' ),
			array( 'icon-earth' => 'earth' ),
			array( 'icon-earth-lock' => 'earth-lock' ),
			array( 'icon-network' => 'network' ),
			array( 'icon-network-lock' => 'network-lock' ),
			array( 'icon-planet' => 'planet' ),
			array( 'icon-happy' => 'happy' ),
			array( 'icon-smile' => 'smile' ),
			array( 'icon-grin' => 'grin' ),
			array( 'icon-tongue' => 'tongue' ),
			array( 'icon-sad' => 'sad' ),
			array( 'icon-wink' => 'wink' ),
			array( 'icon-dream' => 'dream' ),
			array( 'icon-shocked' => 'shocked' ),
			array( 'icon-shocked2' => 'shocked2' ),
			array( 'icon-tongue2' => 'tongue2' ),
			array( 'icon-neutral' => 'neutral' ),
			array( 'icon-happy-grin' => 'happy-grin' ),
			array( 'icon-cool' => 'cool' ),
			array( 'icon-mad' => 'mad' ),
			array( 'icon-grin-evil' => 'grin-evil' ),
			array( 'icon-evil' => 'evil' ),
			array( 'icon-wow' => 'wow' ),
			array( 'icon-annoyed' => 'annoyed' ),
			array( 'icon-wondering' => 'wondering' ),
			array( 'icon-confused' => 'confused' ),
			array( 'icon-zipped' => 'zipped' ),
			array( 'icon-grumpy' => 'grumpy' ),
			array( 'icon-mustache' => 'mustache' ),
			array( 'icon-tombstone-hipster' => 'tombstone-hipster' ),
			array( 'icon-tombstone' => 'tombstone' ),
			array( 'icon-ghost' => 'ghost' ),
			array( 'icon-ghost-hipster' => 'ghost-hipster' ),
			array( 'icon-halloween' => 'halloween' ),
			array( 'icon-christmas' => 'christmas' ),
			array( 'icon-easter-egg' => 'easter-egg' ),
			array( 'icon-mustache2' => 'mustache2' ),
			array( 'icon-mustache-glasses' => 'mustache-glasses' ),
			array( 'icon-pipe' => 'pipe' ),
			array( 'icon-alarm' => 'alarm' ),
			array( 'icon-alarm-add' => 'alarm-add' ),
			array( 'icon-alarm-snooze' => 'alarm-snooze' ),
			array( 'icon-alarm-ringing' => 'alarm-ringing' ),
			array( 'icon-bullhorn' => 'bullhorn' ),
			array( 'icon-hearing' => 'hearing' ),
			array( 'icon-volume-high' => 'volume-high' ),
			array( 'icon-volume-medium' => 'volume-medium' ),
			array( 'icon-volume-low' => 'volume-low' ),
			array( 'icon-volume' => 'volume' ),
			array( 'icon-mute' => 'mute' ),
			array( 'icon-lan' => 'lan' ),
			array( 'icon-lan2' => 'lan2' ),
			array( 'icon-wifi' => 'wifi' ),
			array( 'icon-wifi-lock' => 'wifi-lock' ),
			array( 'icon-wifi-blocked' => 'wifi-blocked' ),
			array( 'icon-wifi-mid' => 'wifi-mid' ),
			array( 'icon-wifi-low' => 'wifi-low' ),
			array( 'icon-wifi-low2' => 'wifi-low2' ),
			array( 'icon-wifi-alert' => 'wifi-alert' ),
			array( 'icon-wifi-alert-mid' => 'wifi-alert-mid' ),
			array( 'icon-wifi-alert-low' => 'wifi-alert-low' ),
			array( 'icon-wifi-alert-low2' => 'wifi-alert-low2' ),
			array( 'icon-stream' => 'stream' ),
			array( 'icon-stream-check' => 'stream-check' ),
			array( 'icon-stream-error' => 'stream-error' ),
			array( 'icon-stream-alert' => 'stream-alert' ),
			array( 'icon-communication' => 'communication' ),
			array( 'icon-communication-crossed' => 'communication-crossed' ),
			array( 'icon-broadcast' => 'broadcast' ),
			array( 'icon-antenna' => 'antenna' ),
			array( 'icon-satellite' => 'satellite' ),
			array( 'icon-satellite2' => 'satellite2' ),
			array( 'icon-mic' => 'mic' ),
			array( 'icon-mic-mute' => 'mic-mute' ),
			array( 'icon-mic2' => 'mic2' ),
			array( 'icon-spotlights' => 'spotlights' ),
			array( 'icon-hourglass' => 'hourglass' ),
			array( 'icon-loading' => 'loading' ),
			array( 'icon-loading2' => 'loading2' ),
			array( 'icon-loading3' => 'loading3' ),
			array( 'icon-refresh' => 'refresh' ),
			array( 'icon-refresh2' => 'refresh2' ),
			array( 'icon-undo' => 'undo' ),
			array( 'icon-redo' => 'redo' ),
			array( 'icon-jump2' => 'jump2' ),
			array( 'icon-undo2' => 'undo2' ),
			array( 'icon-redo2' => 'redo2' ),
			array( 'icon-sync' => 'sync' ),
			array( 'icon-repeat-one2' => 'repeat-one2' ),
			array( 'icon-sync-crossed' => 'sync-crossed' ),
			array( 'icon-sync2' => 'sync2' ),
			array( 'icon-repeat-one3' => 'repeat-one3' ),
			array( 'icon-sync-crossed2' => 'sync-crossed2' ),
			array( 'icon-return' => 'return' ),
			array( 'icon-return2' => 'return2' ),
			array( 'icon-refund' => 'refund' ),
			array( 'icon-history' => 'history' ),
			array( 'icon-history2' => 'history2' ),
			array( 'icon-self-timer' => 'self-timer' ),
			array( 'icon-clock' => 'clock' ),
			array( 'icon-clock2' => 'clock2' ),
			array( 'icon-clock3' => 'clock3' ),
			array( 'icon-watch' => 'watch' ),
			array( 'icon-alarm2' => 'alarm2' ),
			array( 'icon-alarm-add2' => 'alarm-add2' ),
			array( 'icon-alarm-remove' => 'alarm-remove' ),
			array( 'icon-alarm-check' => 'alarm-check' ),
			array( 'icon-alarm-error' => 'alarm-error' ),
			array( 'icon-timer' => 'timer' ),
			array( 'icon-timer-crossed' => 'timer-crossed' ),
			array( 'icon-timer2' => 'timer2' ),
			array( 'icon-timer-crossed2' => 'timer-crossed2' ),
			array( 'icon-download' => 'download' ),
			array( 'icon-upload' => 'upload' ),
			array( 'icon-download2' => 'download2' ),
			array( 'icon-upload2' => 'upload2' ),
			array( 'icon-enter-up' => 'enter-up' ),
			array( 'icon-enter-down' => 'enter-down' ),
			array( 'icon-enter-left' => 'enter-left' ),
			array( 'icon-enter-right' => 'enter-right' ),
			array( 'icon-exit-up' => 'exit-up' ),
			array( 'icon-exit-down' => 'exit-down' ),
			array( 'icon-exit-left' => 'exit-left' ),
			array( 'icon-exit-right' => 'exit-right' ),
			array( 'icon-enter-up2' => 'enter-up2' ),
			array( 'icon-enter-down2' => 'enter-down2' ),
			array( 'icon-enter-vertical' => 'enter-vertical' ),
			array( 'icon-enter-left2' => 'enter-left2' ),
			array( 'icon-enter-right2' => 'enter-right2' ),
			array( 'icon-enter-horizontal' => 'enter-horizontal' ),
			array( 'icon-exit-up2' => 'exit-up2' ),
			array( 'icon-exit-down2' => 'exit-down2' ),
			array( 'icon-exit-left2' => 'exit-left2' ),
			array( 'icon-exit-right2' => 'exit-right2' ),
			array( 'icon-cli' => 'cli' ),
			array( 'icon-bug' => 'bug' ),
			array( 'icon-code' => 'code' ),
			array( 'icon-file-code' => 'file-code' ),
			array( 'icon-file-image' => 'file-image' ),
			array( 'icon-file-zip' => 'file-zip' ),
			array( 'icon-file-audio' => 'file-audio' ),
			array( 'icon-file-video' => 'file-video' ),
			array( 'icon-file-preview' => 'file-preview' ),
			array( 'icon-file-charts' => 'file-charts' ),
			array( 'icon-file-stats' => 'file-stats' ),
			array( 'icon-file-spreadsheet' => 'file-spreadsheet' ),
			array( 'icon-link' => 'link' ),
			array( 'icon-unlink' => 'unlink' ),
			array( 'icon-link2' => 'link2' ),
			array( 'icon-unlink2' => 'unlink2' ),
			array( 'icon-thumbs-up' => 'thumbs-up' ),
			array( 'icon-thumbs-down' => 'thumbs-down' ),
			array( 'icon-thumbs-up2' => 'thumbs-up2' ),
			array( 'icon-thumbs-down2' => 'thumbs-down2' ),
			array( 'icon-thumbs-up3' => 'thumbs-up3' ),
			array( 'icon-thumbs-down3' => 'thumbs-down3' ),
			array( 'icon-share' => 'share' ),
			array( 'icon-share2' => 'share2' ),
			array( 'icon-share3' => 'share3' ),
			array( 'icon-magnifier' => 'magnifier' ),
			array( 'icon-file-search' => 'file-search' ),
			array( 'icon-find-replace' => 'find-replace' ),
			array( 'icon-zoom-in' => 'zoom-in' ),
			array( 'icon-zoom-out' => 'zoom-out' ),
			array( 'icon-loupe' => 'loupe' ),
			array( 'icon-loupe-zoom-in' => 'loupe-zoom-in' ),
			array( 'icon-loupe-zoom-out' => 'loupe-zoom-out' ),
			array( 'icon-cross' => 'cross' ),
			array( 'icon-menu' => 'menu' ),
			array( 'icon-list' => 'list' ),
			array( 'icon-list2' => 'list2' ),
			array( 'icon-list3' => 'list3' ),
			array( 'icon-menu2' => 'menu2' ),
			array( 'icon-list4' => 'list4' ),
			array( 'icon-menu3' => 'menu3' ),
			array( 'icon-exclamation' => 'exclamation' ),
			array( 'icon-question' => 'question' ),
			array( 'icon-check' => 'check' ),
			array( 'icon-cross2' => 'cross2' ),
			array( 'icon-plus' => 'plus' ),
			array( 'icon-minus' => 'minus' ),
			array( 'icon-percent' => 'percent' ),
			array( 'icon-chevron-up' => 'chevron-up' ),
			array( 'icon-chevron-down' => 'chevron-down' ),
			array( 'icon-chevron-left' => 'chevron-left' ),
			array( 'icon-chevron-right' => 'chevron-right' ),
			array( 'icon-chevrons-expand-vertical' => 'chevrons-expand-vertical' ),
			array( 'icon-chevrons-expand-horizontal' => 'chevrons-expand-horizontal' ),
			array( 'icon-chevrons-contract-vertical' => 'chevrons-contract-vertical' ),
			array( 'icon-chevrons-contract-horizontal' => 'chevrons-contract-horizontal' ),
			array( 'icon-arrow-up' => 'arrow-up' ),
			array( 'icon-arrow-down' => 'arrow-down' ),
			array( 'icon-arrow-left' => 'arrow-left' ),
			array( 'icon-arrow-right' => 'arrow-right' ),
			array( 'icon-arrow-up-right' => 'arrow-up-right' ),
			array( 'icon-arrows-merge' => 'arrows-merge' ),
			array( 'icon-arrows-split' => 'arrows-split' ),
			array( 'icon-arrow-divert' => 'arrow-divert' ),
			array( 'icon-arrow-return' => 'arrow-return' ),
			array( 'icon-expand' => 'expand' ),
			array( 'icon-contract' => 'contract' ),
			array( 'icon-expand2' => 'expand2' ),
			array( 'icon-contract2' => 'contract2' ),
			array( 'icon-move' => 'move' ),
			array( 'icon-tab' => 'tab' ),
			array( 'icon-arrow-wave' => 'arrow-wave' ),
			array( 'icon-expand3' => 'expand3' ),
			array( 'icon-expand4' => 'expand4' ),
			array( 'icon-contract3' => 'contract3' ),
			array( 'icon-notification' => 'notification' ),
			array( 'icon-warning' => 'warning' ),
			array( 'icon-notification-circle' => 'notification-circle' ),
			array( 'icon-question-circle' => 'question-circle' ),
			array( 'icon-menu-circle' => 'menu-circle' ),
			array( 'icon-checkmark-circle' => 'checkmark-circle' ),
			array( 'icon-cross-circle' => 'cross-circle' ),
			array( 'icon-plus-circle' => 'plus-circle' ),
			array( 'icon-circle-minus' => 'circle-minus' ),
			array( 'icon-percent-circle' => 'percent-circle' ),
			array( 'icon-arrow-up-circle' => 'arrow-up-circle' ),
			array( 'icon-arrow-down-circle' => 'arrow-down-circle' ),
			array( 'icon-arrow-left-circle' => 'arrow-left-circle' ),
			array( 'icon-arrow-right-circle' => 'arrow-right-circle' ),
			array( 'icon-chevron-up-circle' => 'chevron-up-circle' ),
			array( 'icon-chevron-down-circle' => 'chevron-down-circle' ),
			array( 'icon-chevron-left-circle' => 'chevron-left-circle' ),
			array( 'icon-chevron-right-circle' => 'chevron-right-circle' ),
			array( 'icon-backward-circle' => 'backward-circle' ),
			array( 'icon-first-circle' => 'first-circle' ),
			array( 'icon-previous-circle' => 'previous-circle' ),
			array( 'icon-stop-circle' => 'stop-circle' ),
			array( 'icon-play-circle' => 'play-circle' ),
			array( 'icon-pause-circle' => 'pause-circle' ),
			array( 'icon-next-circle' => 'next-circle' ),
			array( 'icon-last-circle' => 'last-circle' ),
			array( 'icon-forward-circle' => 'forward-circle' ),
			array( 'icon-eject-circle' => 'eject-circle' ),
			array( 'icon-crop' => 'crop' ),
			array( 'icon-frame-expand' => 'frame-expand' ),
			array( 'icon-frame-contract' => 'frame-contract' ),
			array( 'icon-focus' => 'focus' ),
			array( 'icon-transform' => 'transform' ),
			array( 'icon-grid' => 'grid' ),
			array( 'icon-grid-crossed' => 'grid-crossed' ),
			array( 'icon-layers' => 'layers' ),
			array( 'icon-layers-crossed' => 'layers-crossed' ),
			array( 'icon-toggle' => 'toggle' ),
			array( 'icon-rulers' => 'rulers' ),
			array( 'icon-ruler' => 'ruler' ),
			array( 'icon-funnel' => 'funnel' ),
			array( 'icon-flip-horizontal' => 'flip-horizontal' ),
			array( 'icon-flip-vertical' => 'flip-vertical' ),
			array( 'icon-flip-horizontal2' => 'flip-horizontal2' ),
			array( 'icon-flip-vertical2' => 'flip-vertical2' ),
			array( 'icon-angle' => 'angle' ),
			array( 'icon-angle2' => 'angle2' ),
			array( 'icon-subtract' => 'subtract' ),
			array( 'icon-combine' => 'combine' ),
			array( 'icon-intersect' => 'intersect' ),
			array( 'icon-exclude' => 'exclude' ),
			array( 'icon-align-center-vertical' => 'align-center-vertical' ),
			array( 'icon-align-right' => 'align-right' ),
			array( 'icon-align-bottom' => 'align-bottom' ),
			array( 'icon-align-left' => 'align-left' ),
			array( 'icon-align-center-horizontal' => 'align-center-horizontal' ),
			array( 'icon-align-top' => 'align-top' ),
			array( 'icon-square' => 'square' ),
			array( 'icon-plus-square' => 'plus-square' ),
			array( 'icon-minus-square' => 'minus-square' ),
			array( 'icon-percent-square' => 'percent-square' ),
			array( 'icon-arrow-up-square' => 'arrow-up-square' ),
			array( 'icon-arrow-down-square' => 'arrow-down-square' ),
			array( 'icon-arrow-left-square' => 'arrow-left-square' ),
			array( 'icon-arrow-right-square' => 'arrow-right-square' ),
			array( 'icon-chevron-up-square' => 'chevron-up-square' ),
			array( 'icon-chevron-down-square' => 'chevron-down-square' ),
			array( 'icon-chevron-left-square' => 'chevron-left-square' ),
			array( 'icon-chevron-right-square' => 'chevron-right-square' ),
			array( 'icon-check-square' => 'check-square' ),
			array( 'icon-cross-square' => 'cross-square' ),
			array( 'icon-menu-square' => 'menu-square' ),
			array( 'icon-prohibited' => 'prohibited' ),
			array( 'icon-circle' => 'circle' ),
			array( 'icon-radio-button' => 'radio-button' ),
			array( 'icon-ligature' => 'ligature' ),
			array( 'icon-text-format' => 'text-format' ),
			array( 'icon-text-format-remove' => 'text-format-remove' ),
			array( 'icon-text-size' => 'text-size' ),
			array( 'icon-bold' => 'bold' ),
			array( 'icon-italic' => 'italic' ),
			array( 'icon-underline' => 'underline' ),
			array( 'icon-strikethrough' => 'strikethrough' ),
			array( 'icon-highlight' => 'highlight' ),
			array( 'icon-text-align-left' => 'text-align-left' ),
			array( 'icon-text-align-center' => 'text-align-center' ),
			array( 'icon-text-align-right' => 'text-align-right' ),
			array( 'icon-text-align-justify' => 'text-align-justify' ),
			array( 'icon-line-spacing' => 'line-spacing' ),
			array( 'icon-indent-increase' => 'indent-increase' ),
			array( 'icon-indent-decrease' => 'indent-decrease' ),
			array( 'icon-text-wrap' => 'text-wrap' ),
			array( 'icon-pilcrow' => 'pilcrow' ),
			array( 'icon-direction-ltr' => 'direction-ltr' ),
			array( 'icon-direction-rtl' => 'direction-rtl' ),
			array( 'icon-page-break' => 'page-break' ),
			array( 'icon-page-break2' => 'page-break2' ),
			array( 'icon-sort-alpha-asc' => 'sort-alpha-asc' ),
			array( 'icon-sort-alpha-desc' => 'sort-alpha-desc' ),
			array( 'icon-sort-numeric-asc' => 'sort-numeric-asc' ),
			array( 'icon-sort-numeric-desc' => 'sort-numeric-desc' ),
			array( 'icon-sort-amount-asc' => 'sort-amount-asc' ),
			array( 'icon-sort-amount-desc' => 'sort-amount-desc' ),
			array( 'icon-sort-time-asc' => 'sort-time-asc' ),
			array( 'icon-sort-time-desc' => 'sort-time-desc' ),
			array( 'icon-sigma' => 'sigma' ),
			array( 'icon-pencil-line' => 'pencil-line' ),
			array( 'icon-hand' => 'hand' ),
			array( 'icon-pointer-up' => 'pointer-up' ),
			array( 'icon-pointer-right' => 'pointer-right' ),
			array( 'icon-pointer-down' => 'pointer-down' ),
			array( 'icon-pointer-left' => 'pointer-left' ),
			array( 'icon-finger-tap' => 'finger-tap' ),
			array( 'icon-fingers-tap' => 'fingers-tap' ),
			array( 'icon-reminder' => 'reminder' ),
			array( 'icon-fingers-crossed' => 'fingers-crossed' ),
			array( 'icon-fingers-victory' => 'fingers-victory' ),
			array( 'icon-gesture-zoom' => 'gesture-zoom' ),
			array( 'icon-gesture-pinch' => 'gesture-pinch' ),
			array( 'icon-fingers-scroll-horizontal' => 'fingers-scroll-horizontal' ),
			array( 'icon-fingers-scroll-vertical' => 'fingers-scroll-vertical' ),
			array( 'icon-fingers-scroll-left' => 'fingers-scroll-left' ),
			array( 'icon-fingers-scroll-right' => 'fingers-scroll-right' ),
			array( 'icon-hand2' => 'hand2' ),
			array( 'icon-pointer-up2' => 'pointer-up2' ),
			array( 'icon-pointer-right2' => 'pointer-right2' ),
			array( 'icon-pointer-down2' => 'pointer-down2' ),
			array( 'icon-pointer-left2' => 'pointer-left2' ),
			array( 'icon-finger-tap2' => 'finger-tap2' ),
			array( 'icon-fingers-tap2' => 'fingers-tap2' ),
			array( 'icon-reminder2' => 'reminder2' ),
			array( 'icon-gesture-zoom2' => 'gesture-zoom2' ),
			array( 'icon-gesture-pinch2' => 'gesture-pinch2' ),
			array( 'icon-fingers-scroll-horizontal2' => 'fingers-scroll-horizontal2' ),
			array( 'icon-fingers-scroll-vertical2' => 'fingers-scroll-vertical2' ),
			array( 'icon-fingers-scroll-left2' => 'fingers-scroll-left2' ),
			array( 'icon-fingers-scroll-right2' => 'fingers-scroll-right2' ),
			array( 'icon-fingers-scroll-vertical3' => 'fingers-scroll-vertical3' ),
			array( 'icon-border-style' => 'border-style' ),
			array( 'icon-border-all' => 'border-all' ),
			array( 'icon-border-outer' => 'border-outer' ),
			array( 'icon-border-inner' => 'border-inner' ),
			array( 'icon-border-top' => 'border-top' ),
			array( 'icon-border-horizontal' => 'border-horizontal' ),
			array( 'icon-border-bottom' => 'border-bottom' ),
			array( 'icon-border-left' => 'border-left' ),
			array( 'icon-border-vertical' => 'border-vertical' ),
			array( 'icon-border-right' => 'border-right' ),
			array( 'icon-border-none' => 'border-none' ),
			array( 'icon-ellipsis' => 'ellipsis' ),
			array( 'icon-uni21' => 'uni21' ),
			array( 'icon-uni22' => 'uni22' ),
			array( 'icon-uni23' => 'uni23' ),
			array( 'icon-uni24' => 'uni24' ),
			array( 'icon-uni25' => 'uni25' ),
			array( 'icon-uni26' => 'uni26' ),
			array( 'icon-uni27' => 'uni27' ),
			array( 'icon-uni28' => 'uni28' ),
			array( 'icon-uni29' => 'uni29' ),
			array( 'icon-uni2a' => 'uni2a' ),
			array( 'icon-uni2b' => 'uni2b' ),
			array( 'icon-uni2c' => 'uni2c' ),
			array( 'icon-uni2d' => 'uni2d' ),
			array( 'icon-uni2e' => 'uni2e' ),
			array( 'icon-uni2f' => 'uni2f' ),
			array( 'icon-uni30' => 'uni30' ),
			array( 'icon-uni31' => 'uni31' ),
			array( 'icon-uni32' => 'uni32' ),
			array( 'icon-uni33' => 'uni33' ),
			array( 'icon-uni34' => 'uni34' ),
			array( 'icon-uni35' => 'uni35' ),
			array( 'icon-uni36' => 'uni36' ),
			array( 'icon-uni37' => 'uni37' ),
			array( 'icon-uni38' => 'uni38' ),
			array( 'icon-uni39' => 'uni39' ),
			array( 'icon-uni3a' => 'uni3a' ),
			array( 'icon-uni3b' => 'uni3b' ),
			array( 'icon-uni3c' => 'uni3c' ),
			array( 'icon-uni3d' => 'uni3d' ),
			array( 'icon-uni3e' => 'uni3e' ),
			array( 'icon-uni3f' => 'uni3f' ),
			array( 'icon-uni40' => 'uni40' ),
			array( 'icon-uni41' => 'uni41' ),
			array( 'icon-uni42' => 'uni42' ),
			array( 'icon-uni43' => 'uni43' ),
			array( 'icon-uni44' => 'uni44' ),
			array( 'icon-uni45' => 'uni45' ),
			array( 'icon-uni46' => 'uni46' ),
			array( 'icon-uni47' => 'uni47' ),
			array( 'icon-uni48' => 'uni48' ),
			array( 'icon-uni49' => 'uni49' ),
			array( 'icon-uni4a' => 'uni4a' ),
			array( 'icon-uni4b' => 'uni4b' ),
			array( 'icon-uni4c' => 'uni4c' ),
			array( 'icon-uni4d' => 'uni4d' ),
			array( 'icon-uni4e' => 'uni4e' ),
			array( 'icon-uni4f' => 'uni4f' ),
			array( 'icon-uni50' => 'uni50' ),
			array( 'icon-uni51' => 'uni51' ),
			array( 'icon-uni52' => 'uni52' ),
			array( 'icon-uni53' => 'uni53' ),
			array( 'icon-uni54' => 'uni54' ),
			array( 'icon-uni55' => 'uni55' ),
			array( 'icon-uni56' => 'uni56' ),
			array( 'icon-uni57' => 'uni57' ),
			array( 'icon-uni58' => 'uni58' ),
			array( 'icon-uni59' => 'uni59' ),
			array( 'icon-uni5a' => 'uni5a' ),
			array( 'icon-uni5b' => 'uni5b' ),
			array( 'icon-uni5c' => 'uni5c' ),
			array( 'icon-uni5d' => 'uni5d' ),
			array( 'icon-uni5e' => 'uni5e' ),
			array( 'icon-uni5f' => 'uni5f' ),
			array( 'icon-uni60' => 'uni60' ),
			array( 'icon-uni61' => 'uni61' ),
			array( 'icon-uni62' => 'uni62' ),
			array( 'icon-uni63' => 'uni63' ),
			array( 'icon-uni64' => 'uni64' ),
			array( 'icon-uni65' => 'uni65' ),
			array( 'icon-uni66' => 'uni66' ),
			array( 'icon-uni67' => 'uni67' ),
			array( 'icon-uni68' => 'uni68' ),
			array( 'icon-uni69' => 'uni69' ),
			array( 'icon-uni6a' => 'uni6a' ),
			array( 'icon-uni6b' => 'uni6b' ),
			array( 'icon-uni6c' => 'uni6c' ),
			array( 'icon-uni6d' => 'uni6d' ),
			array( 'icon-uni6e' => 'uni6e' ),
			array( 'icon-uni6f' => 'uni6f' ),
			array( 'icon-uni70' => 'uni70' ),
			array( 'icon-uni71' => 'uni71' ),
			array( 'icon-uni72' => 'uni72' ),
			array( 'icon-uni73' => 'uni73' ),
			array( 'icon-uni74' => 'uni74' ),
			array( 'icon-uni75' => 'uni75' ),
			array( 'icon-uni76' => 'uni76' ),
			array( 'icon-uni77' => 'uni77' ),
			array( 'icon-uni78' => 'uni78' ),
			array( 'icon-uni79' => 'uni79' ),
			array( 'icon-uni7a' => 'uni7a' ),
			array( 'icon-uni7b' => 'uni7b' ),
			array( 'icon-uni7c' => 'uni7c' ),
			array( 'icon-uni7d' => 'uni7d' ),
			array( 'icon-uni7e' => 'uni7e' ),
			array( 'icon-copyright' => 'copyright' ),
		);

		return array_merge( $icons, array( $linearicons ) );
	}

	/**
	 * Enqueue icon element font
	 *
	 * @param $font
	 */
	function vc_icon_element_fonts_enqueue( $font ) {
		switch ( $font ) {
			case 'ionicons':
				wp_enqueue_style( 'ionicons' );
				break;

			case 'linearicons':
				wp_enqueue_style( 'linearicons' );
				break;
		}
	}

	function vc_iconpicker_base_register_css() {
		wp_enqueue_style( 'ionicons', SUPRO_ADDONS_URL . '/assets/css/ionicons.min.css', array(), '2.0.0' );
		wp_enqueue_style( 'linearicons', SUPRO_ADDONS_URL . '/assets/css/linearicons.min.css', array(), '1.0.0' );
	}
}